@@ -14,8 +14,7 @@
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -374,7 +373,9 @@ module SiSU_character_encode
   ['ü',  252, '374', '\303\274',     '&#252;', '&uuml;',    'ü',    '\"{u}',           '',                'Small u, umlaut         ü' ],
   ['ý',  253, '375', '\303\275',     '&#253;', '&yacute;',  'ý',    '',                '',                'Small y, acute accent   ý' ],
   ['þ',  254, '376', '\303\276',     '&#254;', '&thorn;',   'þ',    '',                '',                'Small thorn, Icelandic  þ' ],
-  ['ÿ',  255, '377', '\303\277',     '&#255;', '&yuml;',    'ÿ',    '',                '',                'Smally y, umlaut        ÿ' ]
+  ['ÿ',  255, '377', '\303\277',     '&#255;', '&yuml;',    'ÿ',    '',                '',                'Smally y, umlaut        ÿ' ],
+  ['∝',     ,    '',         '',    '&#8733;', '&prop;',    '∝',    '',                '',                'proportional to  U+221D (8733) ∝' ],
+  ['∞',     ,    '',         '',    '&#8734;', '&infin;',   '∞',    '',                '',                'infinity  U+221E (8734) ∞' ],
 ]
     end
   end
