@@ -1,4 +1,4 @@
-# coding:utf-7
+# coding:utf-8
 =begin
 
  * Name: SiSU
@@ -9,15 +9,13 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007,
-   2008 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -90,6 +88,8 @@ Mx[:gl_bullet]=       "#{Mx[:gl_o]}●#{Mx[:gl_c]}"
 #non substantive text sort: <-#> <~#>
   Mx[:pa_non_object_dummy_heading]="#{Mx[:pa_o]}-##{Mx[:pa_c]}" #unnumbered paragraph, delete when not required [used in dummy headings, eg. for segmented html] (place marker at end of paragraph)
   Mx[:pa_non_object_no_heading]="#{Mx[:pa_o]}~##{Mx[:pa_c]}" #unnumbered paragraph (place marker at end of paragraph)
+Mx[:idx_o]='▢ ';                                         Mx[:idx_c]='▢ ' #
+Mx[:nbsp]=            '░' #'▭ '
 Mx[:br_line]=         "#{Mx[:mk_o]}br#{Mx[:mk_c]}"
 Mx[:br_paragraph]=    "#{Mx[:mk_o]}br#{Mx[:mk_c]}"
 Mx[:br_nl]=           "#{Mx[:mk_o]}nl#{Mx[:mk_c]}"
@@ -97,7 +97,8 @@ Mx[:br_page]=         "#{Mx[:mk_o]}pb#{Mx[:mk_c]}"
 Mx[:br_page_new]=     "#{Mx[:mk_o]}pn#{Mx[:mk_c]}"
 Mx[:br_endnotes]=     "#{Mx[:mk_o]}ENDNOTES#{Mx[:mk_c]}"
 Mx[:br_eof]=          "#{Mx[:mk_o]}EOF#{Mx[:mk_c]}"
-Mx[:lnk_o]='「'; Mx[:lnk_c]='」'
+Mx[:lnk_o]='◁'; Mx[:lnk_c]='▷'
+ #‹ ›
 Mx[:sm_set_o]='《'; Mx[:sm_set_c]='》'
 Mx[:sm_subset_o]='《 '; Mx[:sm_subset_c]='》'
 #Mx[:sm_set_o]='∈ '; Mx[:sm_set_c]='∋ '
@@ -139,9 +140,9 @@ unless RUBY_VERSION < '1.9'
   Mx[:sm_set_o].force_encoding('utf-8');                    Mx[:sm_set_c].force_encoding('utf-8')
   Mx[:sm_subset_o].force_encoding('utf-8');                 Mx[:sm_subset_c].force_encoding('utf-8')
 #
-  Rx[:mx_fa_clean].force_encoding('utf-8')
-  Rx[:lv].force_encoding('utf-8');Rx[:lv_1].force_encoding('utf-8');Rx[:lv_2].force_encoding('utf-8');Rx[:lv_3].force_encoding('utf-8');Rx[:lv_4].force_encoding('utf-8');Rx[:lv_5].force_encoding('utf-8');Rx[:lv_6].force_encoding('utf-8');Rx[:lv_7].force_encoding('utf-8');Rx[:lv_8].force_encoding('utf-8');Rx[:lv_9].force_encoding('utf-8')
-  Rx[:meta].force_encoding('utf-8')
+  #Rx[:mx_fa_clean].force_encoding('utf-8')
+  #Rx[:lv].force_encoding('utf-8');Rx[:lv_1].force_encoding('utf-8');Rx[:lv_2].force_encoding('utf-8');Rx[:lv_3].force_encoding('utf-8');Rx[:lv_4].force_encoding('utf-8');Rx[:lv_5].force_encoding('utf-8');Rx[:lv_6].force_encoding('utf-8');Rx[:lv_7].force_encoding('utf-8');Rx[:lv_8].force_encoding('utf-8');Rx[:lv_9].force_encoding('utf-8')
+  #Rx[:meta].force_encoding('utf-8')
 end
 __END__
 consider:
@@ -166,4 +167,6 @@ check:
  ‹ › ∗ 
 '〔lv1〕','〔lv2〕','〔lv3〕','〔lv4〕','〔lv5〕','〔lv6〕','〔lv7〕','〔lv8〕','〔lv9〕'
 '〔 Ѳ1〕','〔 Ѳ2〕','〔 Ѳ3〕','〔 Ѳ4〕','〔 Ѳ5〕','〔Ѳ6〕','〔Ѳ7〕','〔Ѳ8〕','〔Ѳ9〕'
+◁▷ 
 
+◀this is text or an image▶ http://
