@@ -14,8 +14,7 @@
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -99,6 +98,136 @@ module SiSU_Style
     color: #{@vz.color_blue_ink};
     text-decoration: underline;
   }
+WOK
+    end
+    def harvest
+      <<WOK
+/* SiSU harvest css default stylesheet */
+  body {
+    color: black;
+    background: "#ffffff";
+    background-color: "#ffffff";
+  }
+  a:link {
+    color: #003399;
+    text-decoration: none;
+  }
+  a:visited {
+    color: #003399;
+    text-decoration: none;
+  }
+  a:hover {
+    color: #000000;
+    background-color: #f9f9aa;
+  }
+  a:hover img {
+    background-color: "#ffffff";
+  }
+  a:active {
+    color: #003399;
+    text-decoration: underline;
+  }
+
+  .norm, .bold {
+    line-height: 150%;
+    margin-left: 1em;
+    margin-right: 2em;
+    margin-top: 10px;
+    margin-bottom: 0px;
+    text-indent: 0mm;
+  }
+  p, h0, h1, h2, h3, h4, h5, h6 {
+    display: block;
+    font-family: verdana, arial, georgia, tahoma, sans-serif, helvetica, times, roman;
+    font-size: 100%;
+    font-weight: normal;
+    line-height: 150%;
+    /* text-align: justify; */
+    margin-left: 1em;
+    text-indent: 0mm;
+    margin-top: 2px;
+    margin-bottom: 2px;
+    margin-right: 6px;
+    text-align: left;
+  }
+  h1 {
+    font-size: 120%;
+    font-weight: bold;
+    color: white;
+    background: #000088;
+    margin-left: 0em;
+  }
+  p.work {
+    font-size: 80%;
+    margin-left: 5em;
+    margin-top: 0px;
+    margin-bottom: 0px;
+    margin-right: 6px;
+    text-align: left;
+  }
+  p.author {
+    font-size: 100%;
+    margin-left: 2em;
+    margin-top: 0px;
+    margin-bottom: 0px;
+    margin-right: 6px;
+    text-align: left;
+  }
+  p.publication {
+    font-size: 80%;
+    margin-left: 4em;
+    margin-top: 0px;
+    margin-bottom: 0px;
+    margin-right: 6px;
+    text-align: left;
+  }
+  p.letter {
+    font-weight: bold;
+    font-size: 60%;
+    margin-left: 1em;
+    margin-top: 0px;
+    margin-bottom: 0px;
+    margin-right: 6px;
+    text-align: left;
+    color: white;
+    background: #880000;
+  }
+  p.lev0 {
+    font-size: 120%;
+    margin-left: 1em;
+    color: white;
+    background: #000000;
+  }
+
+  p.lev1 {
+    font-size: 110%;
+    margin-left: 2em;
+    color: white;
+    background: #444444;
+  }
+
+  p.lev2 {
+    font-size: 100%;
+    margin-left: 3em;
+    background: #888888;
+  }
+
+  p.lev3 {
+    font-size: 90%;
+    margin-left: 4em;
+    background: #bbbbbb;
+  }
+
+  p.lev4 {
+    font-size: 80%;
+    margin-left: 5em;
+    background: #eeeeee;
+  }
+
+  p.lev5 {
+    font-size: 80%;
+    margin-left: 6em;
+  }
 WOK
     end
     def html                                      #stylesheet for css html pages == html.css
@@ -106,7 +235,8 @@ WOK
 /* SiSU css default stylesheet */
   body {
     color: black;
-    background: #{@vz.color_white};
+    background: "#ffffff";
+    background-color: "#ffffff";
   }
 /*
     table {
@@ -118,28 +248,32 @@ WOK
     }
     th, td {
       display: inline;
+      vertical-align: top;
     }
 */
   a:link {
-    color: #{@vz.color_blue_ink};
+    color: #003399;
     text-decoration: none;
   }
   a:visited {
-    color: #{@vz.color_blue_ink};
+    color: #003399;
     text-decoration: none;
   }
+  a:hover {
+    color: #000000;
+    background-color: #f9f9aa;
+  }
 /*
   a:hover {
-    color: #{@vz.color_black};
     border-bottom: 2px solid #777777;
-    background-color: #{@vz.color_yellow_light};
+    background-color: #fff3b6;
   }
 */
   a:hover img {
-    background-color: #{@vz.color_white};
+    background-color: "#ffffff";
   }
   a:active {
-    color: #{@vz.color_blue_ink};
+    color: #003399;
     text-decoration: underline;
   }
   div {
@@ -150,6 +284,7 @@ WOK
     margin-left: 5%;
     margin-right: 1%;
   }
+
   #top_band {
     position: absolute;
     top: 0;
@@ -167,7 +302,7 @@ WOK
     position: absolute;
     top: 80px;
     left: 0;
-    margin-left: 0;
+    margin-left: 1%;
     width: 20%;
   }
   #column_center {
@@ -197,61 +332,136 @@ WOK
     margin-left: 75%;
     width: 20%;
   }
-  p {
+
+  .norm, .bold {
+    line-height: 150%;
+    margin-left: 0em;
+    margin-right: 2em;
+    margin-top: 10px;
+    margin-bottom: 0px;
+    text-indent: 0mm;
+  }
+  p, h0, h1, h2, h3, h4, h5, h6 {
     display: block;
-    font-family: #{fonts};
+    font-family: verdana, arial, georgia, tahoma, sans-serif, helvetica, times, roman;
     font-size: 100%;
     font-weight: normal;
     line-height: 150%;
-    text-align: left;
-    margin-left: 10mm;
+    text-align: justify;
+    margin-left: 0em;
+    margin-right: 2em;
     text-indent: 0mm;
     margin-top: 3px;
     margin-bottom: 3px;
-    margin-right: 5mm;
   }
-  p.norm {
-    text-align: justify;
+  p.norm { }
+  p.i1 {margin-left: 1em;}
+  p.i2 {margin-left: 2em;}
+  p.i3 {margin-left: 3em;}
+  p.i4 {margin-left: 4em;}
+  p.i5 {margin-left: 5em;}
+  p.i6 {margin-left: 6em;}
+  p.i7 {margin-left: 7em;}
+  p.i8 {margin-left: 8em;}
+  p.i9 {margin-left: 9em;}
+
+  p.it0 {
+    margin-left: 0em;
+    margin-top: 6px;
+    margin-bottom: 0px;
+    line-height: 100%;
   }
+  p.it1 {
+    margin-left: 1em;
+    margin-top: 0px;
+    margin-bottom: 0px;
+    line-height: 100%;
+  }
+  p.it2 {
+    margin-left: 2em;
+    margin-top: 0px;
+    margin-bottom: 0px;
+    line-height: 100%;
+  }
+  p.it3 {
+    margin-left: 3em;
+    margin-top: 0px;
+    margin-bottom: 0px;
+    line-height: 100%;
+  }
+  p.it4 {
+    margin-left: 4em;
+    margin-top: 0px;
+    margin-bottom: 0px;
+    line-height: 100%;
+  }
+  p.it5 {
+    margin-left: 5em;
+    margin-top: 0px;
+    margin-bottom: 0px;
+    line-height: 100%;
+  }
+  p.it6 {
+    margin-left: 6em;
+    margin-top: 0px;
+    margin-bottom: 0px;
+    line-height: 100%;
+  }
+  p.it7 {
+    margin-left: 7em;
+    margin-top: 0px;
+    margin-bottom: 0px;
+    line-height: 100%;
+  }
+  p.it8 {
+    margin-left: 8em;
+    margin-top: 0px;
+    margin-bottom: 0px;
+    line-height: 100%;
+  }
+  p.it9 {
+    margin-left: 9em;
+    margin-bottom: 0px;
+    margin-top: 0px;
+    line-height: 100%;
+  }
+
   p.code {
-    font-family: monospace;
+    font-family: inconsolata, andale mono, courier new, courier, monospace;
+    font-size: 90%;
     text-align: left;
   }
+
   p.caption {
     text-align: left;
     font-size: 80%;
     display: inline;
   }
+
   p.endnote {
-    font-family: #{fonts};
     font-size: 96%;
-    font-weight: normal;
     line-height: 120%;
     text-align: left;
-    margin-left: 10mm;
-    text-indent: 0mm;
-    margin-top: 3px;
-    margin-bottom: 3px;
     margin-right: 15mm;
   }
   p.endnote_indent {
-    font-family: #{fonts};
     font-size: 96%;
-    font-weight: normal;
     line-height: 120%;
     text-align: left;
-    margin-left: 15mm;
-    text-indent: 0mm;
-    margin-top: 3px;
-    margin-bottom: 3px;
+    margin-left: 2em;
     margin-right: 15mm;
   }
+
   p.center {
     text-align: center;
   }
   p.bold {
     font-weight: bold;
   }
+  p.bold_left {
+    font-weight: bold;
+    text-align: left;
+  }
   p.centerbold {
     text-align: center;
     font-weight: bold;
@@ -261,23 +471,7 @@ WOK
     font-style: normal;
     background: #fff3b6;
   }
-  p.ocn, p.paranum {
-    font-size: 10px;
-    margin-top: 0px;
-    margin-bottom: 5px;
-    color: #777777;
-    margin-right: 5px;
-    text-align: right;
-  }
-  p.ocn_off, p.no_paranum {
-    display: none;
-    font-size: 10px;
-    margin-top: 0px;
-    margin-bottom: 5px;
-    color: #777777;
-    margin-right: 5px;
-    text-align: right;
-  }
+
   p.small {
     font-size: 80%;
     margin-top: 0px;
@@ -285,7 +479,8 @@ WOK
     margin-right: 6px;
     text-align: left;
   }
-  p.tiny {
+
+  .tiny, .tiny_left, .tiny_right, .tiny_center {
     font-size: 10px;
     margin-top: 0px;
     margin-bottom: 0px;
@@ -293,33 +488,23 @@ WOK
     margin-right: 6px;
     text-align: left;
   }
+  p.tiny { }
   p.tiny_left {
-    font-size: 10px;
-    margin-top: 0px;
-    margin-bottom: 0px;
-    color: #777777;
     margin-left: 0px;
     margin-right: 0px;
     text-align: left;
   }
   p.tiny_right {
-    font-size: 10px;
-    margin-top: 0px;
-    margin-bottom: 0px;
-    color: #777777;
-    margin-right: 5mm;
+    margin-right: 1em;
     text-align: right;
   }
   p.tiny_center {
-    font-size: 10px;
-    margin-top: 0px;
-    margin-bottom: 0px;
-    color: #777777;
     margin-left: 0px;
     margin-right: 0px;
     text-align: center;
   }
-  p.pane {
+
+  p.pane, p.pane_title, p.pane_blurb, p.pane_link, p.pane_indent {
     font-size: 80%;
     margin-top: 0px;
     margin-bottom: 0px;
@@ -327,39 +512,26 @@ WOK
     margin-right: 4px;
     text-align: left;
   }
+  p.pane { }
   p.pane_title {
     font-weight: bold;
-    font-size: 80%;
-    margin-top: 0px;
     margin-bottom: 0px;
-    margin-left: 2mm;
-    margin-right: 4px;
-    text-align: left;
   }
   p.pane_blurb {
     font-size: 10px;
-    margin-top: 0px;
     margin-bottom: 0px;
-    margin-left: 2mm;
-    margin-right: 4px;
-    text-align: left;
   }
   p.pane_link {
     font-size: 10px;
-    margin-top: 0px;
     margin-bottom: 0px;
     margin-left: 4mm;
-    margin-right: 4px;
-    text-align: left;
   }
   p.pane_indent {
     font-size: 10px;
-    margin-top: 0px;
     margin-bottom: 0px;
     margin-left: 4mm;
-    margin-right: 4px;
-    text-align: left;
   }
+
   p.concordance_word {
     line-height: 150%;
     font-weight: bold;
@@ -371,20 +543,30 @@ WOK
     font-size: 80%;
     color: #777777;
     display: inline;
-    margin-left: 0mm;
-    text-indent: 0mm;
+    margin-left: 0em;
   }
   p.concordance_object {
     font-size: 80%;
-    font-weight: normal;
     line-height: 120%;
     text-align: left;
-    margin-left: 15mm;
-    text-indent: 0mm;
+    margin-left: 3em;
     margin-top: 1px;
     margin-bottom: 3px;
   }
-  p.quickref{
+  p.book_index_lev1 {
+    line-height: 100%;
+    margin-top: 4px;
+    margin-bottom: 1px;
+  }
+  p.book_index_lev2 {
+    line-height: 100%;
+    text-align: left;
+    margin-left: 3em;
+    margin-top: 1px;
+    margin-bottom: 3px;
+  }
+
+  p.quickref {
     font-size: 10px;
     font-style: italic;
     margin-top: 0px;
@@ -393,7 +575,7 @@ WOK
     margin-right: 5px;
     text-align: left;
   }
-  p.bigref{
+  p.bigref {
     font-size: 11px;
     font-weight: bold;
     margin-top: 0px;
@@ -402,19 +584,36 @@ WOK
     margin-right: 5px;
     text-align: center;
   }
-  p.i1 {margin-left: 15mm;}
-  p.i2 {margin-left: 20mm;}
-  p.i3 {margin-left: 25mm;}
-  p.i4 {margin-left: 30mm;}
-  p.i5 {margin-left: 35mm;}
-  p.i6 {margin-left: 40mm;}
-  p.i7 {margin-left: 45mm;}
-  p.i8 {margin-left: 50mm;}
-  p.i9 {margin-left: 55mm;}
+
+  p.letter {
+    font-weight: bold;
+    font-size: 80%;
+    margin-left: 0em;
+    margin-top: 2px;
+    margin-bottom: 2px;
+    margin-right: 6px;
+    text-align: left;
+    color: white;
+    background: #880000;
+  }
+
+  label.ocn {
+    width: 2%;
+    float: right;
+    top: 0;
+    font-size: 10px;
+    margin-top: 0px;
+    margin-bottom: 5px;
+    color: #777777;
+    margin-right: 5px;
+    text-align: right;
+    background-color: #ffffff;
+  }
 
   table { }
   tr { }
-  th, td { }
+  th, td { vertical-align: top; }
+
   p.left, th.left, td.left {
     text-align: left;
   }
@@ -426,75 +625,6 @@ WOK
     text-align: right;
   }
 
-  h0, h1, h2, h3, h4, h5, h6 {
-    display: block;
-    font-family: #{fonts};
-    font-weight: bold;
-    line-height: 120%;
-    margin-left: 10mm;
-    margin-right: 10mm;
-    text-align: left;
-    margin-top: 20px;
-    margin-bottom: 10px;
-  }
-  h1.center, h2.center, h3.center, h4.center, h5.center, h6.center {
-    text-align: center;
-  }
-  ul {
-    list-style: none;
-  }
-  ul.horizontal {
-    list-style: none;
-  }
-  ul.vertical {
-    list-style: none;
-  }
-  li {
-    background: url(../image/bullet_09.png) no-repeat 0px 6px;
-    /* list-style-type: disc; */
-    padding-left: 20px;
-    display: block;
-    font-family: #{fonts};
-    /* font-size: 100%; */
-    font-weight: normal;
-    line-height: 150%;
-    text-align: left;
-    margin-left: 10mm;
-    text-indent: 0mm;
-    margin-top: 3px;
-    margin-bottom: 3px;
-    margin-right: 0mm;
-  }
-  li.bullet {
-    margin-left: 10mm;
-  }
-  li.i1 {
-    margin-left: 15mm;
-  }
-  li.i2 {
-    margin-left: 20mm;
-  }
-  li.i3 {
-    margin-left: 25mm;
-  }
-  li.i4 {
-    margin-left: 30mm;
-  }
-  li.i5 {
-    margin-left: 35mm;
-  }
-  li.i6 {
-    margin-left: 40mm;
-  }
-  li.i7 {
-    margin-left: 45mm;
-  }
-  li.i8 {
-    margin-left: 50mm;
-  }
-  li.i9 {
-    margin-left: 55mm;
-  }
   #horizontal_links {
     background: #eeeeee;
     margin-left: 5%;
@@ -515,8 +645,6 @@ WOK
     background: none;
   }
   #horizontal a {
-    /* font-weight: normal; */
-    /* float: left; */
     line-height: 12px;
     margin: 0 0 0 0;
     text-decoration: none;
@@ -525,20 +653,20 @@ WOK
   #horizontal a.active, #horizontal a:hover {
     border-bottom: 2px solid #777777;
     padding-bottom: 2px;
-    /* font-weight: bold; */
     color: #000077;
   }
   #horizontal a:hover {
     color: #000077;
   }
+
   #document_versions {
     position: absolute;
     top: 10mm;
     right: 2%;
     width: 12%;
-    /* background: #ffffff; */
     float: right;
   }
+
   #vertical_links {
     position: absolute;
     top: 10mm;
@@ -548,28 +676,15 @@ WOK
     float: right;
   }
   #vertical {
-    /* background: none; */
     padding: 0 12px 0px 0px;
-    /* border-top: 2px solid #000077; */
-    /* border-bottom: 2px solid #000077; */
-    /* margin-left: 33%; */
     margin-left: 2%;
     margin-right: 2%;
   }
-/*
-  #vertical {
-    padding: 0 12px 0px 0px;
-    border-top: 2px solid #000077;
-    border-bottom: 2px solid #000077;
-    margin-left: 33%;
-    margin-right: 33%;
-  } */
   #vertical li {
     display: block;
     list-style-type: none;
   }
   #vertical a {
-    /* font-weight: normal; */
     line-height: 12px;
     text-decoration: none;
     color: #000077;
@@ -577,15 +692,43 @@ WOK
   #vertical a.active, #vertical a:hover {
     border-bottom: 2px solid #777777;
     padding-bottom: 2px;
-    /* font-weight: bold; */
     color: #000077;
   }
-  li.doc {
+
+  ul, li {
+    list-style-type: none;
+    list-style: none;
+    padding-left: 20px;
+    display: block;
+    font-family: verdana, arial, georgia, tahoma, sans-serif, helvetica, times, roman;
+    font-weight: normal;
+    line-height: 150%;
+    text-align: left;
+    text-indent: 0mm;
+    margin-left: 1em;
+    margin-right: 2em;
+    margin-top: 3px;
+    margin-bottom: 3px;
+  }
+
+  li {
     background: url(../image/bullet_09.png) no-repeat 0px 6px;
-    /* background: url(../image/bullet_doc.png) no-repeat 0 0; */
-    /* background: url(../../_sisu/image/bullet_09.png) no-repeat 0px 6px; */
-    padding-left: 16px;
-    margin-left: 10px;
+  }
+
+  ul {
+  }
+  li.bullet { margin-left: 1em; }
+  li.i1 { margin-left: 2em; }
+  li.i2 { margin-left: 3em; }
+  li.i3 { margin-left: 4em; }
+  li.i4 { margin-left: 5em; }
+  li.i5 { margin-left: 6em; }
+  li.i6 { margin-left: 7em; }
+  li.i7 { margin-left: 8em; }
+  li.i8 { margin-left: 9em; }
+  li.i9 { margin-left: 10em; }
+
+  li.doc, li.ref, li.refcenter {
     margin-top: 0px;
     margin-bottom: 0px;
     margin-right: 0px;
@@ -593,74 +736,65 @@ WOK
     font-style: normal;
     text-align: left;
   }
+  li.doc {
+    background: url(../image/bullet_09.png) no-repeat 0px 6px;
+    padding-left: 16px;
+    margin-left: 10px;
+    margin-right: 0px;
+  }
   li.ref {
     background: none;
     padding-left: 0;
     margin-left: 0;
-    margin-top: 0px;
-    margin-bottom: 0px;
     color: #777777;
-    font-size: 8px;
-    font-style: normal;
-    text-align: left;
   }
   li.refcenter {
     background: url(../image/bullet_09.png) no-repeat 0px 6px;
-    /* background: url(../image/bullet_doc.png) no-repeat 0 0; */
-    background: none;
     padding-left: 20px;
     margin-left: 10%;
     font-size: 9px;
-    margin-top: 0px;
-    margin-bottom: 0px;
     color: #777777;
     text-align: center;
   }
   li.refbold {
-    background: url(../image/bullet_09.png) no-repeat 0px 6px;
-    /* background: url(../image/bullet_doc.png) no-repeat 0 0; */
-    /* padding-left: 0px; */
+    list-style-type: none;
     padding-left: 16px;
     margin-left: 0;
-    margin-top: 0px;
-    margin-bottom: 0px;
     margin-right: 10mm;
-    font-size: 8px;
     font-weight: bold;
-    text-align: left;
   }
-  h1 {
-    font-size: 120%;
-    margin-top: 20px;
-  }
-  h2 {
-    font-size: 115%;
-    margin-top: 20px;
-  }
-  h3 {
-    font-size: 110%;
-    margin-top: 20px;
-  }
-  h4 {
-    font-size: 105%;
-  }
-  h5 {
-    font-size: 100%;
-  }
-  h6 {
-    font-size: 100%;
-  }
-  h0 {
-    font-size: 80%;
-  }
-  h1.norm, h2.norm, h3.norm {
-    font-size: 110%;
-    margin-left: 10mm;
-    margin-right: 15mm;
+
+  h0, h1, h2, h3, h4, h5, h6 {
+    font-weight: bold;
+    line-height: 120%;
     text-align: left;
     margin-top: 20px;
     margin-bottom: 10px;
   }
+  h4.norm, h5.norm, h6.norm {
+    margin-top: 10px;
+    margin-bottom: 0px;
+  }
+  h1.center, h2.center, h3.center, h4.center, h5.center, h6.center {
+    text-align: center;
+  }
+  h1 { font-size: 120%; }
+  h2 { font-size: 115%; }
+  h3 { font-size: 110%; }
+  h4 { font-size: 105%; }
+  h5 { font-size: 100%; }
+  h6 { font-size: 100%; }
+  h0 { font-size: 80%; }
+
+  h1.i {margin-left: 2em;}
+  h2.i {margin-left: 3em;}
+  h3.i {margin-left: 4em;}
+  h4.i {margin-left: 5em;}
+  h5.i {margin-left: 6em;}
+  h6.i {margin-left: 7em;}
+  h7.i {margin-left: 8em;}
+  h8.i {margin-left: 9em;}
+  h9.i {margin-left: 10em;}
   h1.top_band {
     display: inline;
     text-align: left;
@@ -682,6 +816,7 @@ WOK
     margin-right: 0px;
     text-align: left;
   }
+
   p.top_band {
     display: inline;
     text-align: left;
@@ -709,178 +844,240 @@ WOK
     text-indent: 0mm;
     margin-right: 1mm;
   }
-  h4.norm, h5.norm, h6.norm {
-    font-size: 100%;
-    margin-left: 10mm;
-    margin-right: 15mm;
-    text-align: left;
-    margin-top: 10px;
-    margin-bottom: 0px;
-  }
-  h1.i {margin-left: 10mm;}
-  h2.i {margin-left: 15mm;}
-  h3.i {margin-left: 20mm;}
-  h4.i {margin-left: 25mm;}
-  h5.i {margin-left: 30mm;}
-  h6.i {margin-left: 35mm;}
-  h7.i {margin-left: 40mm;}
-  h8.i {margin-left: 45mm;}
-  h9.i {margin-left: 50mm;}
-  h1.banner {
+
+  .banner, .subbanner {
     font-weight: bold;
     text-align: center;
-    font-size: 120%;
     margin-left: 10mm;
     margin-right: 15mm;
     margin-top: 20px;
     margin-bottom: 10px;
   }
+
+  h1.banner {
+    font-size: 120%;
+  }
   h1.subbanner {
-    font-weight: bold;
-    text-align: center;
     font-size: 115%;
-    margin-left: 10mm;
-    margin-right: 15mm;
-    margin-top: 20px;
-    margin-bottom: 10px;
   }
   h2.banner {
-    font-weight: bold;
-    text-align: center;
     font-size: 110%;
-    margin-left: 10mm;
-    margin-right: 15mm;
-    margin-top: 20px;
-    margin-bottom: 10px;
   }
   h3.banner {
-    font-weight: bold;
-    text-align: center;
     color: #990000;
     font-size: 105%;
-    margin-left: 10mm;
-    margin-right: 15mm;
-    margin-top: 20px;
-    margin-bottom: 10px;
   }
   h4.banner {
-    font-weight: bold;
-    text-align: center;
     color: #ff0000;
     font-size: 100%;
-    margin-left: 10mm;
-    margin-right: 15mm;
-    margin-top: 20px;
-    margin-bottom: 10px;
   }
   h5.banner {
-    font-weight: bold;
   }
   h6.banner {
-    font-weight: bold;
   }
-  h1.toc {
-    margin-left: 10mm;
-    font-size: 115%;
+
+  .toc {
+    font-weight: normal;
     margin-top: 6px;
     margin-bottom: 6px;
+  }
+  h1.toc {
+    margin-left: 1em;
+    font-size: 115%;
     line-height: 150%;
   }
   h2.toc {
-    margin-left: 15mm;
+    margin-left: 2em;
     font-size: 110%;
-    margin-top: 6px;
-    margin-bottom: 6px;
     line-height: 140%;
   }
   h3.toc {
-    margin-left: 20mm;
+    margin-left: 3em;
     font-size: 105%;
-    margin-top: 6px;
-    margin-bottom: 6px;
     line-height: 120%;
   }
   h4.toc {
-    margin-left: 25mm;
-    font-weight: normal;
+    margin-left: 4em;
     font-size: 100%;
-    margin-top: 6px;
-    margin-bottom: 6px;
     line-height: 120%;
   }
   h5.toc {
-    margin-left: 30mm;
-    font-weight: normal;
+    margin-left: 5em;
     font-size: 95%;
-    margin-top: 6px;
-    margin-bottom: 6px;
     line-height: 110%;
   }
   h6.toc {
-    margin-left: 35mm;
-    font-weight: normal;
+    margin-left: 6em;
     font-size: 90%;
-    margin-top: 6px;
-    margin-bottom: 6px;
     line-height: 110%;
   }
-/* microtoc (for later) --> */
+
+  .microtoc {
+    margin-top: 2px;
+    margin-bottom: 2px;
+  }
+
   h1.microtoc {
     margin-left: 0mm;
     font-size: 115%;
-    margin-top: 2px;
-    margin-bottom: 2px;
   }
   h2.microtoc {
     margin-left: 5mm;
     font-size: 110%;
-    margin-top: 2px;
-    margin-bottom: 2px;
   }
   h3.microtoc {
     margin-left: 10mm;
     font-size: 105%;
-    margin-top: 2px;
-    margin-bottom: 2px;
   }
   h4.microtoc {
     margin-left: 15mm;
     font-weight: normal;
     font-size: 100%;
-    margin-top: 2px;
-    margin-bottom: 2px;
   }
   h5.microtoc {
     margin-left: 20mm;
     font-weight: normal;
     font-size: 95%;
-    margin-top: 2px;
-    margin-bottom: 2px;
   }
   h6.microtoc {
     margin-left: 25mm;
     font-weight: normal;
     font-size: 90%;
-    margin-top: 2px;
-    margin-bottom: 2px;
   }
-/* subtoc --> */
-  h5.subtoc {
-    margin-left: 20mm;
+
+  .subtoc {
     margin-right: 34%;
     font-weight: normal;
+  }
+  h5.subtoc {
+    margin-left: 2em;
     font-size: 80%;
     margin-top: 2px;
     margin-bottom: 2px;
   }
   h6.subtoc {
-    margin-left: 25mm;
-    margin-right: 34%;
-    font-weight: normal;
+    margin-left: 3em;
     font-size: 75%;
     margin-top: 0px;
     margin-bottom: 0px;
   }
+
+  div.substance {
+    width: 100%;
+    background-color: #ffffff;
+  }
+  div.ocn {
+    width: 5%;
+    float: right;
+    top: 0;
+    background-color: #ffffff;
+  }
+  div.endnote {
+    width: 95%;
+    background-color: #fffffff;
+  }
+  div.toc {
+    position: absolute;
+    float: left;
+    margin: 0;
+    padding: 0;
+    padding-top: 0.5em;
+    border: 0;
+    width: 13em;
+    background-color: #eeeeee;
+    margin-right:1em;
+  }
+  div.summary {
+    margin: 0;
+    padding: 0;
+    border-left: 13em solid #eeeeee;
+    padding-left: 1em;
+    background-color: #eeeeee;
+  }
+  div.content, div.main_column {
+    margin: 0;
+    padding: 0;
+    border-left: 13em solid #ffffff;
+    padding-left: 1em;
+  }
+  div.content:after {
+    content:' ';
+    clear:both;
+    display:block;
+    height:0;
+    overflow:hidden
+  }
+  div.footer {
+    clear:left;
+    padding: 0.5em;
+    font-size: 80%;
+    margin: 0;
+  }
+  div.toc ul {
+    list-style: none;
+    padding: 0;
+    margin: 0;
+  }
+  div.toc li ul a, li ul span.currentlink
+  {
+    font-weight: normal;
+    font-size: 90%;
+    padding-left: 2em;
+    background-color: #eeeeee;
+  }
+  div.toc a, span.currentlink{
+    display:block;
+    text-decoration: none;
+    padding-left: 0.5em;
+    color: #0000aa;
+  }
+  hr {
+    width: 90%;
+  }
+
+  span.currentlink {
+    text-decoration: none;
+    background-color: #aaaaf9;
+  }
+
+  div.toc a:visited {
+    color: #0000aa;
+  }
+  div.toc a:hover {
+    color: #000000;
+    background-color: #f9f9aa;
+  }
+
+  .minitoc {
+    font-weight: normal;
+    margin-top: 2px;
+    margin-bottom: 2px;
+  }
+  h1.minitoc, h2.minitoc, h3.minitoc {
+    margin-left: 0em;
+    font-weight: bold;
+    text-align: left;
+    font-size: 90%;
+    margin-top: 4px;
+    margin-bottom: 4px;
+  }
+  h4.minitoc {
+    margin-left: 0em;
+    font-size: 90%;
+  }
+  h5.minitoc {
+    margin-left: 1em;
+    font-size: 85%;
+  }
+  h6.minitoc {
+    margin-left: 2em;
+    font-size: 85%;
+  }
+  h0.minitoc {
+    margin-left: 0em;
+    font-size: 90%;
+  }
+
   h1.c, h2.c, h3.c, h4.c, h5.c, h6.c, p.c {
     text-align: center
   }
@@ -902,35 +1099,6 @@ WOK
     margin-bottom: 20px;
     margin-right: 15mm;
   }
-/*
-  table.hidden {
-    color: #ffffff;
-    text-decoration: none;
-  }
-  td.hidden {
-    color: #ffffff;
-    background-color: #000000;
-  }
-  td.hidden a.active, div.hidden a:hover {
-    color: #ffffff;
-    background-color: #000000;
-  }
-  td.hidden a:hover {
-    text-decoration: none;
-  }
-  div.hidden a {
-    line-height: 12px;
-    margin: 0 0 0 0;
-    text-decoration: none;
-    color: #000077;
-  }
-  div.hidden a.active, div.hidden a:hover {
-    text-decoration: none;
-  }
-  div.hidden a:hover {
-    text-decoration: none;
-  }
-*/
 WOK
     end
     def homepage                                  #stylesheet for index, home page
@@ -972,257 +1140,6 @@ WOK
   }
   #column_right p { font-size:12px}
   #banner h1 { margin:0px; padding:10px}
-WOK
-    end
-    def html_bk                                   #stylesheet for html... check use
-<<WOK
-    document {
-      display: block;
-      margin-left: 0mm;
-      margin-right: 0mm;
-    }
-    head {
-      display: block;
-      margin-bottom: 20px;
-      background-color: #dddddd;
-    }
-    dc,keywords,copyright {
-      display: block;
-      font-family: #{fonts};
-      color: blue;
-      background-color: #dddddd;
-      font-weight: normal;
-      text-align: justify;
-      font-size: xx-small%;
-      line-height: 120%;
-      margin-left: 5%;
-      margin-right: 5mm;
-      margin-top: 0px;
-      margin-bottom: 0px;
-    }
-    keywords,copyright {
-      display: block;
-      font-family: #{fonts};
-      color: red;
-      background-color: #dddddd;
-      font-weight: normal;
-      text-align: justify;
-      font-size: xx-small%;
-      line-height: 120%;
-      margin-left: 5%;
-      margin-right: 5mm;
-      margin-top: 0px;
-      margin-bottom: 0px;
-    }
-    table {
-      margin-left: 5%;
-      display: block;
-    }
-    tr {
-      display: block;
-    }
-    th, td {
-      display: inline;
-    }
-    th.left {
-      text-align: left;
-    }
-    td.right {
-      text-align: right;
-    }
-    body {
-      color: black;
-      background: #ffffff;
-    }
-    a:link {
-      color: #003399;
-      text-decoration: none;
-    }
-    a:visited {
-      color: #003399;
-      text-decoration: none;
-      /* background-color: #e3ecef; */
-    }
-    a:hover {
-      color: #000000;
-      text-decoration: underline;
-      background-color: #fff3b6;
-    }
-    a:hover IMG {
-      background-color: #ffffff;
-    }
-    a:active {
-      color: #003399;
-      text-decoration: underline;
-    }
-    p {
-      display: block;
-      font-family: #{fonts};
-      font-weight: normal;
-      text-align: justify;
-      font-size: 100%;
-      line-height: 150%;
-      margin-left: 5%;
-      margin-right: 5%;
-      margin-top: 2px;
-      margin-bottom: 0px;
-    }
-    p.norm {
-    }
-    p.h1 {
-      font-family: #{fonts};
-      font-size: 120%;
-      font-weight: bold;
-      text-align: left;
-      line-height: 120%;
-      margin-top: 20px;
-      margin-bottom: 10px;
-    }
-    p.h2 {
-      font-weight: bold;
-      font-size: 110%;
-      text-align: left;
-      margin-top: 20px;
-      margin-bottom: 10px;
-    }
-    p.h3 {
-      font-size: 110%;
-      font-weight: bold;
-      text-align: left;
-    }
-    p.h4 {
-      font-size: 110%;
-      font-weight: bold;
-      text-align: left;
-    }
-    p.h5 {
-      font-size: 110%;
-      font-weight: bold;
-      text-align: left;
-    }
-    p.h6 {
-      font-size: 110%;
-      font-weight: bold;
-      text-align: left;
-    }
-    p.toc1 {
-      font-weight: bold;
-      font-size: small;
-      text-align: left;
-      line-height: 100%;
-      margin-left: 5%;
-      margin-right: 5%;
-      margin-top: 10px;
-      margin-bottom: 5px;
-    }
-    p.toc2 {
-      font-weight: bold;
-      font-size: x-small;
-      text-align: left;
-      line-height: 100%;
-      margin-left: 5%;
-      margin-right: 10%;
-      margin-top: 10px;
-      margin-bottom: 5px;
-    }
-    p.toc3 {
-      font-size: x-small;
-      text-align: left;
-      line-height: 100%;
-      margin-left: 5%;
-      margin-right: 10%;
-      margin-top: 10px;
-      margin-bottom: 5px;
-    }
-    p.toc4 {
-      font-size: x-small;
-      text-align: left;
-      line-height: 100%;
-      margin-left: 10%;
-      margin-right: 10%;
-      margin-top: 5px;
-      margin-bottom: 5px;
-    }
-    p.toc5 {
-      font-size: x-small;
-      text-align: left;
-      line-height: 100%;
-      margin-left: 15%;
-      margin-right: 10%;
-      margin-top: 5px;
-      margin-bottom: 5px;
-    }
-    p.toc6 {
-      font-size: x-small;
-      text-align: left;
-      line-height: 100%;
-      margin-left: 20%;
-      margin-right: 10%;
-      margin-top: 5px;
-      margin-bottom: 5px;
-    }
-/* microtoc for use later -->  */
-/*
-
-*/
-/* subtoc --> */
-    p.subtoc4 {
-      font-size: x-small;
-      text-align: left;
-      line-height: 100%;
-      margin-left: 10%;
-      margin-right: 10%;
-      margin-top: 5px;
-      margin-bottom: 5px;
-    }
-    p.subtoc5 {
-      font-size: x-small;
-      text-align: left;
-      line-height: 100%;
-      margin-left: 15%;
-      margin-right: 10%;
-      margin-top: 5px;
-      margin-bottom: 5px;
-    }
-    p.subtoc6 {
-      font-size: x-small;
-      text-align: left;
-      line-height: 100%;
-      margin-left: 20%;
-      margin-right: 10%;
-      margin-top: 5px;
-      margin-bottom: 5px;
-    }
-    p.ocn {
-      display: block;
-      text-align: right;
-      vertical-align: super;
-      color: #999999;
-      font-size: xx-small;
-      margin-right: 0mm;
-      margin-top: 0px;
-      margin-bottom: 0px;
-    }
-    p.note {
-      display: block;
-      font-size: small;
-      font-family: #{fonts};
-      font-weight: normal;
-      line-height: 150%;
-      text-align: justify;
-      margin-left: 10%;
-      margin-right: 5%;
-      margin-top: 4px;
-      margin-bottom: 0px;
-    }
-    en {
-      font-size: xx-small;
-      vertical-align: super;
-    }
-    i { font-style: italic; }
-    b { font-style: bold; }
-    u { text-decoration: underline; }
-    br { display: block; }
 WOK
     end
     def xhtml                                     #stylesheet for xhtml
@@ -2015,8 +1932,7 @@ WOK
       margin-bottom: 0px;
       margin-right: 5mm
     }
-    p.norm {
-    }
+    p.norm { }
     p.endnote {
       font-size: 100%;
       margin-left: 20%;
