@@ -14,8 +14,7 @@
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -59,8 +58,8 @@
 
 =end
 module SiSU_document_structure
-  require "#{SiSU_lib}/dal_doc_str_tables"
-  require "#{SiSU_lib}/dal_doc_str_code"
+  require "#{SiSU_lib}/dal_doc_str_tables"                 # dal_doc_str_tables.rb
+  require "#{SiSU_lib}/dal_doc_str_code"                   # dal_doc_str_code.rb
   class Structure
     def initialize(md,para)
       @md,@para=md,para
@@ -216,15 +215,15 @@ module SiSU_document_structure
                   end
                 else
                   ocno+=1
-                  if para=~/#{Mx[:gr_o]}TZ#{Mx[:gr_c]}/;                             ocnt+=1 #table
+                  if para=~/#{Mx[:gr_o]}TZ#{Mx[:gr_c]}/;                      ocnt+=1 #table
                     ocn_dv,ocn_sp="o#{ocno}","t#{ocnt}"
-                  elsif para=~/^#{Mx[:gr_o]}code#{Mx[:gr_c]}/;                        ocnc+=1 #code block
+                  elsif para=~/^#{Mx[:gr_o]}code#{Mx[:gr_c]}/;                ocnc+=1 #code block
                     ocn_dv,ocn_sp="o#{ocno}","c#{ocnc}"
-                  elsif para=~/^#{Mx[:gr_o]}(?:group|alt|verse)#{Mx[:gr_c]}/;         ocng+=1 #group, poem
+                  elsif para=~/^#{Mx[:gr_o]}(?:group|alt|verse)#{Mx[:gr_c]}/; ocng+=1 #group, poem
                     ocn_dv,ocn_sp="o#{ocno}","g#{ocng}"
-                  elsif para=~/\{\S+?\.(?:png|jpg|gif)\s+/m;     ocni+=1 #image
+                  elsif para=~/#{Mx[:lnk_o]}\S+?\.(?:png|jpg|gif)\s+/m;       ocni+=1 #image
                     ocn_dv,ocn_sp="o#{ocno}","i#{ocni}"
-                  else                                           ocnp+=1 #paragraph
+                  else                                                        ocnp+=1 #paragraph
                     ocn_dv,ocn_sp="o#{ocno}","p#{ocnp}"
                   end
                 end
