@@ -14,8 +14,7 @@
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -101,59 +100,73 @@ module SiSU_DB_create
         } unless @opt.cmd =~/q/
         @conn.execute(%{
           CREATE TABLE metadata (
-            tid               BIGINT PRIMARY KEY,
-            title             VARCHAR(#{lt_title}) NULL,
-            subtitle          VARCHAR(#{lt_subtitle}) NULL,
-            creator           VARCHAR(#{lt_creator}) NULL,
-            illustrator       VARCHAR(#{lt_illustrator}) NULL,
-            translator        VARCHAR(#{lt_translator}) NULL,
-            subject           VARCHAR(#{lt_subject}) NULL,
-            date              VARCHAR(#{lt_date}) NULL,
-            date_created      VARCHAR(#{lt_date_created}) NULL,
-            date_issued       VARCHAR(#{lt_date_issued}) NULL,
-            date_available    VARCHAR(#{lt_date_available}) NULL,
-            date_valid        VARCHAR(#{lt_date_valid}) NULL,
-            date_modified     VARCHAR(#{lt_date_modified}) NULL,
-/*          date              DATE, */
-/*          date_created      DATE, */
-/*          date_issued       DATE, */
-/*          date_available    DATE, */
-/*          date_valid        DATE, */
-/*          date_modified     DATE, */
-            type              VARCHAR(#{lt_type}) NULL,
-            description       VARCHAR(#{lt_description}) NULL,
-            publisher         VARCHAR(#{lt_publisher}) NULL,
-            contributor       VARCHAR(#{lt_contributor}) NULL,
-            prepared_by       VARCHAR(#{lt_prepared_by}) NULL,
-            digitized_by      VARCHAR(#{lt_digitized_by}) NULL,
-            format            VARCHAR(#{lt_format}) NULL,
-            identifier        VARCHAR(#{lt_identifier}) NULL,
-            source            VARCHAR(#{lt_source}) NULL,
-            language          VARCHAR(#{lt_language}) NULL,
-            language_original VARCHAR(#{lt_language_original}) NULL,
-            relation          VARCHAR(#{lt_relation}) NULL,
-            coverage          VARCHAR(#{lt_coverage}) NULL,
-            rights            VARCHAR(#{lt_rights}) NULL,
-            copyright         VARCHAR(#{lt_copyright}) NULL,
-            owner             VARCHAR(#{lt_owner}) NULL,
-            keywords          VARCHAR(#{lt_keywords}) NULL,
-            comment           VARCHAR(#{lt_comment}) NULL,
-            loc               VARCHAR(#{lt_loc}) NULL,
-            dewey             VARCHAR(#{lt_dewey}) NULL,
-            isbn              VARCHAR(#{lt_isbn}) NULL,
-            pg                VARCHAR(#{lt_pg}) NULL,
-            abstract          VARCHAR(#{lt_abstract}) NULL,
-            prefix_a          TEXT NULL,
-            prefix_b          TEXT NULL,
-            skin              VARCHAR(#{lt_skin}) NULL,
-            markup            VARCHAR(#{lt_markup}) NULL,
-            links             VARCHAR(#{lt_links}) NULL,
-            information       VARCHAR(#{lt_information}) NULL,
-            contact           VARCHAR(#{lt_contact}) NULL,
-            suffix            VARCHAR(#{lt_suffix}) NULL,
-            filename          VARCHAR(#{lt_filename}) NULL UNIQUE,
-            types             CHAR(#{lt_types}) NULL,
-            subj              VARCHAR(#{lt_subj}) NULL
+            tid                  BIGINT PRIMARY KEY,
+            title                VARCHAR(#{lt_title}) NULL,
+            subtitle             VARCHAR(#{lt_subtitle}) NULL,
+            author               VARCHAR(#{lt_author}) NULL,
+/* plan to replace creator field, currently used, with author field */
+            creator              VARCHAR(#{lt_author}) NULL,
+            author_title         VARCHAR(#{lt_author_title}) NULL,
+            author_nationality   VARCHAR(#{lt_author_nationality}) NULL,
+            illustrator          VARCHAR(#{lt_illustrator}) NULL,
+            translator           VARCHAR(#{lt_translator}) NULL,
+            subject              VARCHAR(#{lt_subject}) NULL,
+            date                 VARCHAR(#{lt_date}) NULL,
+            date_added_to_site   VARCHAR(#{lt_date}) NULL,
+            date_created         VARCHAR(#{lt_date}) NULL,
+            date_issued          VARCHAR(#{lt_date}) NULL,
+            date_available       VARCHAR(#{lt_date}) NULL,
+            date_valid           VARCHAR(#{lt_date}) NULL,
+            date_modified        VARCHAR(#{lt_date}) NULL,
+            date_translated      VARCHAR(#{lt_date}) NULL,
+/*          date                 DATE, */
+/*          date_added_to_site   DATE, */
+/*          date_created         DATE, */
+/*          date_issued          DATE, */
+/*          date_available       DATE, */
+/*          date_valid           DATE, */
+/*          date_modified        DATE, */
+/*          date_translated      DATE, */
+            type                 VARCHAR(#{lt_type}) NULL,
+            description          VARCHAR(#{lt_description}) NULL,
+            publisher            VARCHAR(#{lt_publisher}) NULL,
+            contributor          VARCHAR(#{lt_contributor}) NULL,
+            prepared_by          VARCHAR(#{lt_prepared_by}) NULL,
+            digitized_by         VARCHAR(#{lt_digitized_by}) NULL,
+            format               VARCHAR(#{lt_format}) NULL,
+            identifier           VARCHAR(#{lt_identifier}) NULL,
+            source               VARCHAR(#{lt_source}) NULL,
+            language             VARCHAR(#{lt_language}) NULL,
+            language_original    VARCHAR(#{lt_language_original}) NULL,
+            relation             VARCHAR(#{lt_relation}) NULL,
+            coverage             VARCHAR(#{lt_coverage}) NULL,
+            rights               VARCHAR(#{lt_rights}) NULL,
+            copyright            VARCHAR(#{lt_copyright}) NULL,
+            owner                VARCHAR(#{lt_owner}) NULL,
+            keywords             VARCHAR(#{lt_keywords}) NULL,
+            comment              VARCHAR(#{lt_comment}) NULL,
+            loc                  VARCHAR(#{lt_loc}) NULL,
+            dewey                VARCHAR(#{lt_dewey}) NULL,
+            isbn                 VARCHAR(#{lt_isbn}) NULL,
+            pg                   VARCHAR(#{lt_pg}) NULL,
+            abstract             VARCHAR(#{lt_abstract}) NULL,
+            prefix_a             TEXT NULL,
+            prefix_b             TEXT NULL,
+            skin                 VARCHAR(#{lt_skin}) NULL,
+            markup               VARCHAR(#{lt_markup}) NULL,
+            links                VARCHAR(#{lt_links}) NULL,
+            information          VARCHAR(#{lt_information}) NULL,
+            contact              VARCHAR(#{lt_contact}) NULL,
+            suffix               VARCHAR(#{lt_suffix}) NULL,
+            filename             VARCHAR(#{lt_filename}) NULL UNIQUE,
+            types                CHAR(#{lt_types}) NULL,
+            subj                 VARCHAR(#{lt_subj}) NULL,
+            original_publication VARCHAR(#{lt_orig_pub}) NULL,
+            original_publication_date VARCHAR(#{lt_orig_pub_date}) NULL,
+            original_publication_institution VARCHAR(#{lt_orig_pub_institution}) NULL,
+            original_publication_nationality VARCHAR(#{lt_orig_pub_nationality}) NULL,
+            writing_focus_nationality VARCHAR(#{lt_writing_focus_nationality}) NULL,
+            topic_register       VARCHAR(#{lt_topic_register}) NULL
           );
           #{@comment.metadata}
         })
@@ -314,6 +327,8 @@ module SiSU_DB_create
           IS 'document subtitle';
         COMMENT ON COLUMN metadata.creator
           IS 'metadata creator (dublin core element 2)';
+        COMMENT ON COLUMN metadata.author
+          IS 'metadata author (dublin core element 2)';
         COMMENT ON COLUMN metadata.illustrator
           IS 'metadata illustrator';
         COMMENT ON COLUMN metadata.translator
