@@ -14,8 +14,7 @@
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -71,25 +70,25 @@ module  SiSU_DB_DBI
   require "#{SiSU_lib}/db_import"
   class Column_size < SiSU_DB_columns::Column_size
   end
-  class Test < SiSU_DB_tests::Test
+  class Test < SiSU_DB_tests::Test                                            #% db_tests.rb
   end
-  class Create <SiSU_DB_create::Create #<SiSU_DB::Column_size
+  class Create <SiSU_DB_create::Create #<SiSU_DB::Column_size                 #% db_create.rb
   end
-  class Case <SiSU_DB_select::Case
+  class Case <SiSU_DB_select::Case                                            #% db_select.rb
   end
-  class Index <SiSU_DB_index::Index                                           # create documents Indexes def initialize(opt,conn='',sql_type='')
+  class Index <SiSU_DB_index::Index                                           #% db_indexes.rb
   end
-  class Drop <SiSU_DB_drop::Drop
+  class Drop <SiSU_DB_drop::Drop                                              #% db_drop.rb
   end
-  class Remove <SiSU_DB_remove::Remove
+  class Remove <SiSU_DB_remove::Remove                                        #% db_remove.rb
   end
-  class Load_documents <SiSU_DB_tuple::Load_documents                                  #% main database populate/update
+  class Load_documents <SiSU_DB_tuple::Load_documents                         #% db_load_tuple.rb
   end
-  class Load_metadata <SiSU_DB_tuple::Load_metadata                                    #% update metadata
+  class Load_metadata <SiSU_DB_tuple::Load_metadata                           #% db_load_tuple.rb
   end
-  class Load_urls <SiSU_DB_tuple::Load_urls                                            #% update urls
+  class Load_urls <SiSU_DB_tuple::Load_urls                                   #% db_update urls
   end
-  class Import <SiSU_DB_import::Import #<SiSU_DB::Column_size                  #% main
+  class Import <SiSU_DB_import::Import #<SiSU_DB::Column_size                 #% db_import.rb
   end
 end
 __END__
