@@ -8,14 +8,13 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah All Rights Reserved.
+   2007, 2008, 2009 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -63,7 +62,7 @@ module SiSU_DB_import
   require "#{SiSU_lib}/db_columns"
   require "#{SiSU_lib}/db_load_tuple"
   require "#{SiSU_lib}/shared_html_lite"
-  #require 'sqlite3'
+  require 'sqlite3'
   class Import < SiSU_DB_columns::Column_size
     include SiSU_Param
     include SiSU_Screen
@@ -86,18 +85,30 @@ module SiSU_DB_import
       @col=Hash.new('')
       @col[:ocn]=''
       @counter={}
+      @db=SiSU_Env::Info_db.new
+      @driver_sqlite3=false
+      @driver_sqlite3=true if @conn.inspect.match(/^(.{10})/)[1] == @db.sqlite.conn_sqlite3.inspect.match(/^(.{10})/)[1]
       sql='SELECT MAX(lid) FROM documents'
       begin
         @col[:lid] ||=0
-        @col[:lid]=@conn.execute( sql ) { |x| x.fetch_all.to_s.to_i }
+        @col[:lid]=if @driver_sqlite3
+          @conn.execute( sql ).join.to_i
+        else @conn.execute( sql ) { |x| x.fetch_all.to_s.to_i }
+        end
       rescue
+        puts "#{__FILE__} #{__LINE__}" if @opt.cmd =~/M/
       end
       @col[:lid] =0 if @col[:lid].nil? or @col[:lid].to_s.empty?
       sql='SELECT MAX(nid) FROM endnotes'
       begin
         @id_n ||=0
-        @id_n=@conn.execute( sql ) { |x| x.fetch_all.to_s.to_i }
+        @id_n=if @driver_sqlite3
+          @conn.execute( sql ).join.to_i
+        else
+          @id_n=@conn.execute( sql ) { |x| x.fetch_all.to_s.to_i }
+        end
       rescue
+        puts "#{__FILE__} #{__LINE__}" if @opt.cmd =~/M/
       end
       @id_n =0 if @col[:lid].nil? or @col[:lid].to_s.empty?
       @col[:lv1]=@col[:lv2]=@col[:lv3]=@col[:lv4]=@col[:lv5]=@col[:lv6]=0
@@ -113,6 +124,7 @@ module SiSU_DB_import
       tell.print_grey if @opt.cmd =~/v/
       case @sql_type
       when /sqlite/                                                    #fix logic for sqlite !
+        #sqlite watch
         #pf_db_import_transaction_open if @opt =~/M/
         db_import_metadata
         db_import_documents(@dal_array)
@@ -121,7 +133,10 @@ module SiSU_DB_import
         #@conn.commit
         #@conn.close
         #@conn.disconnect
-#sqlite watch
+        if @opt.cmd =~/M/
+          puts "\n" + @conn.inspect
+          puts "\nat #{__FILE__} #{__LINE__}"
+        end
       else
         file_exist=@conn.select_one(%{ SELECT metadata.tid FROM metadata WHERE metadata.filename ~ '#{@opt.fns}'; })
         unless file_exist
@@ -130,6 +145,10 @@ module SiSU_DB_import
           db_import_documents(@dal_array)
           db_import_urls(@dal_array,@fnm)                              #import OID on/off
           @conn.execute('COMMIT')
+          if @opt.cmd =~/[MV]/
+            puts "\n" + @conn.inspect
+            puts "\nat #{__FILE__} #{__LINE__}"
+          end
         else
           @db=SiSU_Env::Info_db.new
           puts "\n#{@cX.grey}file #{@cX.off} #{@cX.blue}#{@opt.fns}#{@cX.off} #{@cX.grey}already exists in database#{@cX.off} #{@cX.blue}#{@db.psql.db}#{@cX.off} #{@cX.brown}update instead?#{@cX.off}"
@@ -141,19 +160,19 @@ module SiSU_DB_import
       string.gsub!(/#{Mx[:br_line]}|#{Mx[:br_nl]}/,"<br />\n")
       string.gsub!(/#{Mx[:gr_o]}(?:code|alt|group|verse)(?:-end)?#{Mx[:gr_c]}/,'')
       string.gsub!(/#{Mx[:mk_o]}:name#\S+?#{Mx[:mk_c]}/,'')
-      string.gsub!(/\{\s*(\S+?\.(?:png|jpg))(?:\s+\d+x\d+)?(.+?)\}\S+/,'[image: \1] \2')
-      string.gsub!(/\{\s*(.+?)\s*\}(?:https?|file|ftp):\/\/\S+?([.,!?]?(?:\s|$))/,'\1\2')
+      string.gsub!(/#{Mx[:lnk_o]}\s*(\S+?\.(?:png|jpg))(?:\s+\d+x\d+)?(.+?)#{Mx[:lnk_c]}\S+/,'[image: \1] \2')
+      string.gsub!(/#{Mx[:lnk_o]}\s*(.+?)\s*#{Mx[:lnk_c]}(?:https?|file|ftp):\/\/\S+?([.,!?]?(?:\s|$))/,'\1\2')
     end
     def strip_markup(string) #define rules, make same as in dal clean
       string.gsub!(/#{Mx[:fa_superscript_o]}(\d+)#{Mx[:fa_superscript_c]}/,'[\1]')
       string.gsub!(/#{Mx[:pa_o]}:i[1-9]#{Mx[:pa_c]}/,'')
-      string.gsub!(/(?:&nbsp\\;)+/,' ')
+      string.gsub!(/(?:&nbsp\\;|#{Mx[:nbsp]})+/,' ')
       string.gsub!(/#{Mx[:gr_o]}T[h]?#{Mx[:tc_p]}.+?#{Mx[:gr_c]}/u,"[TABLE]\n")             #tables #CHECK should take whole table
       string.gsub!(/#{Mx[:tc_o]}#{Mx[:tc_p]}#{Mx[:tc_p]}\d+(.+)#{Mx[:tc_c]}/u,'\1')         #tables
       string.gsub!(/#{Mx[:tc_p]}#{Mx[:tc_p]}\d+#{Mx[:tc_p]}/u,' ')                          #tables
       string.gsub!(/#{Mx[:tc_p]}/u,' ')                                                     #tables tidy later
       string.gsub!(/<.+?>/,'')
-      string.gsub!(/\{.+?\.(?:png|jpg|gif).+?\}(?:https?|file|ftp)\\\:\S+ /,' [image] ') # else image names found in search
+      string.gsub!(/#{Mx[:lnk_o]}.+?\.(?:png|jpg|gif).+?#{Mx[:lnk_c]}(?:https?|file|ftp)\\\:\S+ /,' [image] ') # else image names found in search
       string.gsub!(/\s\s+/,' ')
       string.strip!
     end
@@ -172,15 +191,19 @@ module SiSU_DB_import
         sql='SELECT MAX(tid) FROM metadata'
         begin
           @@id_t ||=0
-          id_t=@conn.execute( sql ) { |x| x.fetch_all.to_s.to_i }
+          id_t=if @driver_sqlite3
+            @conn.execute( sql ).join.to_i # { |x| id_t=x.join.to_i }
+          else @conn.execute( sql ) { |x| x.fetch_all.to_s.to_i }
+          end
           @@id_t=id_t if id_t
         rescue
+          puts "#{__FILE__} #{__LINE__}" if @opt.cmd =~/M/
         end
         @@id_t =0 if @col[:lid].nil? or @col[:lid].to_s.empty?
         @@id_t+=1 #bug related, needs to be performed once at start of file, but consider moving, as, placed here it means program will fail if document header lacks 0~title
         puts %{\n#{@cX.grey}Processing file number#{@cX.off}: #{@cX.green}#{@@id_t}#{@@cX.off}} unless @opt.cmd =~/q/
       end
-      if @md.dc_title; @tp[:long_title]=@md.dc_title
+      if @md.full_title; @tp[:long_title]=@md.full_title #dc
         #sql='SELECT MAX(tid) FROM metadata'
         #id_t=@conn.execute( sql ) { |x| x.fetch_all.to_s.to_i }
         #@@id_t=id_t if id_t
@@ -192,11 +215,11 @@ module SiSU_DB_import
         special_character_escape(txt)
         @tp[:subtitle_f],@tp[:subtitle_i]='subtitle, ',"'#{txt}', "
       end
-      if @md.dc_creator; txt=@md.dc_creator
+      if @md.author; txt=@md.author #dc
         special_character_escape(txt)
         @tp[:creator_f],@tp[:creator_i]='creator, ',"'#{txt}', "
       end
-      if @md.dc_contributor; txt=@md.dc_contributor
+      if @md.contributor; txt=@md.contributor #dc
         special_character_escape(txt)
         @tp[:contributor_f],@tp[:contributor_i]='contributor, ',"'#{txt}', "
       end
@@ -208,7 +231,7 @@ module SiSU_DB_import
         special_character_escape(txt)
         @tp[:illustrator_f],@tp[:illustrator_i]='illustrator, ',"'#{txt}', "
       end
-      if @md.dc_publisher; txt=@md.dc_publisher
+      if @md.publisher; txt=@md.publisher #dc
         special_character_escape(txt)
         @tp[:publisher_f],@tp[:publisher_i]='publisher, ',"'#{txt}', "
       end
@@ -220,11 +243,11 @@ module SiSU_DB_import
         special_character_escape(txt)
         @tp[:digitized_by_f],@tp[:digitized_by_i]='digitized_by, ',"'#{txt}', "
       end
-      if @md.dc_subject; txt=@md.dc_subject
+      if @md.subject; txt=@md.subject #dc
         special_character_escape(txt)
         @tp[:subject_f],@tp[:subject_i]='subject, ',"'#{txt}', "
       end
-      if @md.dc_description; txt=@md.dc_description
+      if @md.description; txt=@md.description #dc
         special_character_escape(txt)
         @tp[:description_f],@tp[:description_i]='description, ',"'#{txt}', "
       end
@@ -232,7 +255,7 @@ module SiSU_DB_import
         special_character_escape(txt)
         @tp[:abstract_f],@tp[:abstract_i]='abstract, ',"'#{txt}', "
       end
-      if @md.dc_type; txt=@md.dc_type
+      if @md.type; txt=@md.type #dc
         special_character_escape(txt)
         @tp[:type_f],@tp[:type_i]='type, ',"'#{txt}', "
       end
@@ -244,35 +267,35 @@ module SiSU_DB_import
       #  special_character_escape(txt)
       #  @tp[:copyright_f],@tp[:copyright_i]='copyright, ',"'#{txt}', "
       #end
-      if @md.dc_rights; txt=@md.dc_rights
+      if @md.rights; txt=@md.rights #dc
         special_character_escape(txt)
         @tp[:rights_f],@tp[:rights_i]='rights, ',"'#{txt}', "
       end
-      if @md.dc_date; txt=@md.dc_date
+      if @md.date; txt=@md.date #dc
         special_character_escape(txt)
         @tp[:date_f],@tp[:date_i]='date, ',"'#{txt}', "
       end
-      if @md.dc_date_created; txt=@md.dc_date_created
+      if @md.date_created; txt=@md.date_created #dc
         special_character_escape(txt)
         @tp[:date_created_f],@tp[:date_created_i]='date_created, ',"'#{txt}', "
       end
-      if @md.dc_date_issued; txt=@md.dc_date_issued
+      if @md.date_issued; txt=@md.date_issued #dc
         special_character_escape(txt)
         @tp[:date_issued_f],@tp[:date_issued_i]='date_issued, ',"'#{txt}', "
       end
-      if @md.dc_date_available; txt=@md.dc_date_available
+      if @md.date_available; txt=@md.date_available #dc
         special_character_escape(txt)
         @tp[:date_available_f],@tp[:date_available_i]='date_available, ',"'#{txt}', "
       end
-      if @md.dc_date_modified; txt=@md.dc_date_modified
+      if @md.date_modified; txt=@md.date_modified #dc
         special_character_escape(txt)
         @tp[:date_modified_f],@tp[:date_modified_i]='date_modified, ',"'#{txt}', "
       end
-      if @md.dc_date_valid; txt=@md.dc_date_valid
+      if @md.date_valid; txt=@md.date_valid #dc
         special_character_escape(txt)
         @tp[:date_valid_f],@tp[:date_valid_i]='date_valid, ',"'#{txt}', "
       end
-      if @md.dc_language[:name]; txt=@md.dc_language[:name]
+      if @md.language[:name]; txt=@md.language[:name] #dc
         special_character_escape(txt)
         @tp[:language_f],@tp[:language_i]='language, ',"'#{txt}', "
       end
@@ -280,23 +303,23 @@ module SiSU_DB_import
         special_character_escape(txt)
         @tp[:language_original_f],@tp[:language_original_i]='language_original, ',"'#{txt}', "
       end
-      if @md.dc_format; txt=@md.dc_format
+      if @md.format; txt=@md.format #dc
         special_character_escape(txt)
         @tp[:format_f],@tp[:format_i]='format, ',"'#{txt}', "
       end
-      if @md.dc_identifier; txt=@md.dc_identifier
+      if @md.identifier; txt=@md.identifier #dc
         special_character_escape(txt)
         @tp[:identifier_f],@tp[:identifier_i]='identifier, ',"'#{txt}', "
       end
-      if @md.dc_source; txt=@md.dc_source
+      if @md.source; txt=@md.source #dc
         special_character_escape(txt)
         @tp[:source_f],@tp[:source_i]='source, ',"'#{txt}', "
       end
-      if @md.dc_relation; txt=@md.dc_relation
+      if @md.relation; txt=@md.relation #dc
         special_character_escape(txt)
         @tp[:relation_f],@tp[:relation_i]='relation, ',"'#{txt}', "
       end
-      if @md.dc_coverage; txt=@md.dc_coverage
+      if @md.coverage; txt=@md.coverage #dc
         special_character_escape(txt)
         @tp[:coverage_f],@tp[:coverage_i]='coverage, ',"'#{txt}', "
       end
@@ -402,7 +425,8 @@ module SiSU_DB_import
                 end
                 txt=endnotes(txt).clean_text
               end
-              @col[:body]=SiSU_Format_Shared::CSS_Format.new(@md,txt,@col).lev4_minus
+              txt_obj={:txt =>txt,:col =>@col}
+              @col[:body]=SiSU_Format_Shared::CSS_Format.new(@md,txt_obj).lev4_minus
               special_character_escape(@col[:body])
               @col[:plaintext]=@col[:body].dup
               strip_markup(@col[:plaintext])
@@ -443,7 +467,8 @@ module SiSU_DB_import
                 end
                 txt=endnotes(txt).clean_text(@base_url)
               end
-              @col[:body]=SiSU_Format_Shared::CSS_Format.new(@md,txt,@col).lev4_plus
+              txt_obj={:txt =>txt,:col =>@col}
+              @col[:body]=SiSU_Format_Shared::CSS_Format.new(@md,txt_obj).lev4_plus
               special_character_escape(@col[:body])
               @col[:plaintext]=@col[:body].dup
               strip_markup(@col[:plaintext])
@@ -482,7 +507,8 @@ module SiSU_DB_import
                 end
                 txt=endnotes(txt).clean_text(@base_url)
               end
-              @col[:body]=SiSU_Format_Shared::CSS_Format.new(@md,txt,@col).lev4_plus
+              txt_obj={:txt =>txt,:col =>@col}
+              @col[:body]=SiSU_Format_Shared::CSS_Format.new(@md,txt_obj).lev4_plus
               special_character_escape(@col[:body])
               @col[:plaintext]=@col[:body].dup
               strip_markup(@col[:plaintext])
@@ -521,7 +547,8 @@ module SiSU_DB_import
                 end
                 txt=endnotes(txt).clean_text(@base_url)
               end
-              @col[:body]=SiSU_Format_Shared::CSS_Format.new(@md,txt,@col).lev4_plus
+              txt_obj={:txt =>txt,:col =>@col}
+              @col[:body]=SiSU_Format_Shared::CSS_Format.new(@md,txt_obj).lev4_plus
               special_character_escape(@col[:body])
               @col[:plaintext]=@col[:body].dup
               strip_markup(@col[:plaintext])
@@ -570,11 +597,14 @@ module SiSU_DB_import
               if @en_pls[0]; @en_a_plus,@en_z_plus=@en_pls[0].first,@en_pls[0].last
               end
               @col[:body]=if txt=~/#{Mx[:gr_o]}T[h]?#{Mx[:tc_p]}.+?#{Mx[:tc_p]}~\d+;\w\d+;\w\d+#{Mx[:gr_c]}/ #watch
-                SiSU_Format_Shared::CSS_Format.new(@md,txt,@col).html_table
+                txt_obj={:txt =>txt,:col =>@col}
+                SiSU_Format_Shared::CSS_Format.new(@md,txt_obj).html_table
               elsif txt=~/^#{Mx[:pa_o]}:i([1-9])#{Mx[:pa_c]}/
-                SiSU_Format_Shared::CSS_Format.new(@md,txt,@col).indent($1)
+                txt_obj={:txt =>txt,:col =>@col}
+                SiSU_Format_Shared::CSS_Format.new(@md,txt_obj).indent($1)
               else
-                SiSU_Format_Shared::CSS_Format.new(@md,txt,@col).norm
+                txt_obj={:txt =>txt,:col =>@col}
+                SiSU_Format_Shared::CSS_Format.new(@md,txt_obj).norm
               end
               special_character_escape(@col[:body])
               @col[:plaintext]=@col[:body].dup
@@ -593,7 +623,8 @@ module SiSU_DB_import
                     nr,txt,digest_clean=$1,$2,$3
                   end
                   @id_n+=1
-                  body=SiSU_Format_Shared::CSS_Format.new(@md,txt,@col,nr).endnote
+                  txt_obj={:txt =>txt,:col =>@col,:endnote_nr =>nr}
+                  body=SiSU_Format_Shared::CSS_Format.new(@md,txt_obj).endnote
                   special_character_escape(body)
                   special_character_escape(txt)
                   strip_markup(txt)
@@ -633,7 +664,8 @@ module SiSU_DB_import
                     nr,txt,digest_clean=$1,$2,$3
                   end
                   @id_n+=1
-                  body=SiSU_Format_Shared::CSS_Format.new(@md,txt,@col,nr).endnote
+                  txt_obj={:txt =>txt,:col =>@col,:endnote_nr =>nr}
+                  body=SiSU_Format_Shared::CSS_Format.new(@md,txt_obj).endnote
                   special_character_escape(body)
                   special_character_escape(txt)
                   strip_markup(txt)
@@ -674,7 +706,8 @@ module SiSU_DB_import
                     nr,txt,digest_clean=$1,$2,$3
                   end
                   @id_n+=1
-                  body=SiSU_Format_Shared::CSS_Format.new(@md,txt,@col,nr).endnote
+                  txt_obj={:txt =>txt,:col =>@col,:endnote_nr =>nr}
+                  body=SiSU_Format_Shared::CSS_Format.new(@md,txt_obj).endnote
                   special_character_escape(body)
                   special_character_escape(txt)
                   strip_markup(txt)
