@@ -14,8 +14,7 @@
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -65,8 +64,8 @@ module SiSU_HTML
   require "#{SiSU_lib}/defaults"
   include SiSU_Viz
   require "#{SiSU_lib}/html_table"
-  require "#{SiSU_lib}/html_format_css"
-  include SiSU_HTML_Format_type
+  require "#{SiSU_lib}/html_format"
+  include SiSU_HTML_Format
   require "#{SiSU_lib}/html_segments"
   require "#{SiSU_lib}/html_scroll"
   include SiSU_HTML_seg
@@ -106,7 +105,7 @@ module SiSU_HTML
         toc=SiSU_HTML::Source::Toc.new(data,@md).songsheet
         links_guide=SiSU_HTML::Source::Links_guide.new(data,@md).toc
         data=@tuned_file_array
-        scr_toc=SiSU_HTML::Source::Scroll_head_and_segtoc.new(data,@md,toc,links_guide).in_common #watch
+        scr_toc=SiSU_HTML::Source::Scroll_head_and_segtoc.new(@md,toc,links_guide).in_common #watch
         SiSU_HTML::Source::Seg.new(data,@md).songsheet
         data=@tuned_file_array
         scr=SiSU_HTML::Source::Scroll.new(data,@md).songsheet
@@ -155,7 +154,7 @@ module SiSU_HTML
       def tuned_file_instructions
         @tell=SiSU_Screen::Ansi.new(@md.cmd)
         if @md
-          @md.sfx=''
+          #@md.sfx=''
           @md.sfx='' if @md.cmd =~/z/
           if @md.cmd =~/h/ \
           or @md.fns =~/\~[a-z]{2,3}\.s?/ #multilingual document protection is a bit arbitrary, (needed by existing server configuration), add configuration overide...
@@ -173,9 +172,6 @@ module SiSU_HTML
         @md.file_type='html' if @md.cmd =~/[hon]/
         directories
         newfilename=%{#{@env.path.output}/#{@md.fnb}/#{@md.fn[:index]}} if @md.file_type =~/html/
-        my_make_source_file=SiSU_Env::Create_file.new(@md.cmd,@md.fns)
-        @fnm=my_make_source_file.marshal_meta
-        @tune_verse_marshal=my_make_source_file.marshal_tune
         dal_array=@particulars.dal_array # dal file drawn here
         @tuned_file_array=SiSU_Tune::Tune.new(dal_array,@md).songsheet
         @tuned_file_array
@@ -190,7 +186,7 @@ module SiSU_HTML
       end
       def toc
         @links_guide_toc=[]
-        format_head_toc=SiSU_HTML_Format_type::Head_toc.new(@md)
+        format_head_toc=SiSU_HTML_Format::Head_toc.new(@md)
         guide_type='horzontal' #values: horizontal or vertical
         @links_guide_toc << format_head_toc.links_guide_open(guide_type)
         if defined? @md.lnk \
@@ -201,24 +197,25 @@ module SiSU_HTML
               else                              '_top'
               end
               s_lnk_url,s_lnk_lnk=l[:url],l[:say]
-              lev_para_ocn=SiSU_HTML_Format_type::Format_toc.new(@md,s_lnk_url,s_lnk_lnk,target)
+              txt_obj={:lnk_url =>s_lnk_url,:lnk_txt =>s_lnk_lnk,:target =>target}
+              lev_para_ocn=SiSU_HTML_Format::Format_toc.new(@md,txt_obj)
               @links_guide_toc << lev_para_ocn.links_guide if s_lnk_lnk
             end
           end
         end
-        format_head_toc=SiSU_HTML_Format_type::Head_toc.new(@md)
+        format_head_toc=SiSU_HTML_Format::Head_toc.new(@md)
         @links_guide_toc << format_head_toc.links_guide_close #(guide_type)
         @links_guide_toc
       end
     end
     class Endnotes
-      include SiSU_HTML_Format_type
+      include SiSU_HTML_Format
       def initialize(data,md)
         @data,@md=data,md
       end
       def scroll
         @scr_endnotes=[]
-        format_head_scroll=SiSU_HTML_Format_type::Head_scroll.new(@md)
+        format_head_scroll=SiSU_HTML_Format::Head_scroll.new(@md)
         @scr_endnotes << format_head_scroll.title_endnote
         @data.each do |para|
           pg=para.dup
@@ -236,7 +233,8 @@ module SiSU_HTML
                 endnote_array << pg.scan(/#{Mx[:en_b_o]}[\d+]+(.+?)#{Mx[:en_b_c]}/m)
               end
               endnote_array.flatten.each do |note|
-                format_scroll=SiSU_HTML_Format_type::Format_scroll.new(@md,note)
+                txt_obj={:txt =>note}
+                format_scroll=SiSU_HTML_Format::Format_scroll.new(@md,txt_obj)
                 @scr_endnotes << format_scroll.endnote_body
               end
             end
@@ -246,7 +244,7 @@ module SiSU_HTML
       end
     end
     class Toc <Links_guide
-      @@toc={ :seg=>[],:scr=>[] }
+      @@toc={ :seg=>[],:seg_mini=>[],:scr=>[] }
       @@seg_url=''
       @@dp,@@firstseg=nil,nil
       def initialize(data='',md=nil)
@@ -255,12 +253,13 @@ module SiSU_HTML
         @dp=@@dp ||=SiSU_Env::Info_env.new.digest.pattern
         @pat_heading=/^(?:#{Mx[:lv_o]}[1-6]:\S*?#{Mx[:lv_c]}\s*)?(.*)#{Mx[:id_o]}~(\d+);(?:[hm]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/
         @pat_strip_heading_name=/<a name="h?\d.*?">(.+?)<\/a>/
-        @tell=SiSU_Screen::Ansi.new(@md.cmd)
+        @tell=SiSU_Screen::Ansi.new(@md.cmd) if @md
       end
       def songsheet #extracts toc for scroll & seg
         SiSU_Screen::Ansi.new(@md.cmd,'Toc').txt_grey unless @md.cmd =~/q/
         toc=nil
         @@firstseg=nil
+        @@toc={ :seg=>[],:seg_mini=>[],:scr=>[] }
         @data.each do |para|
           if para =~/^(?:#{Mx[:lv_o]}[1-6]:|4~!)/
             para_toc=para.dup
@@ -272,7 +271,7 @@ module SiSU_HTML
             when /^\s*#{Mx[:lv_o]}4:\S+/; Toc.new(para_toc,@md).level_4
             when /^\s*#{Mx[:lv_o]}5:\S*/; Toc.new(para_toc,@md).level_5
             when /^\s*#{Mx[:lv_o]}6:\S*/; Toc.new(para_toc,@md).level_6
-            when /^\s*4~!/;      Toc.new(para_toc).level_crosslink
+            when /^\s*4~!/;               Toc.new(para_toc).level_crosslink
             else
             end
             if @@firstseg.nil? \
@@ -282,6 +281,7 @@ module SiSU_HTML
             if toc
               begin
                 @@toc[:seg] << toc[:seg] if toc[:seg]
+                @@toc[:seg_mini] << toc[:seg_mini] if toc[:seg_mini]
                 @@toc[:scr] << toc[:scr] if toc[:scr]
               rescue; SiSU_Errors::Info_error.new($!,$@,@md.cmd,@md.fns).error
               end
@@ -291,6 +291,10 @@ module SiSU_HTML
         @md.firstseg=@@firstseg
         @@toc
       end
+      def minitoc
+        minitoc=@@toc[:seg_mini].join("\n")
+        '<div class="toc">' + minitoc + '</div>'
+      end
     protected
       def rss #sort all wrong, disabled but kept
         @@toc[:seg] <<<<WOK
@@ -308,26 +312,34 @@ WOK
       end
       def level_doc_owner_details
         if @md.stmp =~/\w\w/
-          format_head_scroll=SiSU_HTML_Format_type::Head_scroll.new(@md)
+          format_head_scroll=SiSU_HTML_Format::Head_scroll.new(@md)
           @@toc[:scr] << format_head_scroll.toc_owner_details
         end
       end
+#not used -->
       def level_endnotes
         if @md.flag_endnotes
-          format_head_scroll=SiSU_HTML_Format_type::Head_scroll.new(@md)
+          format_head_scroll=SiSU_HTML_Format::Head_scroll.new(@md)
           @@toc[:scr] << format_head_scroll.toc_endnote
         end
       end
+      def level_concordance
+        format_head_toc=SiSU_HTML_Format::Head_toc.new(@md)
+        @@toc[:seg_mini] << format_head_toc.mini_seg_concordance
+      end
       def level_metadata
-        format_head_toc=SiSU_HTML_Format_type::Head_toc.new(@md)
+        format_head_toc=SiSU_HTML_Format::Head_toc.new(@md)
         @@toc[:scr] << format_head_toc.metadata
         @@toc[:seg] << format_head_toc.seg_metadata
+        @@toc[:seg_mini] << format_head_toc.mini_seg_metadata
       end
       def level_word_index
-        format_head_toc=SiSU_HTML_Format_type::Head_toc.new(@d0c)
+        format_head_toc=SiSU_HTML_Format::Head_toc.new(@d0c)
         @@toc[:scr] << format_head_toc.concordance
         @@toc[:seg] << format_head_toc.concordance
+        @@toc[:seg_mini] << format_head_toc.mini_concordance
       end
+# <-- not used
       def level_1
         para=@data
         unless para =~/#{Mx[:id_o]}~0;(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/
@@ -337,7 +349,7 @@ WOK
         linkname,link=$1.strip,$2 if $&
           if link \
           and link !~/#/ #% keep eye on link
-            p_num=SiSU_HTML_Format_type::Paragraph_number.new(@md,link)
+            p_num=SiSU_HTML_Format::Paragraph_number.new(@md,link)
           end
           title=unless para =~/Document Information/; linkname
         else
@@ -345,11 +357,19 @@ WOK
           %{<b><a href="#{@md.fnl[:pre]}#{link}#{@md.fnl[:mid]}#{@md.sfx}#{@md.fnl[:post]}">#{linkname}</a></b>}
         end
         toc={}
-        format_toc=SiSU_HTML_Format_type::Format_toc.new(@md,title)
+        txt_obj={:txt =>title}
+        format_toc=SiSU_HTML_Format::Format_toc.new(@md,txt_obj)
         toc[:seg]=if para =~/^#{Mx[:lv_o]}\d:meta^#{Mx[:lv_c]}\s*Document Information/
           format_toc.lev0
         else format_toc.lev1
         end
+        toc[:seg_mini]=if para =~/^#{Mx[:lv_o]}\d:meta#{Mx[:lv_c]}\s*Document Information/
+          x=if @md.concord_make
+            format_toc.mini_concord_tail
+          else format_toc.mini_tail
+          end
+        else format_toc.mini_lev1
+        end
         title=if para =~/(#{Mx[:id_o]}~0;(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]})$/
           m=/#{$1}/
           para.gsub!(m,'')
@@ -364,7 +384,8 @@ WOK
           end
           %{<b><a href="##{link}">#{linkname}</a></b>}
         end
-        format_toc=SiSU_HTML_Format_type::Format_toc.new(@md,title)
+        txt_obj={:txt =>title}
+        format_toc=SiSU_HTML_Format::Format_toc.new(@md,txt_obj)
         toc[:scr]=if para =~/^#{Mx[:lv_o]}\d:meta^#{Mx[:lv_c]}\s*Document Information/
           format_toc.lev0
         else format_toc.lev1
@@ -377,21 +398,24 @@ WOK
           para.gsub!(@pat_strip_heading_name,'\1')
         end
         para[@pat_heading]
-        linkname,link=$1.strip,$2 if $&
-        if link \
-        and link !~/#/
-          p_num=SiSU_HTML_Format_type::Paragraph_number.new(@md,link)
+        linkname,ocn=$1.strip,$2 if $&
+        if ocn \
+        and ocn !~/#/
+          p_num=SiSU_HTML_Format::Paragraph_number.new(@md,ocn)
         end
-        format_toc=SiSU_HTML_Format_type::Format_toc.new(@md,linkname)
+        txt_obj={:txt =>linkname}
+        format_toc=SiSU_HTML_Format::Format_toc.new(@md,txt_obj)
         toc={}
         toc[:seg]=format_toc.lev2
+        toc[:seg_mini]=format_toc.mini_lev2
         if para =~/(#{Mx[:id_o]}~0;(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]})$/
           m=/#{$1}/
           para.gsub!(m,'')
           title=linkname
         else title=%{#{p_num.goto}#{linkname}</a>}
         end
-        format_toc=SiSU_HTML_Format_type::Format_toc.new(@md,title)
+        txt_obj={:txt =>title}
+        format_toc=SiSU_HTML_Format::Format_toc.new(@md,txt_obj)
         toc[:scr]=format_toc.lev2
         toc
       end
@@ -400,21 +424,24 @@ WOK
         para.gsub!(@pat_strip_heading_name,'\1')
         para.gsub(/(.*?)<a name="(\d+)"><\/a>(.*)/,'\1') #2002w42 altered gsub! - problematic? - suspect
         para[@pat_heading]
-        linkname,link=$1.strip,$2 if $&
-        if link \
-        and link !~/#/
-          p_num=SiSU_HTML_Format_type::Paragraph_number.new(@md,link)
+        linkname,ocn=$1.strip,$2 if $&
+        if ocn \
+        and ocn !~/#/
+          p_num=SiSU_HTML_Format::Paragraph_number.new(@md,ocn)
         end
-        format_toc=SiSU_HTML_Format_type::Format_toc.new(@md,linkname)
+        txt_obj={:txt =>linkname}
+        format_toc=SiSU_HTML_Format::Format_toc.new(@md,txt_obj)
         toc={}
         toc[:seg]=format_toc.lev3
+        toc[:seg_mini]=format_toc.mini_lev3
         if para =~/(#{Mx[:id_o]}~0;(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]})$/
           m=/#{$1}/
           para.gsub!(m,'')
           title=linkname
         else title=%{#{p_num.goto}#{linkname}</a>}
         end
-        format_toc=SiSU_HTML_Format_type::Format_toc.new(@md,title)
+        txt_obj={:txt =>title}
+        format_toc=SiSU_HTML_Format::Format_toc.new(@md,txt_obj)
         toc[:scr]=format_toc.lev3
         toc
       end
@@ -424,8 +451,8 @@ WOK
           unless para =~/#{Mx[:id_o]}~0;(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/
             para.gsub!(@pat_strip_heading_name,'\1')
             para[@pat_heading]
-            linkname,link=$1.strip,$2 if $&
-            p_num=SiSU_HTML_Format_type::Paragraph_number.new(@md,link) if link
+            linkname,ocn=$1.strip,$2 if $&
+            p_num=SiSU_HTML_Format::Paragraph_number.new(@md,ocn) if ocn
           end
           para.gsub!(/#{Mx[:id_o]}~0;(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/,'')
           if para =~/^#{Mx[:lv_o]}4:/
@@ -433,23 +460,30 @@ WOK
               %{  <a href="#{@md.fnl[:pre]}\\1#{@md.fnl[:mid]}#{@md.sfx}#{@md.fnl[:post]}" target="_top">
     \\2
   </a> })
+            if seg_link =~/(#{Mx[:id_o]}\~\d+;(?:\w|[0-6]:\d+);\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]})$/m
+              m=/#{$1}/m
+              seg_link.gsub!(m,'')
+            end
             @@seg_url=para[/^#{Mx[:lv_o]}4:(\S+?)#{Mx[:lv_c]}.+?$/,1]
           elsif para =~/\d+.\d+.\d+.\d+|\d+.\d+.\d+|\d+.\d+|\d+/
             seg_link=para.gsub(/^\s*(#{@md.lv4}\s+)\s*(\d+.\d+.\d+.\d+|\d+.\d+.\d+|\d+.\d+|\d+)(.*)/,
               %{<a href="#{@md.fnl[:pre]}\\2#{@md.fnl[:mid]}#{@md.sfx}#{@md.fnl[:post]}" } +
               %{target="_top">\\1 \\2 \\3</a> })
           end
-          p_num=SiSU_HTML_Format_type::Paragraph_number.new(@md,link) if link
-          format_toc=SiSU_HTML_Format_type::Format_toc.new(@md,seg_link)
+          p_num=SiSU_HTML_Format::Paragraph_number.new(@md,ocn) if ocn
+          txt_obj={:txt =>seg_link}
+          format_toc=SiSU_HTML_Format::Format_toc.new(@md,txt_obj)
           toc={}
           toc[:seg]=format_toc.lev4
+          toc[:seg_mini]=format_toc.mini_lev4
           if para =~/#{Mx[:id_o]}~0;(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/
             m=/#{$1}/
             para.gsub!(m,'')
             title=linkname
           else title=%{#{p_num.goto}#{linkname}</a>} if p_num
           end
-          format_toc=SiSU_HTML_Format_type::Format_toc.new(@md,title)
+          txt_obj={:txt =>title}
+          format_toc=SiSU_HTML_Format::Format_toc.new(@md,txt_obj)
           toc[:scr]=format_toc.lev4
           toc
         end
@@ -460,10 +494,10 @@ WOK
           para.gsub!(@pat_strip_heading_name,'\1')
         end
         para[@pat_heading]
-        linkname,link=$1.strip,$2 if $&
-        if link \
-        and link !~/#/
-          p_num=SiSU_HTML_Format_type::Paragraph_number.new(@md,link)
+        linkname,ocn=$1.strip,$2 if $&
+        if ocn \
+        and ocn !~/#/
+          p_num=SiSU_HTML_Format::Paragraph_number.new(@md,ocn)
         end
         toc={}
         if para =~/#{Mx[:id_o]}~0;(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/
@@ -471,14 +505,17 @@ WOK
           para.gsub!(m,'')
           title=linkname
         else
-          lnk_n_txt=%{  <a href="#{@md.fnl[:pre]}#{@@seg_url}#{@md.fnl[:mid]}#{@md.sfx}#{@md.fnl[:post]}##{link}">
+          lnk_n_txt=%{  <a href="#{@md.fnl[:pre]}#{@@seg_url}#{@md.fnl[:mid]}#{@md.sfx}#{@md.fnl[:post]}##{ocn}">
     #{linkname}
   </a>}
-          format_toc=SiSU_HTML_Format_type::Format_toc.new(@md,lnk_n_txt)
+          txt_obj={:txt =>lnk_n_txt}
+          format_toc=SiSU_HTML_Format::Format_toc.new(@md,txt_obj)
           toc[:seg]=format_toc.lev5
+          toc[:seg_mini]=format_toc.mini_lev5
           title=%{#{p_num.goto}#{linkname}</a>}
         end
-        format_toc=SiSU_HTML_Format_type::Format_toc.new(@md,title)
+        txt_obj={:txt =>title}
+        format_toc=SiSU_HTML_Format::Format_toc.new(@md,txt_obj)
         toc[:scr]=format_toc.lev5
         toc
       end
@@ -488,10 +525,10 @@ WOK
           para.gsub!(@pat_strip_heading_name,'\1')
         end
         para[@pat_heading]
-        linkname,link=$1.strip,$2 if $&
-        if link \
-        and link !~/#/
-          p_num=SiSU_HTML_Format_type::Paragraph_number.new(@md,link)
+        linkname,ocn=$1.strip,$2 if $&
+        if ocn \
+        and ocn !~/#/
+          p_num=SiSU_HTML_Format::Paragraph_number.new(@md,ocn)
         end
         toc={}
         if para =~/#{Mx[:id_o]}~0;(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/
@@ -499,14 +536,17 @@ WOK
           para.gsub!(m,'')
           title=linkname
         else
-          lnk_n_txt=%{  <a href="#{@md.fnl[:pre]}#{@@seg_url}#{@md.fnl[:mid]}#{@md.sfx}#{@md.fnl[:post]}##{link}">
+          lnk_n_txt=%{  <a href="#{@md.fnl[:pre]}#{@@seg_url}#{@md.fnl[:mid]}#{@md.sfx}#{@md.fnl[:post]}##{ocn}">
     #{linkname}
   </a>}
-          format_toc=SiSU_HTML_Format_type::Format_toc.new(@md,lnk_n_txt)
+          txt_obj={:txt =>lnk_n_txt}
+          format_toc=SiSU_HTML_Format::Format_toc.new(@md,txt_obj)
           toc[:seg]=format_toc.lev6
+          toc[:seg_mini]=format_toc.mini_lev6
           title=%{#{p_num.goto}#{linkname}</a>}
         end
-        format_toc=SiSU_HTML_Format_type::Format_toc.new(@md,title)
+        txt_obj={:txt =>title}
+        format_toc=SiSU_HTML_Format::Format_toc.new(@md,txt_obj)
         toc[:scr]=format_toc.lev6
         toc
       end
@@ -535,24 +575,24 @@ WOK
       end
     end
     class Scroll_head_and_segtoc < Toc
-      def initialize(data,md='',toc='',links_guide_toc='')
-        @data,@md,@toc,@links_guide_toc=data,md,toc,links_guide_toc
+      def initialize(md='',toc='',links_guide_toc='')
+        @md,@toc,@links_guide_toc=md,toc,links_guide_toc
         @vz=SiSU_Env::Get_init.instance.skin
       end
       def in_common
         toc_shared=[]
         @segtoc=[]
         SiSU_Screen::Ansi.new(@md.cmd,'Scroll & Segtoc').txt_grey unless @md.cmd =~/q/
-        format_head_toc=SiSU_HTML_Format_type::Head_toc.new(@md)
+        format_head_toc=SiSU_HTML_Format::Head_toc.new(@md)
         dochead=format_head_toc.head
         dochead.gsub!(/toc\.(html)/,'doc.\1') #kludge
         ads=SiSU_HTML_promo::Ad.new(@md)
         toc_shared << dochead << ads.div.major
         @segtoc << format_head_toc.head << ads.div.major
-        toc_shared << format_head_toc.toc_head_escript if SiSU_HTML_Format_type::Head_toc.method_defined? :toc_head_escript
-        @segtoc << format_head_toc.toc_head_escript if SiSU_HTML_Format_type::Head_toc.method_defined? :toc_head_escript
+        toc_shared << format_head_toc.toc_head_escript if SiSU_HTML_Format::Head_toc.method_defined? :toc_head_escript
+        @segtoc << format_head_toc.toc_head_escript if SiSU_HTML_Format::Head_toc.method_defined? :toc_head_escript
         toc_shared << format_head_toc.scroll_head_navigation_band
-        if @md.dc_rights
+        if @md.rights
           rights=format_head_toc.rights
           rights=SiSU_Tune::Clean_html.new(rights).clean
         end
@@ -561,26 +601,30 @@ WOK
           prefix_b=SiSU_Tune::Clean_html.new(prefix_b).clean
         end
         @seg_toc_band=format_head_toc.seg_head_navigation_band('pdf') #bug, vary depending on type of doc !! examine
+        @seg_toc_band_bottom=format_head_toc.seg_head_navigation_band_bottom('pdf') #bug, vary depending on type of doc !! examine
         @segtoc << @seg_toc_band
         toc_shared << format_head_toc.scroll_head_title_banner_open
         @segtoc << format_head_toc.seg_head_title_banner_open
         tmp_head=nil
         doc_title_endnote=@md.title.gsub(/(\*+)/,'<sup><a href="#endnotes">\1</a></sup>')
         tmp_head=doc_title_endnote + "\n"
-        format_txt_obj=SiSU_HTML_Format_type::Format_text_object.new(@md,tmp_head)
+        txt_obj={:txt =>tmp_head}
+        format_txt_obj=SiSU_HTML_Format::Format_text_object.new(@md,txt_obj)
         toc_shared << format_txt_obj.center_bold
         @segtoc << format_txt_obj.center_bold
         if not @md.subtitle.nil? \
         and not @md.subtitle.empty?
           tmp_head=@md.subtitle + "\n"
-          format_txt_obj=SiSU_HTML_Format_type::Format_text_object.new(@md,tmp_head)
+          txt_obj={:txt=>tmp_head}
+          format_txt_obj=SiSU_HTML_Format::Format_text_object.new(@md,txt_obj)
           toc_shared << format_txt_obj.center_bold
           @segtoc << format_txt_obj.center_bold
         end
-        if @md.dc_creator
-          creator_endnote=@md.dc_creator.gsub(/(\*+)/,%{&nbsp;<sup><a href="#notes">\\1</a></sup>})
+        if @md.author
+          creator_endnote=@md.author.gsub(/(\*+)/,%{&nbsp;<sup><a href="#notes">\\1</a></sup>})
           tmp_head=creator_endnote + "\n"
-          format_txt_obj=SiSU_HTML_Format_type::Format_text_object.new(@md,tmp_head)
+          txt_obj={:txt =>tmp_head}
+          format_txt_obj=SiSU_HTML_Format::Format_text_object.new(@md,txt_obj)
           toc_shared << format_txt_obj.center_bold
           @segtoc << format_txt_obj.center_bold
         end
@@ -596,17 +640,17 @@ WOK
         end
         tmp_head=nil
         toc_shared << @links_guide_toc
-        toc_shared << rights if @md.dc_rights
+        toc_shared << rights if @md.rights
         toc_shared << prefix_b if @md.prefix_b
         #Table of Contents added/appended here
         toc_shared << @toc[:scr]
         @segtoc << @links_guide_toc
         @segtoc << @toc[:seg]
-        @segtoc << rights if @md.dc_rights
+        @segtoc << rights if @md.rights
         @segtoc << prefix_b if @md.prefix_b
         #Segtoc tail added here
         @segtoc << "</p>\n" #bugfix sort later DEBUGNOW
-        @segtoc << @seg_toc_band
+        @segtoc << @seg_toc_band_bottom
         ads=SiSU_HTML_promo::Ad.new(@md)
         @segtoc << format_head_toc.seg_navigation_tail << ads.div.close << ads.display << format_head_toc.html_close
         @segtoc.flatten!.compact!
