@@ -14,8 +14,7 @@
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -62,14 +61,53 @@ module SiSU_HTML_seg
   require "#{SiSU_lib}/shared_html"
   require "#{SiSU_lib}/html"
   require "#{SiSU_lib}/html_promo"
+  class Seg_output
+    def initialize(md,outputfile,seg,minitoc,type='')
+      @md,@output_seg_file,@seg,@minitoc,@type=md,outputfile,seg,minitoc,type
+    end
+    def output #CONSIDER
+      if @seg[:title] =~/\S/
+        filename_seg=[]
+        filename_seg << @seg[:title] << @seg[:tocband_banner]
+        if @type =~/endnote/
+          @seg[:headers]=[]
+          format_head_seg=SiSU_HTML_Format::Head_seg.new(@md)
+          @seg[:headers] << format_head_seg.title_banner(@md.title,@md.subtitle,@author)
+          txt_obj={:txt =>'Endnotes',:ocn_display =>''}
+          format_seg=SiSU_HTML_Format::Format_seg.new(@md,txt_obj)
+          @seg[:headers] << format_seg.title_header1
+          filename_seg << @seg[:header_endnotes] << @minitoc << @seg[:headers] << %{\n<div class="content">\n} << @seg[:endnote_all] << '</div>' # << '</div>'
+        elsif @type =~/idx/
+          @seg[:headers]=[]
+          format_head_seg=SiSU_HTML_Format::Head_seg.new(@md)
+          @seg[:headers] << format_head_seg.title_banner(@md.title,@md.subtitle,@author)
+          txt_obj={:txt =>'Index',:ocn_display =>''}
+          format_seg=SiSU_HTML_Format::Format_seg.new(@md,txt_obj)
+          @seg[:headers] << format_seg.title_header1
+          filename_seg << @seg[:header_idx] << @minitoc << @seg[:headers] << %{\n<div class="content">\n} << @seg[:idx] << '</div>' # << '</div>'
+        else
+          filename_seg << @minitoc <<  @seg[:headers] << @seg[:main] << "\n</div>\n"
+        end
+        filename_seg << @seg[:tail] << @seg[:tocband_bannerless] << @seg[:credits]
+        filename_seg.flatten!.compact!
+        filename_seg.each do |para|
+          unless para =~/\A\s*\Z/
+            para.strip!
+            @output_seg_file << para
+          end
+        end
+        @output_seg_file.close
+      end
+    end
+  end
   class Seg
     @@seg,@@seg_subtoc,@@seg_endnotes,@@seg_ad={},{},{},{}
-    @@seg_name,@@seg_name_html,@@seg_name_php=[],[],[]
-    @@filename_seg=@@filename_segphp=@@seg_url=@@fn=@@to_lev4=@@get_hash_to=@@get_hash_fn=''
+    @@seg_name,@@seg_name_html=[],[]
+    @@seg_url=@@fn=@@to_lev4=@@get_hash_to=@@get_hash_fn=''
     @@loop_count=@@seg_total=@@tracker=0
     @@is4=@@is3=@@is2=@@is1=0
     @@header1=@@header2=@@header3=@@header4=0
-    @@seg[:tocband],@@seg[:title],@@seg[:headers],@@seg[:main],@@seg[:tail],@@seg[:credits],@@seg_subtoc_array,@@seg_endnotes_array,@@seg[:endnote_all]=Array.new(9){[]}
+    @@seg[:tocband_banner],@@seg[:tocband_bannerless],@@seg[:title],@@seg[:headers],@@seg[:main],@@seg[:idx],@@seg[:tail],@@seg[:credits],@@seg_subtoc_array,@@seg_endnotes_array,@@seg[:endnote_all]=Array.new(11){[]}
     @@seg[:header_endnotes]=''
     @@tablehead,@@number_of_cols=0,0
     @@flag_alt=false
@@ -85,6 +123,7 @@ module SiSU_HTML_seg
     end
     def songsheet
       begin
+        @minitoc=SiSU_HTML::Source::Toc.new(@data,@md).minitoc
         data=get_subtoc_endnotes(@data)
         data=articles(data)
         Seg.new.cleanup # (((( added ))))
@@ -102,6 +141,13 @@ module SiSU_HTML_seg
       @h_sfx='.php' if @md.file_type =~/php/
       @h_sfx=@md.sfx if @md.file_type =~/html/
       @h_sfx='.html' if @md.file_type =~/html/ #used in creating file, not to be omitted.
+      idx_html=nil
+      if @md.book_idx
+        my_make_source_file=SiSU_Env::Create_file.new(@md.cmd,@md.fns)
+        idx_html=SiSU_Particulars::Combined_singleton.instance.get_html_idx(@md.opt).html_idx
+        idx_html.each {|x| @@seg[:idx] << x }
+        @@seg[:header_idx]=''
+      end
       data.each do |para|
         if para =~/^#{Mx[:lv_o]}4:/
           @@seg_name << para[/^#{Mx[:lv_o]}4:(\S+?)#{Mx[:lv_c]}/,1]
@@ -140,7 +186,9 @@ module SiSU_HTML_seg
           end
         end
         if @@is4 == 1 \
-        or para =~/^#{Mx[:br_endnotes]}|^#{Mx[:br_eof]}/
+        or para =~/^#{Mx[:br_endnotes]}|^#{Mx[:br_eof]}/ \
+        or para =~/^#{Mx[:mk_o]}4:metadata#{Mx[:mk_c]}/
+          m=para[/^#{Mx[:lv_o]}4:(metadata)#{Mx[:lv_c]}/]; @@get_hash_fn=$1 if m
           if newfile == 1 \
           or para =~/^#{Mx[:br_endnotes]}|^#{Mx[:br_eof]}/
             newfile=0
@@ -150,20 +198,24 @@ module SiSU_HTML_seg
                 mkdir_p(@md.dir_out) unless FileTest.directory?(@md.dir_out) #bug - added specifically for nav! not needed by regular seg, check !!!
                 Seg.new('',@md).tail
                 segfilename="#{@md.dir_out}/#{@md.fnl[:pre]}#{@@seg_name_html[tracking-1]}#{@md.fnl[:mid]}#@h_sfx#{@md.fnl[:post]}"
-                @@filename_seg=File.new(segfilename,'w') if @@seg_name_html[tracking-1]
-                unless (@@seg_name_html[tracking-1] =~/endnotes/)
-                  Seg.new.output
-                else Seg.new.output('endnotes')
+                @output_seg_file=File.new(segfilename,'w') if @@seg_name_html[tracking-1]
+                if @@seg_name_html[tracking-1] !~/endnotes|idx/
+                  Seg_output.new(@md,@output_seg_file,@@seg,@minitoc).output
+                elsif @@seg_name_html[tracking-1] =~/endnotes/
+                  Seg_output.new(@md,@output_seg_file,@@seg,@minitoc,'endnotes').output
+                elsif @@seg_name_html[tracking-1] =~/idx/
+                  Seg_output.new(@md,@output_seg_file,@@seg,@minitoc,'idx').output
+                else p 'check'
                 end
                 Seg.new.reinitialise
                 header_art(para)
                 head(para)
                 if @@seg_name_html[tracking] =~/metadata/ # this is for metadata
                   segfilename="#{@md.dir_out}/#{@md.fnl[:pre]}#{@@seg_name_html[tracking]}#{@md.fnl[:mid]}#@h_sfx#{@md.fnl[:post]}"
-                  @@filename_seg=File.new(segfilename,'w')
-                  Seg.new.reinitialise
+                  @output_seg_file=File.new(segfilename,'w')
+                  Seg.new.reinitialise #BUG with items following endnote, and occurring before metadata, this becomes a bug ... work area for book index, FIX
                   flagend="x"
-                  @@filename_seg.close                                         #%(((( EOF )))) -->
+                  @output_seg_file.close                                         #%(((( EOF )))) -->
                 end
               end
               if  tracking == 0
@@ -192,9 +244,10 @@ module SiSU_HTML_seg
           end
         end
       end
+      data
     end
     def header_art(para)
-      format_head_seg=SiSU_HTML_Format_type::Head_seg.new(@md)
+      format_head_seg=SiSU_HTML_Format::Head_seg.new(@md)
       if para =~/^#{Mx[:lv_o]}[1-6]:/ #2004w27/5
         if @@tracker < @@seg_total-1; @@seg[:dot_nav]=format_head_seg.dot_control_pre_next
         else                          @@seg[:dot_nav]=format_head_seg.dot_control_pre
@@ -205,7 +258,7 @@ module SiSU_HTML_seg
     end
     def head(para)
       clean=/<!.*?!>|#{Mx[:gr_o]}:.*?#{Mx[:gr_c]}|<:.*?>|#{Mx[:id_o]}~\d+;(?:[ohum]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/
-      format_head_seg=SiSU_HTML_Format_type::Head_seg.new(@md)
+      format_head_seg=SiSU_HTML_Format::Head_seg.new(@md)
       if @@tracker < @@seg_total-1
         if @@tracker == 0; @@segtocband=format_head_seg.toc_next2 #if format_head_seg.toc_next2
         else               @@segtocband=format_head_seg.toc_pre_next2 #if format_head_seg.toc_pre_next2
@@ -214,58 +267,68 @@ module SiSU_HTML_seg
       end
       @p_num ||= ''
       if @@is1 == 1
-        @dc_creator=%{<b>#{@md.dc_creator}</b>\n} if @md.dc_creator.to_s =~/\S/
-        @@seg[:tocband] << format_head_seg.navigation_band(@@segtocband,@@seg[:dot_nav])
-        @@seg[:headers] << format_head_seg.seg_head_escript if SiSU_HTML_Format_type::Head_seg.method_defined? :seg_head_escript #debug PHP move up in text #bug
-        @@seg[:headers] << format_head_seg.title_banner(@md.title,@md.subtitle,@dc_creator).gsub(clean,'')
-        paranum=if @@header1[/.+?#{Mx[:id_o]}~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/]; $1
+        @author=%{<b>#{@md.author}</b>\n} if @md.author.to_s =~/\S/
+        @@seg[:tocband_banner] << format_head_seg.navigation_band(@@segtocband,@@seg[:dot_nav])
+        conditional_div_close=if @@get_hash_fn =~/metadata/ #watch
+          '</div>'
         else ''
         end
-        @p_num=SiSU_HTML_Format_type::Paragraph_number.new(@md,paranum)
-        format_seg=SiSU_HTML_Format_type::Format_seg.new(@md,@@header1,@p_num.ocn_display)
+        @@seg[:tocband_bannerless] << conditional_div_close << format_head_seg.navigation_band_bottom(@@segtocband,@@seg[:dot_nav])
+        @@seg[:headers] << format_head_seg.seg_head_escript if SiSU_HTML_Format::Head_seg.method_defined? :seg_head_escript #debug PHP move up in text #bug
+        @@seg[:headers] << format_head_seg.title_banner(@md.title,@md.subtitle,@author).gsub(clean,'')
+        ocn=if @@header1[/.+?#{Mx[:id_o]}~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/]; $1
+        else ''
+        end
+        @p_num=SiSU_HTML_Format::Paragraph_number.new(@md,ocn)
+        txt_obj={:txt =>@@header1,:ocn_display =>@p_num.ocn_display}
+        format_seg=SiSU_HTML_Format::Format_seg.new(@md,txt_obj)
         @@seg[:headers] << format_seg.title_header1.gsub(clean,'')
         @@header1.gsub!(/&nbsp;<a name="-[\d*+]+" href="#_[\d*+]+">&nbsp;<sup>[\d*+]+<\/sup>&nbsp;<\/a>/,'')
       end
       if @@is2 == 1
         header2=@@header2
-        paranum=if header2[/.+?#{Mx[:id_o]}~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/]; $1
+        ocn=if header2[/.+?#{Mx[:id_o]}~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/]; $1
         else ''
         end
-        @p_num=SiSU_HTML_Format_type::Paragraph_number.new(@md,paranum)
-        format_seg=SiSU_HTML_Format_type::Format_seg.new(@md,header2,@p_num.ocn_display)
+        @p_num=SiSU_HTML_Format::Paragraph_number.new(@md,ocn)
+        txt_obj={:txt =>header2,:ocn_display =>@p_num.ocn_display}
+        format_seg=SiSU_HTML_Format::Format_seg.new(@md,txt_obj)
         @@seg[:headers] << format_seg.title_header2.gsub(clean,'')
         @@header2.gsub!(/&nbsp;<a name="-[\d*+]+" href="#_[\d*+]+">&nbsp;<sup>[\d*+]+<\/sup>&nbsp;<\/a>/,'')
       end
       if @@is3 == 1
         header3=@@header3
-        paranum=if header3[/.+?#{Mx[:id_o]}~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/]; $1
+        ocn=if header3[/.+?#{Mx[:id_o]}~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/]; $1
         else ''
         end
-        @p_num=SiSU_HTML_Format_type::Paragraph_number.new(@md,paranum)
-        format_seg=SiSU_HTML_Format_type::Format_seg.new(@md,header3,@p_num.ocn_display)
+        @p_num=SiSU_HTML_Format::Paragraph_number.new(@md,ocn)
+        txt_obj={:txt =>header3,:ocn_display =>@p_num.ocn_display}
+        format_seg=SiSU_HTML_Format::Format_seg.new(@md,txt_obj)
         @@seg[:headers] << format_seg.title_header3.gsub(clean,'')
         @@header3.gsub!(/&nbsp;<a name="-[\d*+]+" href="#_[\d*+]+">&nbsp;<sup>[\d*+]+<\/sup>&nbsp;<\/a>/,'')
       end
       if @@is4 == 1
         header4=@@header4
-        paranum=if header4[/.+?#{Mx[:id_o]}~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/]; $1
+        ocn=if header4[/.+?#{Mx[:id_o]}~(\d+);(?:[oh]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/]; $1
         else ''
         end
-        @p_num=SiSU_HTML_Format_type::Paragraph_number.new(@md,paranum)
-        format_seg=SiSU_HTML_Format_type::Format_seg.new(@md,header4,@p_num.ocn_display)
+        @p_num=SiSU_HTML_Format::Paragraph_number.new(@md,ocn)
+        txt_obj={:txt =>header4,:ocn_display =>@p_num.ocn_display}
+        format_seg=SiSU_HTML_Format::Format_seg.new(@md,txt_obj)
         @@seg[:headers] << format_seg.title_header4.gsub(clean,'')
       end
-      @@seg[:header_endnotes]=format_head_seg.title_endnote(@md.title,@md.subtitle,@dc_creator,@@seg[:dot_nav])
+      @@seg[:header_endnotes]=format_head_seg.title_endnote(@md.title,@md.subtitle,@author,@@seg[:dot_nav])
       @@tracker=@@tracker+1
     end
     def markup(para)
       @debug=[]
-      format_head_seg=SiSU_HTML_Format_type::Head_seg.new(@md)
+      para.gsub!(/(?:\s*#{Mx[:br_page]}\s*|\s*#{Mx[:br_page_new]}\s*)+/m,'')
+      format_head_seg=SiSU_HTML_Format::Head_seg.new(@md)
       if para !~/^#{Rx[:meta]}/
         m=para[/.+?#{Mx[:id_o]}~(\d+);(?:[ohm]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/]
         if m
-          paranum=m[1].to_s
-          @p_num=SiSU_HTML_Format_type::Paragraph_number.new(@md,paranum)
+          ocn=m[1].to_s
+          @p_num=SiSU_HTML_Format::Paragraph_number.new(@md,ocn)
         end
         if para =~/#{Mx[:gr_o]}(?:code|alt|verse|group)#{Mx[:gr_c]}/m \
         or @@flag_alt==true
@@ -288,14 +351,18 @@ module SiSU_HTML_seg
         end
         if para !~/^#{Mx[:lv_o]}[1-9]:|#{Rx[:meta]}/
           if para =~/(.*)#{Mx[:id_o]}~0;(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}(.*)/
-            one,two=$1,$2
-            format_seg=SiSU_HTML_Format_type::Format_seg.new(@md,one,two)
+            cont="#{$1} #{$2}" #check where $2 is other than space
+            txt_obj={:txt =>cont}
+            format_seg=SiSU_HTML_Format::Format_seg.new(@md,txt_obj)
             para=format_seg.no_paranum
           end
         end
         if para[/#{Mx[:id_o]}~(\d+;(?:[ohmu]|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp)#{Mx[:id_c]}$/]
           @sto=SiSU_HTML::Source::Split_text_object.new(@md,para).html_seg
-          format_txt_obj=SiSU_HTML_Format_type::Format_text_object.new(@md,@sto.text) if @sto.format =~/i[1-9]|null/ #watch
+          if @sto.format =~/i[1-9]|ordinary/ #watch
+            txt_obj={:txt =>@sto.text}
+            format_txt_obj=SiSU_HTML_Format::Format_text_object.new(@md,txt_obj)
+          end
           para=case @sto.format # work area 2003w29 ||@|def lev_segname_para_ocn|
           when /^4:/; @sto.seg_lev_para_ocn.header4 # work on see Split_text_object
           when /^5:/; @sto.seg_lev_para_ocn.header5
@@ -312,7 +379,7 @@ module SiSU_HTML_seg
             @sto.seg_lev_para_ocn.para
           when /^code$/
             @sto.seg_lev_para_ocn.code
-          when /null/
+          when /ordinary/
             if para !~/#{@vz.margin_txt_0}|#{@vz.margin_txt_1}|#{@vz.margin_txt_2}/ \
             and para !~/^#{Mx[:gr_o]}TZ#{Mx[:gr_c]}/
               format_txt_obj.gsub_body
@@ -320,14 +387,16 @@ module SiSU_HTML_seg
             elsif para !~/#{@vz.margin_txt_0}|#{@vz.margin_txt_1}|#{@vz.margin_txt_2}/ \
             and para =~/^#{Mx[:gr_o]}TZ#{Mx[:gr_c]}/
               format_txt_obj.gsub_body
-              @sto.seg_lev_para_ocn.table_end
+              @sto.seg_lev_para_ocn.table_css_end
             else para
             end
           else para
           end
         elsif para =~/#{Mx[:tc_p]}|#{Mx[:gr_o]}T[hZ]?/u
+          @sto=nil
           table=SiSU_HTML_shared::Table.new(para)
           para=table.table
+        else @sto=nil
         end
         if @md.flag_separate_endnotes
           para.gsub!(/"\s+href="#_(\d+)">/,%{" href=\"endnotes#{@md.sfx}#_\\1">})       #endnote- twice #removed file type
@@ -335,18 +404,19 @@ module SiSU_HTML_seg
         if para !~/#{@vz.margin_txt_w1}|#{@vz.margin_txt_w2}/
           if para[/(.*)#{Mx[:id_o]}~0;(?:u|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}(.*)/] #% watch u & m?
             one,two=$1,$2
-            format_seg=SiSU_HTML_Format_type::Format_seg.new(@md,one,two)
-#FIX --> not that undefined, rather is not needed, should not be visited, and remove
-            #para=format_seg.seg_no_paranum                                   #% undefined
+            txt_obj={:txt =>$1.strip,:trailing =>$2.strip}
+            format_seg=SiSU_HTML_Format::Format_seg.new(@md,txt_obj)
           end
           para.gsub!(/\s*(-\{{2}~\d+|<:e[:_]\d+>).*/,'')                   #potentially dagerous - removes all paragraphs with <!e_!> #?? workpoint
           if para =~/<a name="_\d+" href="#-\d+">&nbsp;<sup>/                #endnote- note-
-            format_seg=SiSU_HTML_Format_type::Format_seg.new(@md,para)
+            txt_obj={:txt =>para}
+            format_seg=SiSU_HTML_Format::Format_seg.new(@md,txt_obj)
             para=format_seg.no_paranum
           end
         end
-        if @sto.format=~/4:\S+/
+        if @sto and @sto.format=~/4:\S+/
           para.gsub!(/^\s*4:\S+\s*|<:[-_\w\d]?(-.+?-)?>|4~!.+/m,'')              #sort seg headers
+          @@seg[:main] <<  %{\n<div class="content">\n}
           @@seg[:main] << para
           @@seg[:main] << @@seg_subtoc[@@get_hash_fn]                       #% insertion of sub-toc
         else
@@ -356,37 +426,22 @@ module SiSU_HTML_seg
       end
     end
     def tail
-      format_head_seg=SiSU_HTML_Format_type::Head_seg.new(@md)
-      if @md.flag_auto_endnotes
-        @@seg[:tail] << format_head_seg.endnote_mark
-        @@seg[:tail] << @@seg_endnotes[@@get_hash_fn] #endnotes deposited at end of individual segments ||@|EXTRACTION OF ENDNOTES|
+      format_head_seg=SiSU_HTML_Format::Head_seg.new(@md)
+      if @md.flag_auto_endnotes and @@seg_endnotes[@@get_hash_fn]
+        @@seg[:tail] <<  %{\n<div class="content">\n<div class="endnote">\n}
+        if @@seg_endnotes[@@get_hash_fn].flatten.length > 0
+          @@seg[:tail] << format_head_seg.endnote_mark
+          @@seg[:tail] << @@seg_endnotes[@@get_hash_fn].flatten #endnotes deposited at end of individual segments ||@|EXTRACTION OF ENDNOTES|
+        end
+        @@seg[:tail] << '</div>'
+        @@seg[:tail] << '</div>' #this div closes div class content
       end
-      @@seg[:tail] << '<table summary="whitespace"><tr><td>&nbsp;</td></tr></table>'
+      #@@seg[:tail] << '</div><table summary="whitespace"><tr><td>&nbsp;</td></tr></table>'
       ads=SiSU_HTML_promo::Ad.new(@md)
       @@seg[:credits] << format_head_seg.credit << ads.div.close << ads.display << format_head_seg.html_close
     end
-    def output(type='')
-      if @@seg[:title] =~/\S/ #kludge (for exception file better.ways, how ironic) get a real ruby test, e.g. test that not array or...
-        filename_seg=[]
-        filename_seg << @@seg[:title] << @@seg[:tocband]
-        if type !~/endnote/
-          filename_seg << @@seg[:headers] << @@seg[:main]
-        else
-          filename_seg << @@seg[:header_endnotes] << @@seg[:endnote_all]
-        end
-        filename_seg << @@seg[:tail] << @@seg[:tocband] << @@seg[:credits]
-        filename_seg.flatten!.compact!
-        filename_seg.each do |para|
-          unless para =~/\A\s*\Z/
-            para.strip!
-            @@filename_seg << para
-          end
-        end
-        @@filename_seg.close
-      end
-    end
     def reinitialise
-      @@seg[:title],@@seg[:dot_nav],@@seg[:tocband],@@seg[:headers],@@seg[:main],@@seg[:tail],@@seg[:credits]=Array.new(7){[]}
+      @@seg[:title],@@seg[:dot_nav],@@seg[:tocband_banner],@@seg[:tocband_bannerless],@@seg[:headers],@@seg[:main],@@seg[:tail],@@seg[:credits]=Array.new(8){[]}
       @@segtocband=nil
     end
     def cleanup
@@ -407,11 +462,9 @@ module SiSU_HTML_seg
             @@seg_endnotes_array=[] if para=~/^#{Mx[:lv_o]}4:/
             @@fns_previous=@md.fns if para=~/^#{Mx[:lv_o]}1:meta#{Mx[:lv_c]}/
           end
-          if para =~/^#{Mx[:lv_o]}4:/                                              #% EXTRACTION OF SUB-TOCs
+          if para =~/^#{Mx[:lv_o]}4:/                                              #%  EXTRACTION OF SUB-TOCs & SEGMENT NAME, after EXTRACTION OF ENDNOTES & SUB-TOCs
             @@seg_subtoc[@@fn]=@@seg_subtoc_array
             @@seg_subtoc_array=[]
-          end
-          if para =~/^#{Mx[:lv_o]}4:/                                              #% SEGMENT NAME, after EXTRACTION OF ENDNOTES & SUB-TOCs
             if para !~/^#{Mx[:lv_o]}4:metadata#{Mx[:lv_c]}/
               m=para[/^#{Mx[:lv_o]}4:(\S+?)#{Mx[:lv_c]}.+?#{Mx[:id_o]}~(\d+);(?:[oh]|4:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/]
             end
@@ -429,12 +482,12 @@ module SiSU_HTML_seg
           para.gsub!(/&nbsp;<\/a>/,'&nbsp;')
           case para # series changed 2002w42
           when /^#{Mx[:lv_o]}5:\S*?#{Mx[:lv_c]}\s*(.+)?#{Mx[:id_o]}~(\d+);(?:h|[56]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/ #remove [u]? req by pg texts, revist
-            one,two=$1,$2
-            format_seg=SiSU_HTML_Format_type::Format_seg.new(@md,one,two)
+            txt_obj={:txt =>$1.strip,:ocn =>$2}
+            format_seg=SiSU_HTML_Format::Format_seg.new(@md,txt_obj)
             para=format_seg.subtoc_lev5
           when /^#{Mx[:lv_o]}6:\S*?#{Mx[:lv_c]}\s*(.+)?#{Mx[:id_o]}~(\d+);(?:h|[56]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/
-            one,two=$1,$2
-            format_seg=SiSU_HTML_Format_type::Format_seg.new(@md,one,two)
+            txt_obj={:txt =>$1.strip,:ocn =>$2}
+            format_seg=SiSU_HTML_Format::Format_seg.new(@md,txt_obj)
             para=format_seg.subtoc_lev6
           end
           @@seg_subtoc_array << para
@@ -459,19 +512,22 @@ module SiSU_HTML_seg
               e_n=note_match_seg[/(?:#{Mx[:en_a_o]}[\d*+]+|#{Mx[:en_b_o]}[*+]\d+)\s+(.+?)(?:#{Mx[:en_a_c]}|#{Mx[:en_b_c]})/m,1]
               try=e_n.split(/<br \/>/)
               try.each do |e|
-                format_seg=SiSU_HTML_Format_type::Format_seg.new(@md,e)
+                txt_obj={:txt =>e}
+                format_seg=SiSU_HTML_Format::Format_seg.new(@md,txt_obj)
                 note_match=if e =~/#{Mx[:pa_o]}i[1-9]#{Mx[:pa_c]}/
-                  format_seg.endnote_body_seg_tail_indent
-                else format_seg.endnote_body_seg_tail
+                  format_seg.endnote_body_indent
+                else format_seg.endnote_body
                 end
                 @@seg_endnotes_array << note_match
               end
               try.join('<br \/>')
               #% creation of separate end segment/page of all endnotes referenced back to reference segment
               m=/(?:#{Mx[:en_a_o]}[\d*+]+|#{Mx[:en_b_o]}[*+]\d+)\s+(.+?href=")(#-[\d*+]+".+)(?:#{Mx[:en_a_c]}|#{Mx[:en_b_c]})/mi
-              one=note_match_seg[m,1] #note~ [a name]
-              two=note_match_seg[m,2] #note-
-              format_seg=SiSU_HTML_Format_type::Format_seg.new(@md,one,two)
+              endnote_part_a=note_match_seg[m,1]
+              endnote_part_b=note_match_seg[m,2]
+              txt_obj={:endnote_part_a =>endnote_part_a,:endnote_part_b =>endnote_part_b}
+
+              format_seg=SiSU_HTML_Format::Format_seg.new(@md,txt_obj)
               note_match_all_seg=format_seg.endnote_seg_body(@@fn) #BUG WATCH 200408
               @@seg[:endnote_all] << note_match_all_seg
             end
