@@ -14,8 +14,7 @@
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -67,17 +66,18 @@ module SiSU_HTML_table
       @one,@parablock,@vz=one,one,SiSU_Env::Get_init.instance.skin
     end
     def table_head(inf)
-      %{<table summary="normal text css" width="100%" border="0" bgcolor="white" cellpadding="2" align="center">
-  <tr>
-    <td valign="top" align="justify">
-      <p class="norm" id="o#{inf}"><a name="#{inf}"></a></p>
-    </td>
-    <td>
+      %{
+<div class="substance">
+<label class="ocn">#{inf}</label>
+<p class="norm" id="o#{inf}"><a name="#{inf}"></a>
 <table summary="normal text css" width="100%" border="0" bgcolor="white" cellpadding="2" align="center">}
     end
     def table_end(tablefoot='')
-      %{</table>#{@vz.margin_num}#{@vz.margin_num}&nbsp;#{@vz.table_close}
-#{tablefoot}}
+      %{</p>
+#{tablefoot}
+</div>
+<div class="substance">
+}
     end
     def table_row(inf,h=false)
       bold=if h; '<b>'
@@ -109,16 +109,16 @@ module SiSU_HTML_table
         tablefoot=[]
         @@tablefoot.each {|x| tablefoot << ''}
         @@tablefoot=[]
-        if @parablock =~/#{Mx[:gr_o]}TZ#{Mx[:gr_c]}/; @parablock=table_end
+        if @parablock =~/#{Mx[:gr_o]}TZ#{Mx[:gr_c]}/; @parablock="</table></p>\n</div>" #table_end
         end
       end
       if @@tablehead == 1
         if @parablock =~/#{Mx[:tc_p]}#{Mx[:tc_p]}/u
-          if @parablock =~/#{Mx[:tc_o]}#{Mx[:tc_p]}#{Mx[:tc_p]}(\d+?)#{Mx[:tc_p]}/u
-            @parablock.gsub!(/#{Mx[:tc_o]}#{Mx[:tc_p]}#{Mx[:tc_p]}(\d+?)#{Mx[:tc_p]}/u,table_row($1,true))
+          while @parablock =~/#{Mx[:tc_o]}#{Mx[:tc_p]}#{Mx[:tc_p]}(\d+)#{Mx[:tc_p]}/u
+            @parablock.sub!(/#{Mx[:tc_o]}#{Mx[:tc_p]}#{Mx[:tc_p]}(\d+)#{Mx[:tc_p]}/u,table_row($1,true))
           end
-          if @parablock =~/#{Mx[:tc_p]}#{Mx[:tc_p]}(\d+?)#{Mx[:tc_p]}/u
-            @parablock.gsub!(/#{Mx[:tc_p]}#{Mx[:tc_p]}(\d+?)#{Mx[:tc_p]}/u,table_cell($1,true))
+          while @parablock =~/#{Mx[:tc_p]}#{Mx[:tc_p]}(\d+)#{Mx[:tc_p]}/u
+            @parablock.sub!(/#{Mx[:tc_p]}#{Mx[:tc_p]}(\d+)#{Mx[:tc_p]}/u,table_cell($1,true))
           end
           if @parablock =~/#{Mx[:tc_c]}/
             @parablock.gsub!(/#{Mx[:tc_c]}/,table_row_close(true))
@@ -127,11 +127,11 @@ module SiSU_HTML_table
         end
         @parablock
       else
-        if @parablock =~/#{Mx[:tc_o]}#{Mx[:tc_p]}#{Mx[:tc_p]}(\d+?)#{Mx[:tc_p]}/u
-          @parablock.gsub!(/#{Mx[:tc_o]}#{Mx[:tc_p]}#{Mx[:tc_p]}(\d+?)#{Mx[:tc_p]}/u,table_row($1))
+        while @parablock =~/#{Mx[:tc_o]}#{Mx[:tc_p]}#{Mx[:tc_p]}(\d+)#{Mx[:tc_p]}/u
+          @parablock.sub!(/#{Mx[:tc_o]}#{Mx[:tc_p]}#{Mx[:tc_p]}(\d+)#{Mx[:tc_p]}/u,table_row($1))
         end
-        if @parablock =~/#{Mx[:tc_p]}#{Mx[:tc_p]}(\d+?)#{Mx[:tc_p]}/u
-          @parablock.gsub!(/#{Mx[:tc_p]}#{Mx[:tc_p]}(\d+?)#{Mx[:tc_p]}/u,table_cell($1))
+        while @parablock =~/#{Mx[:tc_p]}#{Mx[:tc_p]}(\d+)#{Mx[:tc_p]}/u
+          @parablock.sub!(/#{Mx[:tc_p]}#{Mx[:tc_p]}(\d+)#{Mx[:tc_p]}/u,table_cell($1))
         end
         if @parablock =~/#{Mx[:tc_c]}/
           @parablock.gsub!(/#{Mx[:tc_c]}/,table_row_close)
@@ -141,12 +141,12 @@ module SiSU_HTML_table
       @parablock
     end
     def table_split
-      @new_content=[]
+      content=[]
       @one.split(/\n/).each do |parablock|
         table=Table.new("#{parablock}\n")
-        @new_content << table.table
+        content << table.table
       end
-      @new_content.join
+      content.join
     end
   end
 end
