@@ -14,8 +14,7 @@
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -105,6 +104,9 @@ module SiSU_Translate
     def metadata
       @lang_class.metadata
     end
+    def filetype_description
+      @lang_class.filetype_description
+    end
     def file_size
       @lang_class.file_size
     end
@@ -114,8 +116,8 @@ module SiSU_Translate
     def sourcefile_digest
       @lang_class.sourcefile_digest
     end
-    def dc_title
-      @lang_class.dc_title
+    def full_title #dc
+      @lang_class.full_title
     end
     def title
       @lang_class.title
@@ -123,8 +125,8 @@ module SiSU_Translate
     def subtitle
       @lang_class.subtitle
     end
-    def creator
-      @lang_class.creator
+    def author
+      @lang_class.author
     end
     def contributor
       @lang_class.contributor
@@ -147,8 +149,8 @@ module SiSU_Translate
     def subject
       @lang_class.subject
     end
-    def dc_description
-      @lang_class.dc_description
+    def description #dc (watch)
+      @lang_class.description
     end
     def abstract
       @lang_class.abstract
@@ -225,6 +227,9 @@ module SiSU_Translate
     def prefix_b
       @lang_class.prefix_b
     end
+    def topic_register
+      @lang_class.topic_register
+    end
     def fns
       @lang_class.fns
     end
@@ -258,6 +263,9 @@ module SiSU_Translate
     def language
       @lang_class.language
     end
+    def manifest_description
+      @lang_class.manifest_description
+    end
     def manifest_description_output
       @lang_class.manifest_description_output
     end
@@ -314,14 +322,17 @@ module SiSU_Translate
     def description
       'description'
     end
+    def filetype_description
+      'filetype description'
+    end
     def metadata
       'metadata'
     end
     def file_size
       'file size'
     end
-    def dc_title
-      'DC Title'
+    def full_title #dc
+      'Title'
     end
     def title
       'Title'
@@ -329,11 +340,14 @@ module SiSU_Translate
     def subtitle
       'Subtitle'
     end
-    def creator
-      'DC Creator'
+    def author
+      'Author'
     end
-    def contributor
-      'DC Contributor'
+    def author #dc
+      'Creator'
+    end
+    def contributor #dc
+      'Contributor'
     end
     def translator
       'Translator'
@@ -341,8 +355,8 @@ module SiSU_Translate
     def illustrator
       'Illustrator'
     end
-    def publisher
-      'DC Publisher'
+    def publisher #dc
+      'Publisher'
     end
     def prepared_by
       'Prepared by'
@@ -350,59 +364,59 @@ module SiSU_Translate
     def digitized_by
       'Digitized by'
     end
-    def subject
-      'DC Subject'
+    def subject #dc
+      'Subject'
     end
-    def dc_description
-      'DC Description'
+    def description #dc (watch)
+      'Description'
     end
-    def abstract
-      'DC Abstract'
+    def abstract #dc
+      'Abstract'
     end
-    def type
-      'DC Type'
+    def type #dc
+      'Type'
     end
-    def rights
-      'DC Rights'
+    def rights #dc
+      'Rights'
     end
-    def date
-      'DC Date'
+    def date #dc
+      'Date'
     end
-    def date_created
-      'DC Date created'
+    def date_created #dc
+      'Date created'
     end
-    def date_issued
-      'DC Date issued'
+    def date_issued #dc
+      'Date issued'
     end
-    def date_available
-      'DC Date available'
+    def date_available #dc
+      'Date available'
     end
-    def date_modified
-      'DC Date modified'
+    def date_modified #dc
+      'Date modified'
     end
-    def date_valid
-      'DC Date valid'
+    def date_valid #dc
+      'Date valid'
     end
-    def language
-      'DC Language'
+    def language #dc
+      'Language'
     end
     def language_original
       'Original Language'
     end
-    def format
-      'DC Format'
+    def format #dc
+      'Format'
     end
-    def identifier
-      'DC Identifier'
+    def identifier #dc
+      'Identifier'
     end
-    def source
-      'DC Source'
+    def source #dc
+      'Source'
     end
-    def relation
-      'DC Relation'
+    def relation #dc
+      'Relation'
     end
-    def coverage
-      'DC Coverage'
+    def coverage #dc
+      'Coverage'
     end
     def keywords
       'Keywords'
@@ -428,6 +442,9 @@ module SiSU_Translate
     def prefix_b
       'Prefix (b)'
     end
+    def topic_register
+      'Topics Registered'
+    end
     def sourcefile
       'Sourcefile'
     end
@@ -464,11 +481,14 @@ module SiSU_Translate
     def language_version_list
       'Document Language Versions, manifests'
     end
+    def manifest_description
+      'SiSU manifest of document filetypes and metadata'
+    end
     def manifest_description_output
-      'SiSU manifest'
+      'Available document filetypes'
     end
     def manifest_description_metadata
-      'SiSU manifest of document metadata'
+      'Document Metadata'
     end
     def language_list_translated
       lang=case @trans_str
@@ -513,14 +533,17 @@ module SiSU_Translate
     def description
       'description'
     end
+    def filetype_description
+      description
+    end
     def metadata
       'metadonnées'
     end
     def file_size
       'taille'
     end
-    def dc_title
-      'Titre (DC)'
+    def full_title #dc
+      'Titre'
     end
     def title
       'Titre'
@@ -528,11 +551,14 @@ module SiSU_Translate
     def subtitle
       'Sous titre'
     end
-    def creator
-      'Auteur (DC)'
+    def author
+      'Auteur'
     end
-    def contributor
-      'Contributeur (DC)'
+    def author #dc
+      'Auteur'
+    end
+    def contributor #dc
+      'Contributeur'
     end
     def translator
       'Traducteur'
@@ -540,8 +566,8 @@ module SiSU_Translate
     def illustrator
       'Illustrateur'
     end
-    def publisher
-      'Éditeur (DC)'
+    def publisher #dc
+      'Éditeur'
     end
     def prepared_by
       'Préparé par'
@@ -549,59 +575,59 @@ module SiSU_Translate
     def digitized_by
       'Numérisé par'
     end
-    def subject
-      'Sujet (DC)'
+    def subject #dc
+      'Sujet'
     end
-    def dc_description
-      'Description (DC)'
+    def description #dc (watch)
+      'Description'
     end
-    def abstract
-      'Résumé (DC)'
+    def abstract #dc
+      'Résumé'
     end
-    def type
-      'Type (DC)'
+    def type #dc
+      'Type'
     end
-    def rights
-      'Droits relatifs à la ressource (DC)'
+    def rights #dc
+      'Droits relatifs à la ressource'
     end
-    def date
-      'Date (DC)'
+    def date #dc
+      'Date'
     end
-    def date_created
-      'Date de création (DC)'
+    def date_created #dc
+      'Date de création'
     end
-    def date_issued
-      'Date de publication (DC)'
+    def date_issued #dc
+      'Date de publication'
     end
-    def date_available
-      'Date de mise à disposition (DC)'
+    def date_available #dc
+      'Date de mise à disposition'
     end
-    def date_modified
-      'Date de modification (DC)'
+    def date_modified #dc
+      'Date de modification'
     end
-    def date_valid
-      'Date de validité (DC)'
+    def date_valid #dc
+      'Date de validité'
     end
-    def language
-      'Langue (DC)'
+    def language #dc
+      'Langue'
     end
     def language_original
       'Langue originale'
     end
-    def format
-      'Format (DC)'
+    def format #dc
+      'Format'
     end
-    def identifier
-      'Identifiant (DC)'
+    def identifier #dc
+      'Identifiant'
     end
-    def source
-      'Source (DC)'
+    def source #dc
+      'Source'
     end
-    def relation
-      'Lien (DC)'
+    def relation #dc
+      'Lien'
     end
-    def coverage
-      'Portée du document (DC)'
+    def coverage #dc
+      'Portée du document'
     end
     def keywords
       'Mots clef'
@@ -627,6 +653,9 @@ module SiSU_Translate
     def prefix_b
       'Préfixe (b)'
     end
+    def topic_register
+      'Topics Registered'
+    end
     def sourcefile
       'Fichier source'
     end
@@ -663,6 +692,9 @@ module SiSU_Translate
     def language_version_list
       'Versions des langues du document, manifestes'
     end
+    def manifest_description
+      'SiSU manifest of document filetypes and metadata'
+    end
     def manifest_description_output
       'Manifeste SiSU du document généré'
     end
@@ -712,14 +744,17 @@ module SiSU_Translate
     def description
       'Beschreibung'
     end
+    def filetype_description
+      description
+    end
     def metadata
       'Metadata'
     end
     def file_size
       'Dateigrösse'
     end
-    def dc_title
-      'DC Titel'
+    def full_title #dc
+      'Titel'
     end
     def title
       'Titel'
@@ -727,11 +762,11 @@ module SiSU_Translate
     def subtitle
       'Untertitel'
     end
-    def creator
+    def author
       'Autor'
     end
-    def contributor
-      'DC Mitautor'
+    def contributor #dc
+      'Mitautor'
     end
     def translator
       'Übersetzung'
@@ -751,11 +786,11 @@ module SiSU_Translate
     def subject
       'Titel'
     end
-    def dc_description
+    def description #dc (watch)
       'Beschreibung'
     end
-    def abstract
-      'DC Abstract'
+    def abstract #dc
+      'Abstract'
     end
     def type
       'Typ'
@@ -787,20 +822,20 @@ module SiSU_Translate
     def language_original
       'Ursprungssprache'
     end
-    def format
-      'DC Format'
+    def format #dc
+      'Format'
     end
-    def identifier
-      'DC Bezeichnung'
+    def identifier #dc
+      'Bezeichnung'
     end
-    def source
-      'DC Quelle'
+    def source #dc
+      'Quelle'
     end
-    def relation
-      'DC Beziehung'
+    def relation #dc
+      'Beziehung'
     end
-    def coverage
-      'DC Eingrenzung'
+    def coverage #dc
+      'Eingrenzung'
     end
     def keywords
       'Schlüsselwörter'
@@ -826,6 +861,9 @@ module SiSU_Translate
     def prefix_b
       'Präfix (b)'
     end
+    def topic_register
+      'Topics Registered'
+    end
     def sourcefile
       'Quelldatei'
     end
@@ -862,6 +900,9 @@ module SiSU_Translate
     def language_version_list
       'verfügbare Sprachen'
     end
+    def manifest_description
+      'SiSU manifest of document filetypes and metadata'
+    end
     def manifest_description_output
       'SiSU Zusammenfassung des Dokumentes'
     end
@@ -907,18 +948,21 @@ module SiSU_Translate
     end
     def filename
      'nombre del fichero'
-   end
-   def description
-     'descripción'
-   end
+    end
+    def description
+      'descripción'
+    end
+    def filetype_description
+      description
+    end
    def metadata
      'metadatos'
    end
    def file_size
      'tamaño del fichero'
    end
-   def dc_title
-     'Título DC'
+   def full_title #dc
+     'Título'
    end
    def title
      'Título'
@@ -926,11 +970,11 @@ module SiSU_Translate
    def subtitle
      'Subtítulo'
    end
-   def creator
-     'Creador DC'
+   def author #dc
+     'Creador'
    end
-   def contributor
-     'Contribuidor DC'
+   def contributor #dc
+     'Contribuidor'
    end
    def translator
      'Traductor'
@@ -938,8 +982,8 @@ module SiSU_Translate
    def illustrator
      'Ilustrador'
    end
-   def publisher
-     'Editor DC'
+   def publisher #dc
+     'Editor'
    end
    def prepared_by
      'Preparado por'
@@ -947,59 +991,59 @@ module SiSU_Translate
    def digitized_by
      'Digitalizado por'
    end
-   def subject
-     'Asunto DC'
+   def subject #dc
+     'Asunto'
    end
-   def dc_description
-     'Descripción DC'
+   def description #dc (watch)
+     'Descripción'
    end
-   def abstract
-     'Resumen DC'
+   def abstract #dc
+     'Resumen'
    end
-   def type
-     'Tipo DC'
+   def type #dc
+     'Tipo'
    end
-   def rights
-     'Derechos DC'
+   def rights #dc
+     'Derechos'
    end
-   def date
-     'Fecha DC'
+   def date #dc
+     'Fecha'
    end
-   def date_created
-     'Fecha de creación DC'
+   def date_created #dc
+     'Fecha de creación'
    end
-   def date_issued
-     'Fecha de publicación DC'
+   def date_issued #dc
+     'Fecha de publicación'
    end
-   def date_available
-     'Fecha de disponibilidad DC'
+   def date_available #dc
+     'Fecha de disponibilidad'
    end
-   def date_modified
-     'Fecha de modificación DC'
+   def date_modified #dc
+     'Fecha de modificación'
    end
-   def date_valid
-     'Fecha de valided DC'
+   def date_valid #dc
+     'Fecha de valided'
    end
-   def language
-     'Idioma DC'
+   def language #dc
+     'Idioma'
    end
    def language_original
      'Lenguaje original'
    end
-   def format
-     'Formato DC'
+   def format #dc
+     'Formato'
    end
-   def identifier
-     'Identificador DC'
+   def identifier #dc
+     'Identificador'
    end
-   def source
-     'Fuente DC'
+   def source #dc
+     'Fuente'
    end
-   def relation
-     'Relación DC'
+   def relation #dc
+     'Relación'
    end
-   def coverage
-     'Cobertura DC'
+   def coverage #dc
+     'Cobertura'
    end
    def keywords
      'Palabras claves'
@@ -1025,6 +1069,9 @@ module SiSU_Translate
    def prefix_b
      'Prefijo (b)'
    end
+    def topic_register
+      'Topics Registered'
+    end
    def sourcefile
      'Fichero fuente'
    end
@@ -1061,6 +1108,9 @@ module SiSU_Translate
    def language_version_list
      'Document Language Versions, manifests'
    end
+    def manifest_description
+      'SiSU manifest of document filetypes and metadata'
+    end
    def manifest_description_output
      'Manifiesto SiSU de salida generada'
    end
@@ -1110,14 +1160,17 @@ module SiSU_Translate
     def description
       'descrizione'
     end
+    def filetype_description
+      description
+    end
     def metadata
       'metadati'
     end
     def file_size
       'dimensione'
     end
-    def dc_title
-      'Titolo (DC)'
+    def full_title #dc
+      'Titolo'
     end
     def title
       'Titolo'
@@ -1125,11 +1178,11 @@ module SiSU_Translate
     def subtitle
       'Sottotitolo'
     end
-    def creator
-      'Autore (DC)'
+    def author #dc
+      'Autore'
     end
-    def contributor
-      'Contributore (DC)'
+    def contributor #dc
+      'Contributore'
     end
     def translator
       'Traduttore'
@@ -1137,8 +1190,8 @@ module SiSU_Translate
     def illustrator
       'Illustratore'
     end
-    def publisher
-      'Casa editrice (DC)'
+    def publisher #dc
+      'Casa editrice'
     end
     def prepared_by
       'Preparato da'
@@ -1146,59 +1199,59 @@ module SiSU_Translate
     def digitized_by
       'Convertito in digitale da'
     end
-    def subject
-      'Oggetto (DC)'
+    def subject #dc
+      'Oggetto'
     end
-    def dc_description
-      'Descrizione (DC)'
+    def description #dc (watch)
+      'Descrizione'
     end
-    def abstract
-      'Abstract (DC)'
+    def abstract #dc
+      'Abstract'
     end
-    def type
-      'Tipo (DC)'
+    def type #dc
+      'Tipo'
     end
-    def rights
-      'Diritti del lettore (DC)'
+    def rights #dc
+      'Diritti del lettore'
     end
-    def date
-      'Data (DC)'
+    def date #dc
+      'Data'
     end
-    def date_created
-      'Data di creazione (DC)'
+    def date_created #dc
+      'Data di creazione'
     end
-    def date_issued
-      'Data di pubblicazione (DC)'
+    def date_issued #dc
+      'Data di pubblicazione'
     end
-    def date_available
-      'Data di effettiva disponibilità (DC)'
+    def date_available #dc
+      'Data di effettiva disponibilità'
     end
-    def date_modified
-      'Data di ultima modifica (DC)'
+    def date_modified #dc
+      'Data di ultima modifica'
     end
-    def date_valid
-      'Data di inizo validità (DC)'
+    def date_valid #dc
+      'Data di inizo validità'
     end
-    def language
-      'Lingua (DC)'
+    def language #dc
+      'Lingua'
     end
     def language_original
       'Lingua originale'
     end
-    def format
-      'Formato (DC)'
+    def format #dc
+      'Formato'
     end
-    def identifier
-      'Indentificatore (DC)'
+    def identifier #dc
+      'Indentificatore'
     end
-    def source
-      'Fonte (DC)'
+    def source #dc
+      'Fonte'
     end
-    def relation
-      'Collegamento (DC)'
+    def relation #dc
+      'Collegamento'
     end
-    def coverage
-      'Ambito (DC)'
+    def coverage #dc
+      'Ambito'
     end
     def keywords
       'Parole chiave'
@@ -1224,6 +1277,9 @@ module SiSU_Translate
     def prefix_b
       'Premessa (b)'
     end
+    def topic_register
+      'Topics Registered'
+    end
     def sourcefile
       'Sorgente'
     end
@@ -1260,6 +1316,9 @@ module SiSU_Translate
     def language_version_list
       'Traduzioni disponibili'
     end
+    def manifest_description
+      'SiSU manifest of document filetypes and metadata'
+    end
     def manifest_description_output
       'Inventario SiSU dell\'output generato'
     end
@@ -1309,14 +1368,17 @@ module SiSU_Translate
     def description
       'kuvaus'
     end
+    def filetype_description
+      description
+    end
     def metadata
       'metadata'
     end
     def file_size
       'tiedoston koko'
     end
-    def dc_title
-      'DC-otsikko'
+    def full_title #dc
+      'otsikko'
     end
     def title
       'Otsikko'
@@ -1324,11 +1386,11 @@ module SiSU_Translate
     def subtitle
       'Alaotsikko'
     end
-    def creator
-      'DC-tekijä'
+    def author #dc
+      'tekijä'
     end
-    def contributor
-      'DC-osallistuja'
+    def contributor #dc
+      'osallistuja'
     end
     def translator
       'Kääntäjä'
@@ -1336,8 +1398,8 @@ module SiSU_Translate
     def illustrator
       'Kuvittaja'
     end
-    def publisher
-      'DC-julkaisija'
+    def publisher #dc
+      'julkaisija'
     end
     def prepared_by
       'Valmistaja'
@@ -1345,59 +1407,59 @@ module SiSU_Translate
     def digitized_by
       'Digitalisoinut'
     end
-    def subject
-      'DC-aihe'
+    def subject #dc
+      'aihe'
     end
-    def dc_description
-      'DC-kuvaus'
+    def description #dc (watch)
+      'kuvaus'
     end
-    def abstract
-      'DC-tiivistelmä'
+    def abstract #dc
+      'tiivistelmä'
     end
-    def type
-      'DC-tyyppi'
+    def type #dc
+      'tyyppi'
     end
-    def rights
-      'DC-oikeudet'
+    def rights #dc
+      'oikeudet'
     end
-    def date
-      'DC-päiväys'
+    def date #dc
+      'päiväys'
     end
-    def date_created
-      'DC-luontipäivä'
+    def date_created #dc
+      'luontipäivä'
     end
-    def date_issued
-      'DC-julkaisupäivä'
+    def date_issued #dc
+      'julkaisupäivä'
     end
-    def date_available
-      'DC-saantipäivä'
+    def date_available #dc
+      'saantipäivä'
     end
-    def date_modified
-      'DC-muokkauspäivä'
+    def date_modified #dc
+      'muokkauspäivä'
     end
-    def date_valid
-      'DC-kelpoisuuspäivä'
+    def date_valid #dc
+      'kelpoisuuspäivä'
     end
-    def language
-      'DC-kieli'
+    def language #dc
+      'kieli'
     end
     def language_original
       'Alkuperäiskieli'
     end
-    def format
-      'DC-muoto'
+    def format #dc
+      'muoto'
     end
-    def identifier
-      'DC-tunnus'
+    def identifier #dc
+      'tunnus'
     end
-    def source
-      'DC-lähde'
+    def source #dc
+      'lähde'
     end
-    def relation
-      'DC-suhde'
+    def relation #dc
+      'suhde'
     end
-    def coverage
-      'DC-kattavuus'
+    def coverage #dc
+      'kattavuus'
     end
     def keywords
       'Avainsanat'
@@ -1423,6 +1485,9 @@ module SiSU_Translate
     def prefix_b
       'Prefix (b)'
     end
+    def topic_register
+      'Topics Registered'
+    end
     def sourcefile
       'Lähdetiedosto'
     end
@@ -1459,6 +1524,9 @@ module SiSU_Translate
     def language_version_list
       'Dokumentin kieliversiot, manifestit'
     end
+    def manifest_description
+      'SiSU manifest of document filetypes and metadata'
+    end
     def manifest_description_output
       'Tuotetun tuloksen SISU-manifesti'
     end
