@@ -14,8 +14,7 @@
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -60,13 +59,22 @@
 =end
 module SiSU_Manifest
   require "#{SiSU_lib}/sysenv"
-  require "#{SiSU_lib}/i18n"
   include SiSU_Env
+  require "#{SiSU_lib}/i18n"
+  require "#{SiSU_lib}/particulars"
+  include SiSU_Particulars
+  require "#{SiSU_lib}/html_minitoc"
+  #require "#{SiSU_lib}/html_format"
+  require "#{SiSU_lib}/html"
+  include SiSU_HTML_Format
+  require "#{SiSU_lib}/param"
   include SiSU_Param
   include SiSU_Viz
   class Source
     def initialize(opt)
       @opt=opt
+      @particulars=SiSU_Particulars::Combined_singleton.instance.get_all(opt)
+      @data=SiSU_HTML::Source::Html_environment.new(@particulars).tuned_file_instructions
       l=SiSU_Env::Standardise_language.new.file_to_language(@opt.fns)
       @doc_language=l[:l]
     end
@@ -83,16 +91,16 @@ module SiSU_Manifest
         tell.green_hi_blue unless @opt.cmd =~/q/
         tell=SiSU_Screen::Ansi.new(@opt.cmd,"#{browser} #{url_html}")
         tell.grey_tab if @opt.cmd =~/v/i
-        Output_Info.new(@md).check_output
+        Output_Info.new(@md,@data).check_output
       rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
       ensure
       end
     end
     private
     class Output_Info <Source
-      def initialize(md)
+      def initialize(md,data)
         @manifest={ :txt=>[],:html=>[] }
-        @md,@fns=md
+        @md,@fns,@data=md,md.fns,data
         @env=SiSU_Env::Info_env.new(@md.fns)
         @fnb=@md.fnb
         @base_url,@base_url_src,@base_url_pod="#{@env.url.root}/#@fnb","#{@env.url.src_txt}","#{@env.url.src_pod}"
@@ -111,7 +119,7 @@ module SiSU_Manifest
           manifest << x
         end
       end
-      def summarize(id,file,img='')
+      def summarize(id,file,img='● ')
         size=(File.size("#{@base_path}/#{file}")/1024.00).to_s
         kb=/([0-9]+\.[0-9]{0,1})/m.match(size)[1]
         @manifest[:txt] << "#{file} #{id} #{kb}\n"
@@ -162,14 +170,14 @@ module SiSU_Manifest
         end
       end
       def metadata(id,info)
-        @manifest[:html] << %{<tr><th class="left"><p class="bold">#{id}:</p></th><td><p class="left">#{info}</p></td></tr>\n}
+        @manifest[:html] << %{<tr><th class="left"><p class="bold_left">#{id}:</p></th><td><p class="left">#{info}</p></td></tr>\n}
       end
       def links(url,lnk,target)
         static=if url =~/^\.\//; url.gsub(/^\.(\.)?/,@base_url)
         elsif url =~/^\.\.\//;   url.gsub(/^\.(\.)?/,@env.url.root)
         else                     url
         end
-        @manifest[:html] << %{<tr><th class="left"><p class="norm"><a href="#{url}">#{lnk}</a></p><p class="tiny">&nbsp;&nbsp;#{@url_brace.xml_open}<a href="#{static}">#{static}</a>#{@url_brace.xml_close}</p></th></tr>\n}
+        @manifest[:html] << %{<tr><th class="right" width=5%><p class="norm">●</p></th><td class="left"><p class="norm"><a href="#{url}">#{lnk}</a></p><p class="tiny">&nbsp;&nbsp;#{@url_brace.xml_open}<a href="#{static}">#{static}</a>#{@url_brace.xml_close}</p></td></tr>\n}
       end
       def output_tests
         if FileTest.file?("#@base_path/#{@md.fn[:toc]}")==true
@@ -182,16 +190,6 @@ module SiSU_Manifest
           id,file='HTML, full length document',@md.fn[:doc]
           summarize(id,file,img)
         end
-        #if FileTest.file?("#@base_path/#{@md.fn[:pdf_p]}")==true
-        #  img='<img border="0" height="18" width="15" src="../_sisu/image_sys/b_pdf.png" alt="PDF portrait" /> '
-        #  id,file="full length document (PDF portrait&nbsp;/ vertical - recommended for printing), size #{@md.papersize_array[0]}",@md.fn[:pdf_p]
-        #  summarize(id,file,img)
-        #end
-        #if FileTest.file?("#@base_path/#{@md.fn[:pdf_l]}")==true
-        #  img='<img border="0" height="15" width="18" src="../_sisu/image_sys/b_pdf.png" alt="PDF landscape" /> '
-        #  id,file="full length document (PDF landscape&nbsp;/ horizontal - recommended for screen viewing), size #{@md.papersize_array[0]}",@md.fn[:pdf_l]
-        #  summarize(id,file,img)
-        #end
         if FileTest.file?("#@base_path/#{@md.fn[:pdf_p_letter]}")==true
           img='<img border="0" height="18" width="15" src="../_sisu/image_sys/b_pdf.png" alt="PDF portrait" /> '
           id,file="PDF, U.S. letter size, portrait/vertical document (recommended for printing)",@md.fn[:pdf_p_letter]
@@ -321,8 +319,8 @@ module SiSU_Manifest
         end
       end
       def metadata_tests
-        if @md.dc_title
-          id,info=@translate.dc_title,@md.dc_title
+        if @md.full_title #dc
+          id,info=@translate.full_title,@md.full_title
           metadata(id,info)
         end
         if @md.title
@@ -333,12 +331,12 @@ module SiSU_Manifest
           id,info=@translate.subtitle,@md.subtitle
           metadata(id,info)
         end
-        if @md.dc_creator
-          id,info=@translate.creator,@md.dc_creator
+        if @md.author #dc
+          id,info=@translate.author,@md.author
           metadata(id,info)
         end
-        if @md.dc_contributor
-          id,info=@translate.contributor,@md.dc_contributor
+        if @md.contributor #dc
+          id,info=@translate.contributor,@md.contributor
           metadata(id,info)
         end
         if @md.translator
@@ -349,8 +347,8 @@ module SiSU_Manifest
           id,info=@translate.illustrator,@md.illustrator
           metadata(id,info)
         end
-        if @md.dc_publisher
-          id,info=@translate.publisher,@md.dc_publisher
+        if @md.publisher #dc
+          id,info=@translate.publisher,@md.publisher
           metadata(id,info)
         end
         if @md.prepared_by
@@ -361,53 +359,53 @@ module SiSU_Manifest
           id,info=@translate.digitized_by,@md.digitized_by
           metadata(id,info)
         end
-        if @md.dc_subject
-          id,info=@translate.subject,@md.dc_subject
+        if @md.subject #dc
+          id,info=@translate.subject,@md.subject
           metadata(id,info)
         end
-        if @md.dc_description
-          id,info=@translate.dc_description,@md.dc_description
+        if @md.description #dc
+          id,info=@translate.description,@md.description
           metadata(id,info)
         end
         if @md.abstract
           id,info=@translate.abstract,@md.abstract
           metadata(id,info)
         end
-        if @md.dc_type
-          id,info=@translate.type,@md.dc_type
+        if @md.type #dc
+          id,info=@translate.type,@md.type
           metadata(id,info)
         end
-        if @md.dc_rights
-          id,info=@translate.rights,@md.dc_rights
+        if @md.rights #dc
+          id,info=@translate.rights,@md.rights
           metadata(id,info)
         end
-        if @md.dc_date
-          id,info=@translate.date,@md.dc_date
+        if @md.date #dc
+          id,info=@translate.date,@md.date
           metadata(id,info)
         end
-        if @md.dc_date_created
-          id,info=@translate.date_created,@md.dc_date_created
+        if @md.date_created #dc
+          id,info=@translate.date_created,@md.date_created
           metadata(id,info)
         end
-        if @md.dc_date_issued
-          id,info=@translate.date_issued,@md.dc_date_issued
+        if @md.date_issued #dc
+          id,info=@translate.date_issued,@md.date_issued
           metadata(id,info)
         end
-        if @md.dc_date_available
-          id,info=@translate.date_available,@md.dc_date_available
+        if @md.date_available #dc
+          id,info=@translate.date_available,@md.date_available
           metadata(id,info)
         end
-        if @md.dc_date_modified
-          id,info=@translate.date_modified,@md.dc_date_modified
+        if @md.date_modified #dc
+          id,info=@translate.date_modified,@md.date_modified
           metadata(id,info)
         end
-        if @md.dc_date_valid
-          id,info=@translate.date_valid,@md.dc_date_valid
+        if @md.date_valid #dc
+          id,info=@translate.date_valid,@md.date_valid
           metadata(id,info)
         end
-        if @md.dc_language \
-        and @md.dc_language[:name]
-          id,info=@translate.language,@md.dc_language[:name]
+        if @md.language \
+        and @md.language[:name] #dc
+          id,info=@translate.language,@md.language[:name]
           metadata(id,info)
         end
         if @md.language_original \
@@ -415,24 +413,24 @@ module SiSU_Manifest
           id,info=@translate.language_original,@md.language_original[:name]
           metadata(id,info)
         end
-        if @md.dc_format
-          id,info=@transate.format,@md.dc_format
+        if @md.format #dc
+          id,info=@transate.format,@md.format
           metadata(id,info)
         end
-        if @md.dc_identifier
-          id,info=@translate.identifier,@md.dc_identifier
+        if @md.identifier #dc
+          id,info=@translate.identifier,@md.identifier
           metadata(id,info)
         end
-        if @md.dc_source
-          id,info=@translate.source,@md.dc_source
+        if @md.source #dc
+          id,info=@translate.source,@md.source
           metadata(id,info)
         end
-        if @md.dc_relation
-          id,info=@translate.relation,@md.dc_relation
+        if @md.relation #dc
+          id,info=@translate.relation,@md.relation
           metadata(id,info)
         end
-        if @md.dc_coverage
-          id,info=@translate.coverage,@md.dc_coverage
+        if @md.coverage #dc
+          id,info=@translate.coverage,@md.coverage
           metadata(id,info)
         end
         if @md.keywords
@@ -467,6 +465,20 @@ module SiSU_Manifest
           id,info=@translate.prefix_b,@md.prefix_b
           metadata(id,info)
         end
+        if @md.topic_register_array.length > 1
+          @manifest[:html] << %{<tr><th class="left"><p class="bold_left">#{@translate.topic_register}:</p></th><td>\n}
+          @md.topic_register_array.each do |t|
+            t.each_with_index do |st,i|
+              if st.class == Array
+                st.each do |v|
+                  @manifest[:html] << %{<p class="it#{i}">#{v}</p>\n}
+                end
+              else @manifest[:html] << %{<p class="it#{i}">#{st}</p>\n}
+              end
+            end
+          end
+          @manifest[:html] << %{</td></tr>\n}
+        end
         if @md.fns
           id,info=@translate.sourcefile,@md.fns
           metadata(id,info)
@@ -523,6 +535,7 @@ module SiSU_Manifest
       end
       def check_output
         begin
+          minitoc=SiSU_HTML_minitoc::Toc_mini.new(@md,@data).songsheet.join("\n")
           id,file='',''
           vz=SiSU_Env::Get_init.instance.skin
           banner_table=if vz.banner_home_button_only !~ /http:\/\/www\.jus\.uio\.no\/sisu/ \
@@ -545,7 +558,7 @@ WOK
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
 <title>
-SiSU manifest: #{@md.title}
+SiSU manifest: #{@md.full_title}
 </title>
 <meta http-equiv="Content-Type" content="text/html;charset=utf-8" />
 <meta name="sourcefile" content="#{@md.fns}" />
@@ -555,16 +568,30 @@ SiSU manifest: #{@md.title}
 </head>
 <body bgcolor="#ffffff" text="#000000" link="#003090" lang="en" xml:lang="en">
 #{banner_table}
-<h1 class="small">#{@md.dc_title}</h1>
-<p class="bold">#{@md.dc_creator}</p>
+<div class="toc">
+#{minitoc.to_s}
+</div>
+<div class="content">
+<h1 class="small">#{@translate.manifest_description}</h1>
+<h2 class="small">#{@md.full_title}</h2>
+<p class="bold">#{@md.author}</p>
+<p class="small">
+&nbsp;&nbsp;<a href="#output">Document, Available Filetypes</a>
+</p>
+<p class="small">
+&nbsp;&nbsp;<a href="#metadata">Document Metadata</a>
+</p>
+<p class="tiny">
+&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<a href="#links">(metadata suggested links (if any)</a>
+</p>
 <table summary="normal text css" width="100%" border="0" bgcolor="white" cellpadding="2" align="center">
 WOK
           published_versions
           @manifest[:html] << '</table>'
           @manifest[:html] <<<<WOK
 <h2 class="small"><a name="output">#{@translate.manifest_description_output}</a></h2>
-<table summary="normal text css" width="100%" border="0" bgcolor="white" cellpadding="2" align="center">
-<tr> <th class="left"><p class="bold">#{@translate.description}</p></th><th class="left"><p class="bold">#{@translate.filename}</p></th><th class="right"><p class="right"><b>#{@translate.file_size}</b></p><p class="tiny_right">(kB)</p></th></tr>
+<table summary="available output/filetypes" width="100%" border="0" bgcolor="white" cellpadding="2" align="center">
+<tr> <th class="left"><p class="bold">#{@translate.filetype_description}</p></th><th class="left"><p class="bold">#{@translate.filename}</p></th><th class="right"><p class="right"><b>#{@translate.file_size}</b></p><p class="tiny_right">(kB)</p></th></tr>
 
 WOK
           output_tests
@@ -576,7 +603,7 @@ WOK
           @manifest[:html] << '</table>'
           @manifest[:html] <<<<WOK
 <h2 class="small"><a name="metadata">#{@translate.manifest_description_metadata}</a></h2>
-<table summary="normal text css" width="100%" border="0" bgcolor="white" cellpadding="2" align="center">
+<table summary="document metadata" width="100%" border="0" bgcolor="white" cellpadding="2" align="center">
 <tr> <th class="left"><p class="bold">#{@translate.metadata}</p></th><th class="left"><p class="bold">#{@translate.description}</p></th></tr>
 WOK
           metadata_tests
@@ -584,8 +611,8 @@ WOK
 </table>
 WOK
           @manifest[:html] <<<<WOK
-<table summary="normal text css" width="90%" border="0" bgcolor="white" cellpadding="2" align="center">
-<tr><th class="left"><p class="bold"><a name="links">#{@translate.suggested_links}:</a></p></th></tr>
+<p class="bold"><a name="links">#{@translate.suggested_links}:</a></p>
+<table summary="suggested links" width="100%" border="0" bgcolor="white" cellpadding="2" align="center">
 WOK
           links_tests
           @manifest[:html] <<<<WOK
@@ -593,15 +620,17 @@ WOK
 WOK
           @manifest[:html] <<<<WOK
 <h2 class="small"><a name="languages">#{@translate.language_version_list}</a></h2>
-<table summary="normal text css" width="100%" border="0" bgcolor="white" cellpadding="2" align="center">
+<table summary="language versions" width="100%" border="0" bgcolor="white" cellpadding="2" align="center">
 <tr> <th class="left"><p class="bold">#{@translate.filename}</p></th><th class="left"><p class="bold">#{@translate.description}</p></th><th class="right"><p class="right">&nbsp;</p></th></tr>
 
 WOK
           language_versions
           @manifest[:html] <<<<WOK
 </table>
-#{vz.credits_splash}
+</div>
+<div class="main_column">
 #{vz.credits_sisu}
+</div>
 </body>
 </html>
 WOK
