@@ -14,8 +14,7 @@
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -66,7 +65,7 @@ module SiSU_manpage
   include SiSU_Param
   include SiSU_Viz
   require "#{SiSU_lib}/manpage_format"
-  include Format
+  include SiSU_Manpage_format
   require "#{SiSU_lib}/shared_txt"
   require "#{SiSU_lib}/shared_structure"
   pwd=Dir.pwd
@@ -144,7 +143,7 @@ module SiSU_manpage
           end
           wrap=util.line_wrap
           if wrap =~ /^\s*[\d*+]+\s+.+?\s*\Z/m
-            wrap.gsub!(/(^|&nbsp;|\s|\*)\\\*/,'\1\\\\\*') #man page requires
+            wrap.gsub!(/(^|&nbsp;|#{Mx[:nbsp]}|\s|\*)\\\*/,'\1\\\\\*') #man page requires
             wrap.gsub!(/\s\.(\S+)/,' \\.\1')
             wrap.gsub!(/(["''])/,"\\\\\\1")                                     # quotation marks need escape
             wrap.gsub!(/^\s*([\d*+]+)\s+(.+?)\s*\Z/m, <<GSUB
@@ -266,6 +265,7 @@ WOK
         table_message='[table omitted, see other document formats]'
         fix=[]
         data.each do |para|
+          para.gsub!(/#{Mx[:id_o]}~0;0:0;x\d+#{Mx[:id_c]}/,'') # if book index? remove
           para.gsub!(/#{Mx[:gr_o]}Th?#{Mx[:tc_p]}.+/um,"#@br#{table_message}")
           para.gsub!(/.+?<-#>/,'')                                           # remove dummy headings (used by html) #check
           para.gsub!(/#{Mx[:gl_bullet]}\s*/,'* ')                                          # bullet markup, marked down
@@ -277,7 +277,7 @@ WOK
           para.gsub!(/\s*#{Mx[:fa_bold_o]}(.+?)#{Mx[:fa_bold_c]}/,"#{Mx[:br_line]}.B \\1#{Mx[:br_line]}")
           para.gsub!(/\s*#{Mx[:fa_underscore_o]}(.+?)#{Mx[:fa_underscore_c]}/,"#{Mx[:br_line]}.I \\1#{Mx[:br_line]}")
           unless para =~/#{Mx[:gr_o]}code#{Mx[:gr_c]}/
-            para.gsub!(/(?:^|\s)\{(.+?)\}((?:https?|file|ftp):\/\/\S+?\.[^'"><\s]+?)([.,]?(?:\s|$))/,"\\1 #{@url_brace.txt_open}\\2#{@url_brace.txt_close}\\3")
+            para.gsub!(/(?:^|\s)#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}((?:https?|file|ftp):\/\/\S+?\.[^'"><\s]+?)([.,]?(?:\s|$))/,"\\1 #{@url_brace.txt_open}\\2#{@url_brace.txt_close}\\3")
             para.gsub!(/(^|#{Mx[:gl_c]}|\s)((?:https?|file|ftp):\/\/\S+?\.[^'"><\s]+?)([.,]?(?:\s|$))/,"\\1#{@url_brace.txt_open}\\2#{@url_brace.txt_close}\\3")
             @manpage[:endnotes]=extract_endnotes(para)
             para.gsub!(/#{Mx[:en_a_o]}([\d*+]+)\s*(?:.+?)#{Mx[:en_a_c]}/m,'[^\1]') # endnote marker marked up
@@ -295,7 +295,7 @@ WOK
             para.gsub!(/#{Mx[:gl_o]}#126#{Mx[:gl_c]}/,'~')
             para.gsub!(/#{Mx[:gl_o]}#169#{Mx[:gl_c]}/,'©')
           end
-          para.gsub!(/(^|&nbsp;|\s|\*)\\\*/,'\1\\\\\*') #man page requires
+          para.gsub!(/(^|&nbsp;|#{Mx[:nbsp]}|\s|\*)\\\*/,'\1\\\\\*') #man page requires
           para.gsub!(/\s\.(\S+)/,' \\.\1')
           para.gsub!(/(\n\.)(\S\S\S+)/m,'\1\\.\2')
           para.gsub!(/-/,'\-') #manpages use this
@@ -330,10 +330,10 @@ WOK
           para.gsub!(/(^|#{Mx[:gl_c]}|\s)[_\\]((?:https?|ftp):\/\/\S+?\.[^'"><\s]+?)([.,]?(?:\s|$))/,'\1\2\3')
           para.gsub!(/<a href=".+?">(.+?)<\/a>/m,'\1')
           para.gsub!(/#{Mx[:mk_o]}name#\S+?#{Mx[:mk_c]}/,'')                                     # remove name links
-          para.gsub!(/&nbsp;/,' ')                                          # decide on
+          para.gsub!(/&nbsp;|#{Mx[:nbsp]}/,' ')                                          # decide on
           para.gsub!(/(["''])/,"\\\\\\1")                                   # quotation marks need escape
-          para.gsub!(/(?:^|[^_\\])\{(\S+?\.(?:png|jpg|gif)) .+?\}(?:(?:https?|file|ftp):\/\/\S+|image)/,'    [ \1 ]') #"[ #{dir.url.images_local}\/\\1 ]")
-          para.gsub!(/^(?:^|[^_\\])\{\S+?\.(?:png|jpg|gif)\s+.+?"(.*?)"\s*\}\S+/,'[image: "\1"]')
+          para.gsub!(/(?:^|[^_\\])#{Mx[:lnk_o]}\s*(\S+?\.(?:png|jpg|gif)) .+?#{Mx[:lnk_c]}(?:(?:https?|file|ftp):\/\/\S+|image)/,'    [ \1 ]') #"[ #{dir.url.images_local}\/\\1 ]")
+          para.gsub!(/^(?:^|[^_\\])#{Mx[:lnk_o]}\s*\S+?\.(?:png|jpg|gif)\s+.+?"(.*?)"\s*#{Mx[:lnk_c]}\S+/,'[image: "\1"]')
           wordlist=para.scan(/\S+/)
           if para =~/^#{Rx[:meta]}\s*(.+?)\Z/m # for headers
             d_meta=SiSU_text_utils::Header_scan.new(@md,para).meta
@@ -343,9 +343,9 @@ WOK
           if para !~/(^#{Rx[:meta]}|#{Mx[:br_eof]}|#{Mx[:br_endnotes]})/
             if para =~@regx #/.+?<~\d+;\w\d+;\w\d+>.*/ #watch change
               paranum=para[@regx,3]
-              @p_num=Format::Paragraph_number.new(paranum)
+              @p_num=SiSU_Manpage_format::Paragraph_number.new(paranum)
             end
-            @sto=SiSU_Structure::Split_text_object.new(@md,para).txt
+            @sto=SiSU_Structure::Split_text_object.new(@md,para).manpage
             ### problem in scroll, it appears tables are getting paragraph numbers
             m=/#{Mx[:id_o]}~(\d+);(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/
             if para =~m \
@@ -369,25 +369,6 @@ WOK
               when /^(6):(\S*)/
                 manpage_structure(para,$1,@sto.ocn,$2)
                 @sto.lev_para_ocn.heading_body6
-              #when /^(i1)$/
-              #  #formatMono.gsubBody
-              #  #para=@sto[:lev_para_ocn].scrIndent1
-              #when /^(i2)$/
-              #  formatMono.gsubBody
-              #  para=@sto[:lev_para_ocn].scrIndent2
-              #when /^(center)$/
-              #  para.gsub!(/(.+)/,
-              #    %{<center>(\\1)</center>})
-              #  para=@sto[:lev_para_ocn].scrPara
-              #when /^(b|bold)$/
-              #  para.gsub!(/(.+)/,
-              #    %{<b>(\\1)</b>})
-              #  para=@sto[:lev_para_ocn].scrPara
-              #when /null/ # see whether u can improve
-              #    if (para !~/#{@margin.txt_0}|#{@margin.txt_1}|#{@margin.txt_2}/)
-              #      #formatMono.gsubBody
-              #      #para=@sto[:lev_para_ocn].scrPara
-              #    end
               else
                 manpage_structure(para,nil,nil,nil) #watch may be problematic
                 para
@@ -406,10 +387,6 @@ WOK
               #@@manpage[:owner_details]=formatMono.bold_para
               #para=''
             elsif para =~/(#{Mx[:tc_p]}|#{Mx[:gr_o]}Th?)/u #tables !
-            elsif para =~/(.*)<!#!>(.*)/
-              one,two=$1,$2
-              format_text=Format_text_object.new(one,two)
-              para=format_text.seg_no_paranum
             end
             if (para =~/<a name="n\d+">/ \
             and para =~/^(-\{{2}~\d+|<!e[:_]\d+!>)/) # -endnote
@@ -418,18 +395,14 @@ WOK
             case para
             when /#{Mx[:pa_o]}:i[1-9]#{Mx[:pa_c]}/
               if para =~/.*<:#>.*$/m
-                format_text=Format_text_object.new(para,'')
+                txt_obj={:txt =>para}
+                format_text=Format_text_object.new(txt_obj)
                 para=format_text.scr_indent_one_no_paranum
               end
             end
             if para !~/#{@vz.margin_txt_0}|#{@vz.margin_txt_1}|#{@vz.margin_txt_2}/
               # i don't get the condition for no paranum
             end
-            if para =~/<:center>/
-              one,two=/(.*)<:center>(.*)/.match(para)[1,2]
-              format_text=Format_text_object.new(one,two)
-              para=format_text.center
-            end
             para.gsub!(/\s(\[)/m,' \ \1') if para #manpages use this
             para.gsub!(/(?:#{Mx[:br_line]}|#{Mx[:br_nl]})/,"\n\n") if para
             para.gsub!(/#{Mx[:gl_o]}#126#{Mx[:gl_c]}/,'~') if para #manpages use this
@@ -445,7 +418,7 @@ WOK
       def publish(manpage)
         divider='='
         content=[]
-        date=if @md.dc_date; @md.dc_date
+        date=if @md.date; @md.date
         else '2007' #date missing decide on action
         end
         proj=SiSU_Env::Info_version.new.get_version
