@@ -9,15 +9,13 @@
  * Author: Ralph Amissah
 
  * Copyright: (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007,
-   2008 Ralph Amissah All Rights Reserved.
+   2007, 2008 Ralph Amissah All Rights Reserved.
 
  * License: GPL 3 or later:
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -92,7 +90,11 @@ module SiSU_Particulars
       set_env
       set_md
     end
-    attr_accessor :opt,:md
+    def get_html_idx(opt)
+      @opt=opt
+      set_html_idx
+    end
+    attr_accessor :opt,:md,:html_idx
     def set_md
       begin
         @md=SiSU_Param::Parameters.new(@opt).get
@@ -116,6 +118,13 @@ module SiSU_Particulars
       rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
       end
     end
+    def set_html_idx
+      begin
+        @html_idx=SiSU_DAL::Source.new(@md).get_idx_html
+        self
+      rescue; SiSU_Errors::Info_error.new($!,$@,@opt.cmd,@opt.fns).error
+      end
+    end
   end
 end
 __END__
