@@ -14,8 +14,7 @@
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -58,7 +57,7 @@
  ** Description: plaintext formatting template
 
 =end
-module Format
+module SiSU_Plaintext_format
   require "#{SiSU_lib}/param"
   include SiSU_Param
   include SiSU_Viz
@@ -78,19 +77,30 @@ module Format
   end
   class Format_text_object
     @@dp=nil
-    def initialize(one,two,three)
-      one.gsub!(/\.(html|pdf|php)/,'') if one =~/\.\.\/\S+/
-      @one,@two,@three=one,two,three
+    def initialize(md,t_o)
+      @md,@t_o=md,t_o
+      if t_o.class == Hash
+        @txt =t_o[:txt]            || nil
+        @lnk_url =t_o[:lnk_url]    || nil
+        @lnk_txt =t_o[:lnk_txt]    || nil
+      #elsif t_o.class == Array
+      #  @txt =txt[0]
+      #elsif t_o.class == String
+      #  @txt =txt
+      else
+        #@one,@two,@three=one,two,three
+        p t_o.class
+        p caller
+      end
       rgx=/^#{Rx[:lv]}/
-      @one.gsub!(rgx,'') if @one =~rgx
+      @txt.gsub!(rgx,'') if @txt =~rgx
       @dp=@@dp ||=SiSU_Env::Info_env.new.digest.pattern
       rgx=/#{Mx[:en_a_o]}[\d*+]+\s+(.+?)#{Mx[:id_o]}#@dp#{Mx[:id_c]}#{Mx[:en_a_c]}/
-      @one.gsub!(rgx,'\1') if @one =~rgx
-      @link,@linkname=one,two
+      @txt.gsub!(rgx,'\1') if @txt =~rgx
       @vz=SiSU_Env::Get_init.instance.skin
     end
     def scr_endnote_body
-      "<endnote>#@one</endnote> "
+      "<endnote>#{@txt}</endnote> "
     end
     def heading_body1
     end
@@ -109,4 +119,3 @@ module Format
   end
 end
 __END__
-
