@@ -14,8 +14,7 @@
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -71,26 +70,11 @@ module SiSU_Remote
       end
       @remote=SiSU_Env::Info_remote.new(@opt)
     end
-    def scp
-      tell=SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement ->',@put)
-      tell.dark_grey_title_hi unless @opt.cmd =~/q/
-      @remote.scp
-    end
     def rsync
       tell=SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement ->',@put)
       tell.dark_grey_title_hi unless @opt.cmd =~/q/
       @remote.rsync
     end
-    def scp_base
-      tell=SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement of base site ->','excluding images')
-      tell.dark_grey_title_hi unless @opt.cmd =~/q/
-      @remote.scp_base
-    end
-    def scp_base_all
-      tell=SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement ->','complete')
-      tell.dark_grey_title_hi unless @opt.cmd =~/q/
-      @remote.scp_base_all
-    end
     def rsync_base
       tell=SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement ->','rsync')
       tell.dark_grey_title_hi unless @opt.cmd =~/q/
@@ -106,6 +90,72 @@ module SiSU_Remote
       tell.dark_grey_title_hi unless @opt.cmd =~/q/
       @remote.rsync_sitemaps
     end
+    def rsync_harvest
+      tell=SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement metadata harvest ->','rsync_harvest')
+      tell.dark_grey_title_hi unless @opt.cmd =~/q/
+      @remote.rsync_harvest
+    end
+    def scp
+      tell=SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement ->',@put)
+      tell.dark_grey_title_hi unless @opt.cmd =~/q/
+      @remote.scp
+    end
+    def scp_base
+      tell=SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement of base site ->','excluding images')
+      tell.dark_grey_title_hi unless @opt.cmd =~/q/
+      @remote.scp_base
+    end
+    def scp_base_all
+      tell=SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement ->','complete')
+      tell.dark_grey_title_hi unless @opt.cmd =~/q/
+      @remote.scp_base_all
+    end
+    #def rsync
+    #  def do #rsync
+    #    tell=SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement ->',@put)
+    #    tell.dark_grey_title_hi unless @opt.cmd =~/q/
+    #    @remote.rsync
+    #  end
+    #  def base
+    #    tell=SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement ->','rsync')
+    #    tell.dark_grey_title_hi unless @opt.cmd =~/q/
+    #    @remote.rsync_base
+    #  end
+    #  def base_sync
+    #    tell=SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement ->','rsync and sync')
+    #    tell.dark_grey_title_hi unless @opt.cmd =~/q/
+    #    @remote.rsync_base_sync
+    #  end
+    #  def sitemaps
+    #    tell=SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement sitemaps ->','rsync')
+    #    tell.dark_grey_title_hi unless @opt.cmd =~/q/
+    #    @remote.rsync_sitemaps
+    #  end
+    #  def harvest
+    #    tell=SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement metadata harvest ->','rsync')
+    #    tell.dark_grey_title_hi unless @opt.cmd =~/q/
+    #    @remote.rsync_harvest
+    #  end
+    #  self
+    #end
+    #def scp
+    #  def do #scp
+    #    tell=SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement ->',@put)
+    #    tell.dark_grey_title_hi unless @opt.cmd =~/q/
+    #    @remote.scp
+    #  end
+    #  def scp_base
+    #    tell=SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement of base site ->','excluding images')
+    #    tell.dark_grey_title_hi unless @opt.cmd =~/q/
+    #    @remote.scp_base
+    #  end
+    #  def scp_base_all
+    #    tell=SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement ->','complete')
+    #    tell.dark_grey_title_hi unless @opt.cmd =~/q/
+    #    @remote.scp_base_all
+    #  end
+    #  self
+    #end
   end
   class Get
     def initialize(opt,get_s)
