@@ -14,8 +14,7 @@
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -65,20 +64,34 @@ module SiSU_Format_Shared
   class CSS_Format
     require "#{SiSU_lib}/defaults"
     @@fns=nil
-    def initialize(md,content=nil,col=nil,en=nil)
-      content.gsub!(/<:i[12]>/,'')
-      @md,@content=md,content
-      @id=@ocn=col[:id]
-      @ocnd,@ocns=col[:ocnd],col[:ocns]
-      @notenumber=en
-      @lv=col[:lev].to_s
+    def initialize(md,t_o)
+      @md,@t_o=md,t_o
+      if t_o.class == Hash
+        @txt =t_o[:txt]            #|| nil #s/@content/@txt/
+        @col =t_o[:col]            #|| nil
+        @notenumber =t_o[:endnote_nr]      || nil
+      #elsif t_o.class == Array
+      #  @txt =txt[0]
+      #elsif t_o.class == String
+      #  @txt =txt
+      else
+        #content.gsub!(/<:i[1-9]>/,'')
+        #@md,@content=md,content
+        p t_o.class
+        p caller
+      end
+
+      @txt.gsub!(/#{Mx[:pa_o]}:i[1-9]#{Mx[:pa_c]}/,'')
+      @id=@ocn=@col[:id]
+      @ocnd,@ocns=@col[:ocnd],@col[:ocns]
+      @lv=@col[:lev].to_s
       @@hname=if @md.fns != @@fns
         @@fns=@md.fns
         ''
       end
-      @hname=if col[:seg] \
-      and not col[:seg].to_s.empty?
-        @@hname=col[:seg].to_s
+      @hname=if @col[:seg] \
+      and not @col[:seg].to_s.empty?
+        @@hname=@col[:seg].to_s
       else @@hname
       end
       @tab="\t"
@@ -87,15 +100,15 @@ module SiSU_Format_Shared
       @@tablehead,@@tablefoot=[],[]
       @vz=SiSU_Env::Get_init.instance.skin
       @env=SiSU_Env::Info_env.new(@md.fns)
-      @base_url="#{@env.url.root}/#{@md.fnb}/#@hname.html"
+      @base_url="#{@env.url.root}/#{@md.fnb}/#{@hname}.html"
     end
     def urls(data)
       @words=[]
       data.each do |word|
-        @words << if word=~/\{(.+?)\}((?:https?|file|ftp)\S+|image)/
-          if word =~/\{(.+?)\}((?:https?|file|ftp)\S+|image)([;.,](?:\s|$))/
-            m,u,d=/\{(.+?)\}((?:https?|file|ftp)\S+|image)([;.,](?:\s|$))/.match(word).captures
-          else m,u=/\{(.+?)\}((?:https?|file|ftp)\S+|image)/.match(word).captures
+        @words << if word=~/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}((?:https?|file|ftp)\S+|image)/
+          if word =~/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}((?:https?|file|ftp)\S+|image)([;.,](?:\s|$))/
+            m,u,d=/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}((?:https?|file|ftp)\S+|image)([;.,](?:\s|$))/.match(word).captures
+          else m,u=/#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}((?:https?|file|ftp)\S+|image)/.match(word).captures
             d=''
           end
           word=case m
@@ -114,14 +127,14 @@ module SiSU_Format_Shared
               %{<a href="#{u}">[#{png}]</a>#{caption}}
             else %{[#{png}] #{caption}}
             end
-            word.gsub!(/\{.+?\}((?:https?|file|ftp)\S+|image)/,ins)
+            word.gsub!(/#{Mx[:lnk_o]}.+?#{Mx[:lnk_c]}((?:https?|file|ftp)\S+|image)/,ins)
           else
             link=m[/(.+)/m]
             png=m.scan(/\S+/)[0].strip
             link=link.strip
             ins=%{<a href="#{u}">#{link}</a>#{d}}
             #ins=%{#{link} <a href="#{u}">[link]</a>#{d}}
-            word.gsub!(/\{.+?\}(?:https?|file|ftp)\S+/,ins)
+            word.gsub!(/#{Mx[:lnk_o]}.+?#{Mx[:lnk_c]}(?:https?|file|ftp)\S+/,ins)
           end
         else word
         end
@@ -131,14 +144,16 @@ module SiSU_Format_Shared
     end
     def markup(para)
       if para !~/^#{Mx[:gr_o]}:code#{Mx[:gr_c]}/
-        if para =~/\{.+?\}((?:https?|file|ftp)\S+|image)/
-          wm=para.scan(/\{.+?\}(?:(?:https?|file|ftp)\S+|image)|\S+/)
+        if para =~/#{Mx[:lnk_o]}.+?#{Mx[:lnk_c]}((?:https?|file|ftp)\S+|image)/
+          wm=para.scan(/#{Mx[:lnk_o]}.+?#{Mx[:lnk_c]}(?:(?:https?|file|ftp)\S+|image)|\S+/)
           words=urls(wm)
           para.gsub!(/.+/m,words)
         end
+        para.gsub!(/#{Mx[:gl_o]}(#[0-9]{3})#{Mx[:gl_c]}/u,'&\1;')
+        para.gsub!(/#{Mx[:gl_o]}#([a-z]{2,4})#{Mx[:gl_c]}/u,'&\1;')
         para.gsub!(/#{Mx[:pa_o]}:i[1-9]#{Mx[:pa_c]}/m,'')
         para.gsub!(/\b[_\\]((?:https?|file|ftp):\/\/\S+?\.[^'"><\s]+?)([;.,]?(?:\s|$))/,'<a href="\1" target="_top">\1</a>\2') #http ftp matches escaped, no decoration
-        para.gsub!(/((?:^|\s)[}])((?:https?|file|ftp):\/\/\S+?\.[^'"><\s]+?)([;.,]?(?:\s|$))/,'\1<a href="\2" target="_top">\2</a>\3') #special case \{ e.g. \}http://url
+        para.gsub!(/((?:^|\s)#{Mx[:lnk_c]})((?:https?|file|ftp):\/\/\S+?\.[^'"><\s]+?)([;.,]?(?:\s|$))/,'\1<a href="\2" target="_top">\2</a>\3') #special case \{ e.g. \}http://url
         para.gsub!(/(^|#{Mx[:gl_c]}|\s)((?:https?|file|ftp):\/\/\S+?\.[^'"><\s]+?)([;.,]?(?=\s|$))/,%{\\1#{@url_brace.xml_open}<a href="\\2" target="_top">\\2</a>#{@url_brace.xml_close}\\3}) #http ftp matches with decoration
       else
         para.gsub!(/(^|[^}])_</m,'\1&lt;'); para.gsub!(/(^|[^}])_>/m,'\1&gt;') #code-block: angle brackets special characters
@@ -147,48 +162,48 @@ module SiSU_Format_Shared
       para
     end
     def paragraph
-      %{#{@tab*1}<p class="h#@lv" id="#@ocn" type="substantive" header="#@hname">\n#{@tab*2}#@content\n#{@tab*1}</p>\n}  << "\n"
+      %{#{@tab*1}<p class="h#{@lv}" id="#{@ocn}" type="substantive" header="#{@hname}">\n#{@tab*2}#{@txt}\n#{@tab*1}</p>\n}  << "\n"
     end
     def endnote #used only by db
-      @content=markup(@content)
+      @txt=markup(@txt)
       <<GSUB
-#{@tab*1}<p class="endnote" name="note_#@notenumber" from="#@ocn">
-#{@tab*2}<a href="#@base_url#-#@notenumber" name="_#@notenumber">#@notenumber.</a> <note>#@content</note>
+#{@tab*1}<p class="endnote" name="note_#{@notenumber}" from="#{@ocn}">
+#{@tab*2}<a href="#{@base_url}#-#{@notenumber}" name="_#{@notenumber}">#{@notenumber}.</a> <note>#{@txt}</note>
 #{@tab*1}</p>
 GSUB
     end
     def lev_toc_hname
-      %{#{@tab*1}<p class="toc#@lv" header="#@hname"><a href="##@ocn">\n#{@tab*2}#@content\n#{@tab*1}</a></p>\n}  << "\n"
+      %{#{@tab*1}<p class="toc#{@lv}" header="#{@hname}"><a href="##{@ocn}">\n#{@tab*2}#{@txt}\n#{@tab*1}</a></p>\n}  << "\n"
     end
     def lev_toc
-      %{#{@tab*1}<p class="toc#@lv"><a href="##@ocn">\n#{@tab*2}#@content\n#{@tab*1}</a></p>\n}  << "\n"
+      %{#{@tab*1}<p class="toc#{@lv}"><a href="##{@ocn}">\n#{@tab*2}#{@txt}\n#{@tab*1}</a></p>\n}  << "\n"
     end
     def lev4_plus
-      %{#{@tab*1}<p class="h#@lv" id="#@ocn" type="substantive" header="#@hname">\n#{@tab*2}#@content\n#{@tab*1}</p>\n}  << "\n"
+      %{#{@tab*1}<p class="h#{@lv}" id="#{@ocn}" type="substantive" header="#{@hname}">\n#{@tab*2}#{@txt}\n#{@tab*1}</p>\n}  << "\n"
     end
     def lev4_minus
-      %{#{@tab*1}<p class="h#@lv" id="#@ocn" type="substantive">\n#{@tab*2}#@content\n#{@tab*1}</p>\n}  << "\n"
+      %{#{@tab*1}<p class="h#{@lv}" id="#{@ocn}" type="substantive">\n#{@tab*2}#{@txt}\n#{@tab*1}</p>\n}  << "\n"
     end
     def norm_comment
-      %{#{@tab*1}<p class="norm" id="none" type="comment">\n#{@tab*2}#@content\n#{@tab*1}</p>\n}
+      %{#{@tab*1}<p class="norm" id="none" type="comment">\n#{@tab*2}#{@txt}\n#{@tab*1}</p>\n}
     end
     def norm
-      @content=markup(@content)
-      %{#{@tab*1}<p class="norm" id="#@ocn" type="substantive">\n#{@tab*2}#@content\n#{@tab*1}</p>\n}
+      @txt=markup(@txt)
+      %{#{@tab*1}<p class="norm" id="#{@ocn}" type="substantive">\n#{@tab*2}#{@txt}\n#{@tab*1}</p>\n}
     end
     def indent(t)
-      @content=markup(@content)
-      %{#{@tab*1}<p class="indent#{t}" id="#@ocn" type="substantive">\n#{@tab*2}#@content\n#{@tab*1}</p>\n}
+      @txt=markup(@txt)
+      %{#{@tab*1}<p class="indent#{t}" id="#{@ocn}" type="substantive">\n#{@tab*2}#{@txt}\n#{@tab*1}</p>\n}
     end
     def para_table
       %{<p class="norm" align="left"><font #{@vz.font_small} #{@vz.font_color} #{@vz.font_face}>}
     end
     def ocn
-      %{#{@tab*1}<p class="ocn">#@ocn</p>} << "\n"
+      %{#{@tab*1}<label class="ocn">#{@ocn}</label>} << "\n"
     end
    def html_table # get rid of use html_table
       @new_content=[]
-      @content.split(/\n/).each do |parablock|
+      @txt.split(/\n/).each do |parablock|
         m=parablock[/<!f(.+?)!>/,1]
         @@tablefoot<<m if m
         parablock.gsub!(/<!f.+?!>/,'')
@@ -233,27 +248,27 @@ GSUB
       @new_content.join
     end
   end
-  class CSS_Format_generic #does CSS_Format in one definition, needs to be told about class, despite brevity of generic, easier to see structure with CSS_Format
-    def initialize(css_class='',content='',id=nil,ocnd=nil,ocns=nil,lv='',hname=nil)
+  class CSS_Format_generic #does CSS_Format in one definition, needs to be told about attrib, despite brevity of generic, easier to see structure with CSS_Format
+    def initialize(attrib='',txt='',id=nil,ocnd=nil,ocns=nil,lv='',hname=nil)
       @tab="\t"
-      @class=css_class
-      @content=content
+      @attrib=attrib
+      @txt=txt
       @lv=@notenumber=lv.to_s
-      #@ocn=ocn.to_s
+      #{@ocn}=ocn.to_s
       @hname=hname.to_s
       @id=@ocn=id
     end
     def paragraph
-      css_class=%{class="#@class" }
+      attrib=%{class="#{@attrib}" }
       if @ocn
-        id=%{id="#@ocn" }
+        id=%{id="#{@ocn}" }
         type=%{type="substantive" }
       else
         id=%{id="none" }
         type=%{type="comment" }
       end
-      header=%{header="#@hname" } if @hname
-      %{#{@tab*1}<p #{css_class}#{id}#{type}#{header}>\n#{@tab*2}#@content\n#{@tab*1}</p>\n}  << "\n"
+      header=%{header="#{@hname}" } if @hname
+      %{#{@tab*1}<p #{attrib}#{id}#{type}#{header}>\n#{@tab*2}#{@txt}\n#{@tab*1}</p>\n}  << "\n"
     end
     def para
       paragraph
@@ -261,4 +276,3 @@ GSUB
   end
 end
 __END__
-
