@@ -14,8 +14,7 @@
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -157,7 +156,7 @@ module SiSU_text_utils
     end
     def start_is_match
       meta=case @p
-      when /^#{Mx[:meta_o]}(title)#{Mx[:meta_c]}\s*(.+?)$/;               header($1,@md.dc_title,'meta','dc') #dc 1
+      when /^#{Mx[:meta_o]}(title)#{Mx[:meta_c]}\s*(.+?)$/;               header($1,@md.full_title,'meta','dc') #dc 1
       #when /^@(subtitle):\s+(.+?)$/;            header($1,$2,'meta','extra')
       when /^#{Mx[:meta_o]}(creator|author)#{Mx[:meta_c]}\s*(.+?)$/;      header('creator',$2,'meta','dc')    #dc 2
       when /^#{Mx[:meta_o]}(subject)#{Mx[:meta_c]}\s*(.+?)$/;             header($1,$2,'meta','dc')           #dc 3
@@ -222,51 +221,4 @@ module SiSU_text_utils
     end
   end
 end
-module SiSU_text_parts_flatfile
-  class Split_text_object
-    @@dl=nil
-    attr_reader :format,:text,:ocn,:lev_para_ocn
-    def initialize(md,para)
-      @md,@para=md,para
-      @format,@ocn='null','null'
-      #@format,@ocn=nil,nil
-      @@dl ||=SiSU_Env::Info_env.new.digest.length
-    end
-    def lev_segname_para_ocn
-      if @para =~/^(?:#{Mx[:lv_o]}[1-9]:\S*?#{Mx[:lv_c]}|<:.+?>).+?#{Mx[:id_o]}~(\d+);(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}[0-9a-f]{#{@@dl}}:[0-9a-f]{#{@@dl}}#{Mx[:id_c]}.*/
-        if /^(#{Mx[:lv_o]}([1-6]):(\S+?)#{Mx[:lv_c]})\s*(\S.+?)#{Mx[:id_o]}~(\d+);(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}[0-9a-f]{#{@@dl}}:[0-9a-f]{#{@@dl}}#{Mx[:id_c]}/m.match(@para)
-          @format,segname,@text,@ocn=$1,$2,$3,$4
-          @format="#@format~#{segname}" #
-        elsif  /^(#{Mx[:lv_o]}([1-6]):#{Mx[:lv_c]})\s*(\S.+?)#{Mx[:id_o]}~(\d+);(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}[0-9a-f]{#{@@dl}}:[0-9a-f]{#{@@dl}}#{Mx[:id_c]}/m.match(@para)
-          @format,@text,@ocn=$1,$2,$3
-        elsif /<:(.+?)>\s*(\S.+?)#{Mx[:id_o]}~(\d+);(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}[0-9a-f]{#{@@dl}}:[0-9a-f]{#{@@dl}}#{Mx[:id_c]}/m.match(@para)
-          @format,@text,@ocn=$1,$2,$3
-        elsif /^(#{Mx[:lv_o]}([1-6]):(\S+?)#{Mx[:lv_c]})\s*(\S.+?)#{Mx[:id_o]}~(0);(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}[0-9a-f]{#{@@dl}}:[0-9a-f]{#{@@dl}}#{Mx[:id_c]}/m.match(@para)
-          @@alt_id_count+=1
-          @format,segname,@text,@ocn=$1,$2,$3,"x#{@@alt_id_count}"
-          @format="#@format~#{segname}" #
-        elsif /^(#{Mx[:lv_o]}([1-6]):#{Mx[:lv_c]})\s*(\S.+?)#{Mx[:id_o]}~(0);(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}[0-9a-f]{#{@@dl}}:[0-9a-f]{#{@@dl}}#{Mx[:id_c]}/m.match(@para)
-          @@alt_id_count+=1
-          @format,@text,@ocn=$1,$2,"x#{@@alt_id_count}"
-        end
-      else
-        if /(.+?)#{Mx[:id_o]}~(\d+);(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}[0-9a-f]{#{@@dl}}:[0-9a-f]{#{@@dl}}#{Mx[:id_c]}/m.match(@para)
-          @text,@ocn=$1,$2
-        end
-        if @para !~/#{Mx[:id_o]}~(\d+);(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}[0-9a-f]{#{@@dl}}:[0-9a-f]{#{@@dl}}#{Mx[:id_c]}|^$/ #added 2002w06
-          @text=/(.+?)/m.match(@para)[1]
-        end
-        if /^(#{Mx[:lv_o]}([1-9]):\S*?#{Mx[:lv_c]})\s*(.+)/m.match(@para)
-          @format,@text=$1,$2
-        end
-      end
-      @lev_para_ocn=if @para =~/.+<~\d+>/ #hmmm, watch
-        Format::ParaSiSU.new(@md,@format,@text,@ocn)
-      else Format::ParaSiSU.new(@md,@format,@text,'<~0>')
-      end
-      self
-    end
-  end
-end
 __END__
-
