@@ -14,8 +14,7 @@
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -166,6 +165,8 @@ module SiSU_XML_munge
           #¢£¥§©ª«®°±²³µ¶¹º»¼½¾×÷
           ##para.gsub!(//, '&#;')
           ##para.gsub!(//, '&;')
+          para.gsub!(/</u, '&#60;') # '&lt;'   # &#060;
+          para.gsub!(/>/u, '&#62;') # '&gt;'   # &#062;
           para.gsub!(/¢/u, '&#162;') # '&cent;'   # &#162;
           para.gsub!(/£/u, '&#163;') # '&pound;'  # &#163;
           para.gsub!(/¥/u, '&#165;') # '&yen;'    # &#165;
@@ -250,10 +251,25 @@ module SiSU_XML_munge
           para.gsub!(/ü/u, '&#253;') # '&uuml;'   # &#253;
           para.gsub!(/þ/u, '&#254;') # '&thorn;'  # &#254;
           para.gsub!(/ÿ/u, '&#255;') # '&yuml;'   # &#255;
+          para.gsub!(/‘/u, '&#8216;') # '&lsquo;' # &#8216;
+          para.gsub!(/’/u, '&#8217;') # '&rsquo;' # &#8217;
+          para.gsub!(/“/u, '&#8220;') # &ldquo;   # &#8220;
+          para.gsub!(/”/u, '&#8221;') # &rdquo;   # &#8221;
+          para.gsub!(/–/u, '&#8211;') # &ndash;   # &#8211;
+          para.gsub!(/—/u, '&#8212;') # &mdash;   # &#8212;
+          para.gsub!(/∝/u, '&#8733;') # &prop;    # &#8733;
+          para.gsub!(/∞/u, '&#8734;') # &infin;   # &#8734;
+          para.gsub!(/™/u, '&#8482;') # &trade;   # &#8482;
+          para.gsub!(/✠/u, '&#10016;') # &cross;  # &#10016;
+          para.gsub!(/ /u, ' ')       # space identify
+          para.gsub!(/ /u, ' ')       # space identify
         end
       end
       def html(para='')
         if @sys.locale =~/utf-?8/i # instead ucs for utf8 #require 'iconv' ? Iñtërnâtiônàlizætiøn
+          para.gsub!(/ /u, ' ')           # space identify
+          para.gsub!(/ /u, ' ')           # space identify
+        else
           para.gsub!(/¢/u, '&cent;')      # &#162;
           para.gsub!(/£/u, '&pound;')     # &#163;
           para.gsub!(/¥/u, '&yen;')       # &#165;
@@ -338,17 +354,32 @@ module SiSU_XML_munge
           para.gsub!(/ü/u, '&uuml;')      # &#253;
           para.gsub!(/þ/u, '&thorn;')     # &#254;
           para.gsub!(/ÿ/u, '&yuml;')      # &#255;
+          para.gsub!(/‘/u, '&#lsquo;')    # &lsquo;  # &#8216;
+          para.gsub!(/’/u, '&#rsquo;')    # &rsquo;  # &#8217;
+          para.gsub!(/“/u, '&ldquo;')     # &ldquo;   # &#8220;
+          para.gsub!(/”/u, '&rdquo;')     # &rdquo;   # &#8221;
+          para.gsub!(/–/u, '&ndash;')     # &ndash;  # &#8211;
+          para.gsub!(/—/u, '&mdash;')     # &mdash;  # &#8212;
+          para.gsub!(/∝/u, '&prop;')      # &prop;   # &#8733;
+          para.gsub!(/∞/u, '&infin;')     # &infin;  # &#8734;
+          para.gsub!(/™/u, '&trade;')     # &trade;  # &#8482;
+          para.gsub!(/✠/u, '&#10016;')    # &#10016;
+          #para.gsub!(/✠/u, '&dagger;')    # &dagger; # &#8224; incorrect replacement †
+          para.gsub!(/ /u, ' ')           # space identify
+          para.gsub!(/ /u, ' ')           # space identify
         end
       end
       self
     end
     def tidywords(wordlist)
       wordlist.each do |x|
+        #imperfect solution will not catch all possible cases
         x.gsub!(/&/,'&amp;') unless x =~/&\S+;/
+        x.gsub!(/&([A-Z])/,'&amp;\1')
       end
     end
     def markup(para='')
-      wordlist=para.scan(/\S+|\n/) #\n needed for tables, check though added 2005w17
+      wordlist=para.scan(/&[#0-9a-z]+;|\S+|\n/) #\n needed for tables, check though added 2005w17
       para=tidywords(wordlist).join(' ').strip
       para.gsub!(/#{Mx[:br_line]}|#{Mx[:br_nl]}/,'<br />')
       para.gsub!(/#{Mx[:mk_o]}:name#\S+?#{Mx[:mk_c]}/,'')
@@ -377,23 +408,25 @@ module SiSU_XML_munge
         para.gsub!(/#{Mx[:br_page]}\s*/,'')
         para.gsub!(/#{Mx[:br_page_new]}\s*/,'')
         para.gsub!(/#{Mx[:pa_non_object_no_heading]}|#{Mx[:pa_non_object_dummy_heading]}/,''); para.gsub!(/<[-~]#>/,'')
-        para.gsub!(/(?:^|[^_\\])\{\s*(\S+?\.(?:jpg|png|gif))\s+(\d+)x(\d+)(\s+[^}]+)?\}(https?:\/\/\S+)/,
-	  %{<image xmlns:xlink="http://www.w3.org/1999/xlink" xlink:type="simple" xlink:actuate="onLoad" xlink:show="embed" xlink:href="#{@dir.url.images_local}/\\1" width="\\2" height="\\3" />[\\1] \\4})
-        para.gsub!(/(?:^|[^_\\])\{\s*(\S+?\.(?:jpg|png|gif))(\s+[^}]+)?\}(https?:\/\/\S+)/,
-	  %{<image xmlns:xlink="http://www.w3.org/1999/xlink" xlink:type="simple" xlink:actuate="onLoad" xlink:show="embed" xlink:href="#{@dir.url.images_local}/\\1"/>\\1})
-        para.gsub!(/(^|#{Mx[:gl_c]}|\s)\{([^}]+)\}(https?:\/\/[^"><]+?)([,.:;"><]?(?=\s|$))/,
+        para.gsub!(/(?:^|[^_\\])#{Mx[:lnk_o]}\s*(\S+?\.(?:jpg|png|gif))\s+(\d+)x(\d+)(\s+[^}]+)?#{Mx[:lnk_c]}(https?:\/\/\S+)/,
+          %{<image xmlns:xlink="http://www.w3.org/1999/xlink" xlink:type="simple" xlink:actuate="onLoad" xlink:show="embed" xlink:href="#{@dir.url.images_local}/\\1" width="\\2" height="\\3" />[\\1] \\4})
+        para.gsub!(/(?:^|[^_\\])#{Mx[:lnk_o]}\s*(\S+?\.(?:jpg|png|gif))(\s+[^}]+)?#{Mx[:lnk_c]}(https?:\/\/\S+)/,
+          %{<image xmlns:xlink="http://www.w3.org/1999/xlink" xlink:type="simple" xlink:actuate="onLoad" xlink:show="embed" xlink:href="#{@dir.url.images_local}/\\1"/>\\1})
+        para.gsub!(/(?:^|[^_\\])#{Mx[:lnk_o]}\s*(\S+?\.(?:jpg|png|gif))\s+(\d+)x(\d+)(\s+[^}]+)?#{Mx[:lnk_c]}image/,
+          %{<image xmlns:xlink="http://www.w3.org/1999/xlink" xlink:type="simple" xlink:actuate="onLoad" xlink:show="embed" xlink:href="#{@dir.url.images_local}/\\1" width="\\2" height="\\3" />[\\1] \\4})
+        para.gsub!(/(?:^|[^_\\])#{Mx[:lnk_o]}\s*(\S+?\.(?:jpg|png|gif))(\s+[^}]+)?#{Mx[:lnk_c]}image/,
+          %{<image xmlns:xlink="http://www.w3.org/1999/xlink" xlink:type="simple" xlink:actuate="onLoad" xlink:show="embed" xlink:href="#{@dir.url.images_local}/\\1"/>\\1})
+        para.gsub!(/(^|#{Mx[:gl_c]}|\s)#{Mx[:lnk_o]}(.+?)#{Mx[:lnk_c]}(https?:\/\/[^"><]+?)([,.:;"><]?(?=\s|$))/,
           '\1<link xmlns:xlink="http://www.w3.org/1999/xlink" xlink:type="simple" xlink:href="\3">\2</link>\4') #watch, compare html_tune
         para.gsub!(/(^|#{Mx[:gl_c]}|\s)((?:https?|file|ftp):\/\/\S+?\.[^'"><\s]+?)([;.,]?(?=\s|$))/,
           %{\\1#{@url_brace.xml_open}<link xmlns:xlink="http://www.w3.org/1999/xlink" xlink:type="simple" xlink:href="\\2">\\2</link>#{@url_brace.xml_close}\\3})
         para.gsub!(/\b[_\\]((?:https?|file|ftp):\/\/\S+?\.[^'"><\s]+?)([;.,]?(?:\s|$))/,
-	  '<link xmlns:xlink="http://www.w3.org/1999/xlink" xlink:type="simple" xlink:href="\1">\1</link>\2') #escaped urls not linked, deal with later
-        para.gsub!(/&nbsp;/,'&#160;')
-        #para.gsub!(/&nbsp;/,' ') #clean
+          '<link xmlns:xlink="http://www.w3.org/1999/xlink" xlink:type="simple" xlink:href="\1">\1</link>\2') #escaped urls not linked, deal with later
       else
         para.gsub!(/(^|[^}])_</m,'\1&lt;'); para.gsub!(/(^|[^}])_>/m,'\1&gt;') #code-block: angle brackets special characters
         para.gsub!(/(^|[^}])_</m,'\1&lt;'); para.gsub!(/(^|[^}])_>/m,'\1&gt;')
-        para.gsub!(/&nbsp;/,'&#160;')
       end
+      para.gsub!(/&nbsp;|#{Mx[:nbsp]}/m,'&#160;')
       para
     end
     def markup_light(para='')
@@ -406,11 +439,11 @@ module SiSU_XML_munge
       para.gsub!(/<[-~]#>/,'')
       para.gsub!(/(^|#{Mx[:gl_c]}|\s)&\s+/,'\1&amp; ') #sort
       para.gsub!(/&([^;]{1,5})/,'&amp;\1') #sort, rough estimate, revisit #WATCH found in node not sax
-      para.gsub!(/(?:^|[^_\\])\{(\S+?\.(?:png|jpg|gif)) .+?\}(?:(?:https?|file|ftp):\/\/\S+|image)/,
+      para.gsub!(/(?:^|[^_\\])#{Mx[:lnk_o]}(\S+?\.(?:png|jpg|gif)) .+?#{Mx[:lnk_c]}(?:(?:https?|file|ftp):\/\/\S+|image)/,
         "<image.path>#{@dir.url.images_local}\/\\1</image.path>")
-      para.gsub!(/&nbsp;/,'&#160;')
+      para.gsub!(/&nbsp;|#{Mx[:nbsp]}/,'&#160;')
       #para.gsub!(/&nbsp;/,' ') #clean
-      wordlist=para.scan(/\S+|\n/) #\n needed for tables, check though added 2005w17
+      wordlist=para.scan(/&[#0-9a-z]+;|\S+|\n/) #\n needed for tables, check though added 2005w17
       para=tidywords(wordlist).join(' ').strip
       para
     end
@@ -429,11 +462,11 @@ module SiSU_XML_munge
       para.gsub!(/<[-~]#>/,'')
       para.gsub!(/(^|#{Mx[:gl_c]}|\s)&\s+/,'\1&amp; ') #sort
       para.gsub!(/&([^;]{1,5})/,'&amp;\1') #sort, rough estimate, revisit #WATCH found in node not sax
-      para.gsub!(/(?:^|[^_\\])\{(\S+?\.(?:png|jpg|gif)) .+?\}(?:(?:https?|file|ftp):\/\/\S+|image)/,
+      para.gsub!(/(?:^|[^_\\])#{Mx[:lnk_o]}(\S+?\.(?:png|jpg|gif)) .+?#{Mx[:lnk_c]}(?:(?:https?|file|ftp):\/\/\S+|image)/,
         "<image.path>#{@dir.url.images_local}\/\\1</image.path>")
-      para.gsub!(/&nbsp;/,'&#160;')
+      para.gsub!(/&nbsp;|#{Mx[:nbsp]}/,'&#160;')
       #para.gsub!(/&nbsp;/,' ') #clean
-      wordlist=para.scan(/\S+|\n/) #\n needed for tables, check though added 2005w17
+      wordlist=para.scan(/&[#0-9a-z]+;|\S+|\n/) #\n needed for tables, check though added 2005w17
       para=tidywords(wordlist).join(' ').strip
       para
     end
@@ -508,109 +541,109 @@ module SiSU_XML_tags #Format
   include SiSU_Viz
   class RDF
     def initialize(md='',seg_name=[],tracker=0)
-      @dc_title=@dc_subtitle=@dc_creator=@dc_subject=@dc_description=@dc_publisher=@dc_contributor=@dc_date=@dc_date_created=@dc_date_issued=@dc_date_available=@dc_date_valid=@dc_date_modified=@dc_type=@dc_format=@dc_identifier=@dc_source=@dc_language=@dc_relation=@dc_coverage=@dc_rights=@copyright=@owner=@keywords=''
+      @full_title=@subtitle=@author=@subject=@description=@publisher=@contributor=@date=@date_created=@date_issued=@date_available=@date_valid=@date_modified=@type=@format=@identifier=@source=@language=@relation=@coverage=@rights=@copyright=@owner=@keywords=''
       #seg_name=%{#{@@seg_name[@@tracker]} - } if @@seg_name[@@tracker]
       @md=md
       @sfx,@pdf=@md.sfx,@md.pdf
       @rdfurl=%{  rdf:about="http://www.jus.uio.no/lm/toc"\n}
-      if @md.dc_title                                                            # DublinCore 1 - title
-        @rdf_title=%{    dc.title="#{seg_name}#{@md.dc_title}"\n}
-        @dc_title=%{  <meta name="dc.title" content="#{@md.dc_title}" />\n}
-        #@dc_title=%{  <meta name="dc.title" content="#{seg_name}#{@md.dc_title}" />\n}
+      if @md.full_title                                                            # DublinCore 1 - title
+        @rdf_title=%{    dc.title="#{seg_name}#{@md.full_title}"\n}
+        @full_title=%{  <meta name="dc.title" content="#{@md.full_title}" />\n}
+        #@full_title=%{  <meta name="dc.title" content="#{seg_name}#{@md.full_title}" />\n}
       end
-      if @md.dc_creator                                                          # DublinCore 2 - creator/author (author)
-        @rdf_creator=%{    dc.creator="#{@md.dc_creator}"\n}
-        content=meta_content_clean(@md.dc_creator)
-        @dc_creator=%{  <meta name="dc.creator" content="#{content}" />\n}
+      if @md.author                                                          # DublinCore 2 - creator/author (author)
+        @rdf_author=%{    dc.author="#{@md.author}"\n}
+        content=meta_content_clean(@md.author)
+        @author=%{  <meta name="dc.author" content="#{content}" />\n}
       end
-      if @md.dc_subject                                                          # DublinCore 3 - subject (us library of congress, eric or udc, or schema???)
-        @rdf_subject=%{    dc.subject="#{@md.dc_subject}"\n}
-        content=meta_content_clean(@md.dc_subject)
-        @dc_subject=%{  <meta name="dc.subject" content="#{content}" />\n}
+      if @md.subject                                                          # DublinCore 3 - subject (us library of congress, eric or udc, or schema???)
+        @rdf_subject=%{    dc.subject="#{@md.subject}"\n}
+        content=meta_content_clean(@md.subject)
+        @subject=%{  <meta name="dc.subject" content="#{content}" />\n}
       end
-      if @md.dc_description                                                      # DublinCore 4 - description
-        @rdf_description=%{    dc.description="#{@md.dc_description}"\n}
-        content=meta_content_clean(@md.dc_description)
-        @dc_description=%{  <meta name="dc.description" content="#{content}" />\n}
+      if @md.description                                                      # DublinCore 4 - description
+        @rdf_description=%{    dc.description="#{@md.description}"\n}
+        content=meta_content_clean(@md.description)
+        @description=%{  <meta name="dc.description" content="#{content}" />\n}
       end
-      if @md.dc_publisher                                                        # DublinCore 5 - publisher (current copy published by)
-        @rdf_publisher=%{    dc.publisher="#{@md.dc_publisher}"\n}
-        content=meta_content_clean(@md.dc_publisher)
-        @dc_publisher=%{  <meta name="dc.publisher" content="#{content}" />\n}
+      if @md.publisher                                                        # DublinCore 5 - publisher (current copy published by)
+        @rdf_publisher=%{    dc.publisher="#{@md.publisher}"\n}
+        content=meta_content_clean(@md.publisher)
+        @publisher=%{  <meta name="dc.publisher" content="#{content}" />\n}
       end
-      if @md.dc_contributor                                                      # DublinCore 6 - contributor
-        @rdf_contributor=%{    dc.contributor="#{@md.dc_contributor}"\n}
-        content=meta_content_clean(@md.dc_contributor)
-        @dc_contributor=%{  <meta name="dc.contributor" content="#{content}" />\n}
+      if @md.contributor                                                      # DublinCore 6 - contributor
+        @rdf_contributor=%{    dc.contributor="#{@md.contributor}"\n}
+        content=meta_content_clean(@md.contributor)
+        @contributor=%{  <meta name="dc.contributor" content="#{content}" />\n}
       end
-      if @md.dc_date                                                             # DublinCore 7 - date year-mm-dd
-        @rdf_date=%{    dc.date="#{@md.dc_date}"\n}
-        @dc_date=%{  <meta name="dc.date" content="#{@md.dc_date}" #{@md.date_scheme} />\n}
+      if @md.date                                                             # DublinCore 7 - date year-mm-dd
+        @rdf_date=%{    dc.date="#{@md.date}"\n}
+        @date=%{  <meta name="dc.date" content="#{@md.date}" #{@md.date_scheme} />\n}
       end
-      if @md.dc_date_created                                                     # DublinCore 7 - date.created year-mm-dd
-        @rdf_date_created=%{    dc.date.created="#{@md.dc_date_created}"\n}
-        @dc_date_created=%{  <meta name="dc.date.created" content="#{@md.dc_date_created}" #{@md.date_created_scheme} />\n}
+      if @md.date_created                                                     # DublinCore 7 - date.created year-mm-dd
+        @rdf_date_created=%{    dc.date.created="#{@md.date_created}"\n}
+        @date_created=%{  <meta name="dc.date.created" content="#{@md.date_created}" #{@md.date_created_scheme} />\n}
       end
-      if @md.dc_date_issued                                                      # DublinCore 7 - date.issued year-mm-dd
-        @rdf_date_issued=%{    dc.date.issued="#{@md.dc_date_issued}"\n}
-        @dc_date_issued=%{  <meta name="dc.date.issued" content="#{@md.dc_date_issued}" #{@md.date_issued_scheme} />\n}
+      if @md.date_issued                                                      # DublinCore 7 - date.issued year-mm-dd
+        @rdf_date_issued=%{    dc.date.issued="#{@md.date_issued}"\n}
+        @date_issued=%{  <meta name="dc.date.issued" content="#{@md.date_issued}" #{@md.date_issued_scheme} />\n}
       end
-      if @md.dc_date_available                                                   # DublinCore 7 - date.available year-mm-dd
-        @rdf_date_available=%{    dc.date.available="#{@md.dc_date_available}"\n}
-        @dc_date_available=%{  <meta name="dc.date.available" content="#{@md.dc_date_available}" #{@md.date_available_scheme} />\n}
+      if @md.date_available                                                   # DublinCore 7 - date.available year-mm-dd
+        @rdf_date_available=%{    dc.date.available="#{@md.date_available}"\n}
+        @date_available=%{  <meta name="dc.date.available" content="#{@md.date_available}" #{@md.date_available_scheme} />\n}
       end
-      if @md.dc_date_valid                                                       # DublinCore 7 - date.valid year-mm-dd
-        @rdf_date_valid=%{    dc.date.valid="#{@md.dc_date_valid}"\n}
-        @dc_date_valid=%{  <meta name="dc.date.valid" content="#{@md.dc_date_valid}" #{@md.date_valid_scheme} />\n}
+      if @md.date_valid                                                       # DublinCore 7 - date.valid year-mm-dd
+        @rdf_date_valid=%{    dc.date.valid="#{@md.date_valid}"\n}
+        @date_valid=%{  <meta name="dc.date.valid" content="#{@md.date_valid}" #{@md.date_valid_scheme} />\n}
       end
-      if @md.dc_date_modified                                                    # DublinCore 7 - date.modified year-mm-dd
-        @rdf_date_modified=%{    dc.date.modified="#{@md.dc_date_modified}"\n}
-        @dc_date_modified=%{  <meta name="dc.date.modified" content="#{@md.dc_date_modified}" #{@md.date_modified_scheme} />\n}
+      if @md.date_modified                                                    # DublinCore 7 - date.modified year-mm-dd
+        @rdf_date_modified=%{    dc.date.modified="#{@md.date_modified}"\n}
+        @date_modified=%{  <meta name="dc.date.modified" content="#{@md.date_modified}" #{@md.date_modified_scheme} />\n}
       end
-      if @md.dc_type                                                             # DublinCore 8 - type (genre eg. report, convention etc)
-        @rdf_type=%{    dc.type="#{@md.dc_type}"\n}
-        content=meta_content_clean(@md.dc_type)
-        @dc_type=%{  <meta name="dc.type" content="#{content}" />\n}
+      if @md.type                                                             # DublinCore 8 - type (genre eg. report, convention etc)
+        @rdf_type=%{    dc.type="#{@md.type}"\n}
+        content=meta_content_clean(@md.type)
+        @type=%{  <meta name="dc.type" content="#{content}" />\n}
       end
-      if @md.dc_format                                                           # DublinCore 9 - format (use your mime type)
-        @rdf_format=%{    dc.format="#{@md.dc_format}"\n}
-        content=meta_content_clean(@md.dc_format)
-        @dc_format=%{  <meta name="dc.format" content="#{content}" />\n}
+      if @md.format                                                           # DublinCore 9 - format (use your mime type)
+        @rdf_format=%{    dc.format="#{@md.format}"\n}
+        content=meta_content_clean(@md.format)
+        @format=%{  <meta name="dc.format" content="#{content}" />\n}
       end
-      if @md.dc_identifier                                                       # DublinCore 10 - identifier (your identifier, could use urn which is free)
-        @rdf_identifier=%{    dc.identifier="#{@md.dc_identifier}"\n}
-        content=meta_content_clean(@md.dc_identifier)
-        @dc_identifier=%{  <meta name="dc.identifier" content="#{content}" />\n}
+      if @md.identifier                                                       # DublinCore 10 - identifier (your identifier, could use urn which is free)
+        @rdf_identifier=%{    dc.identifier="#{@md.identifier}"\n}
+        content=meta_content_clean(@md.identifier)
+        @identifier=%{  <meta name="dc.identifier" content="#{content}" />\n}
       end
-      if @md.dc_source                                                           # DublinCore 11 - source (document source)
-        @rdf_source=%{    dc.source="#{@md.dc_source}"\n}
-        content=meta_content_clean(@md.dc_source)
-        @dc_source=%{  <meta name="dc.source" content="#{content}" />\n}
+      if @md.source                                                           # DublinCore 11 - source (document source)
+        @rdf_source=%{    dc.source="#{@md.source}"\n}
+        content=meta_content_clean(@md.source)
+        @source=%{  <meta name="dc.source" content="#{content}" />\n}
       end
-      if @md.dc_language \
-      and @md.dc_language[:name]                                                  # DublinCore 12 - language (English)
-        @rdf_language=%{    dc.language="#{@md.dc_language[:name]}"\n}
-        @dc_language=%{  <meta name="dc.language" content="#{@md.dc_language[:name]}" />\n}
+      if @md.language \
+      and @md.language[:name]                                                  # DublinCore 12 - language (English)
+        @rdf_language=%{    dc.language="#{@md.language[:name]}"\n}
+        @language=%{  <meta name="dc.language" content="#{@md.language[:name]}" />\n}
       end
       if @md.language_original \
       and @md.language_original[:name]
         @rdf_language_original=%{    dc.language="#{@md.language_original[:name]}"\n}
         @language_original=%{  <meta name="dc.language" content="#{@md.language_original[:name]}" />\n}
       end
-      if @md.dc_relation                                                         # DublinCore 13 - relation
-        @rdf_relation=%{    dc.relation="#{@md.dc_relation}"\n}
-        content=meta_content_clean(@md.dc_relation)
-        @dc_relation=%{  <meta name="dc.relation" content="#{content}" />\n}
+      if @md.relation                                                         # DublinCore 13 - relation
+        @rdf_relation=%{    dc.relation="#{@md.relation}"\n}
+        content=meta_content_clean(@md.relation)
+        @relation=%{  <meta name="dc.relation" content="#{content}" />\n}
       end
-      if @md.dc_coverage                                                         # DublinCore 14 - coverage
-        @rdf_coverage=%{    dc.coverage="#{@md.dc_coverage}"\n}
-        content=meta_content_clean(@md.dc_coverage)
-        @dc_coverage=%{  <meta name="dc.coverage" content="#{content}" />\n}
+      if @md.coverage                                                         # DublinCore 14 - coverage
+        @rdf_coverage=%{    dc.coverage="#{@md.coverage}"\n}
+        content=meta_content_clean(@md.coverage)
+        @coverage=%{  <meta name="dc.coverage" content="#{content}" />\n}
       end
-      if @md.dc_rights                                                           # DublinCore 15 - rights
-        @rdf_rights=%{    dc.rights="#{@md.dc_rights}"\n}
-        content=meta_content_clean(@md.dc_rights)
-        @dc_rights=%{  <meta name="dc.rights" content="#{content}" />\n}
+      if @md.rights                                                           # DublinCore 15 - rights
+        @rdf_rights=%{    dc.rights="#{@md.rights}"\n}
+        content=meta_content_clean(@md.rights)
+        @rights=%{  <meta name="dc.rights" content="#{content}" />\n}
       end
       content=meta_content_clean(@md.keywords)
       @keywords=%{  <meta name="keywords" content="#{content}" />\n} if @md.keywords
@@ -692,7 +725,7 @@ WOK
     def metatag_html #values strung together, because some empty, and resulting output (line breaks) is much better
 #{@vz.js_head}
 <<WOK
-#@dc_title#@dc_subtitle#@dc_creator#@dc_subject#@dc_description#@dc_publisher#@dc_contributor#@dc_date#@dc_date_created#@dc_date_issued#@dc_date_available#@dc_date_valid#@dc_date_modified#@dc_type#@dc_format#@dc_identifier#@dc_source#@dc_language#@dc_relation#@dc_coverage#@dc_rights#@copyright#@owner
+#@full_title#@subtitle#@author#@subject#@description#@publisher#@contributor#@date#@date_created#@date_issued#@date_available#@date_valid#@date_modified#@type#@format#@identifier#@source#@language#@relation#@coverage#@rights#@copyright#@owner
 #{@vz.txt_generator}
 #{@vz.png_ico}
 WOK
