@@ -14,8 +14,7 @@
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -365,7 +364,9 @@ WOK
           para.gsub!(/<:pb>\s*/,'')
           para.gsub!(/\{(\S+?\.(?:png|jpg|gif)) .+?\}(?:(?:https?|file|ftp):\/\/\S+|image)/,
             "<image.path>#{dir.url.images_local}/\\1</image.path>")
-          para.gsub!(/&nbsp;/,' ')
+          para.gsub!(/#{Mx[:lnk_o]}(\S+?\.(?:png|jpg|gif)) .+?#{Mx[:lnk_c]}(?:(?:https?|file|ftp):\/\/\S+|image)/,
+            "<image.path>#{dir.url.images_local}/\\1</image.path>")
+          para.gsub!(/&nbsp;|#{Mx[:nbsp]}/,' ')  # checking source Mx not necessary
           para=SiSU_document_structure::Structure.new(@md,para).structure
           @trans.char_enc.utf8(para) if @sys.locale =~/utf-?8/i #% utf8
           para.gsub!(/^0~(\S+)/,"#{Mx[:lv_o]}@\\1#{Mx[:lv_c]}")
@@ -384,7 +385,7 @@ WOK
             @sto=SiSU_text_parts::Split_text_object.new(@md,para).lev_segname_para
             unless @rcdc
               if para !~/^(?:%\s|0~|@\S+?:)/
-                format_scroll=SiSU_XML_format::Format_scroll.new(@md,@sto.text) if @sto.format =~/i[12]|null/
+                format_scroll=SiSU_XML_format::Format_scroll.new(@md,@sto.text) if @sto.format =~/i[12]|ordinary/
                 case @sto.format
                 when /^(1):(\S*)/
                   xml_clean(para)
@@ -410,25 +411,6 @@ WOK
                   xml_clean(para)
                   xml_structure($1,para,$2)
                   para=@sto.lev_para_ocn.heading_body6
-                #when /^(i1)$/i
-                #  #format_scroll.gsubBody
-                #  #para=@sto.lev_para_ocn.scrIndent1
-                #when /^(i2)$/i
-                #  format_scroll.gsubBody
-                #  para=@sto.lev_para_ocn.scrIndent2
-                #when /^(center)$/i
-                #  para.gsub!(/(.+)/,
-                #    %{<center>(\\1)</center>})
-                #  para=@sto.lev_para_ocn.scrPara
-                #when /^(b|bold)$/i
-                #  para.gsub!(/(.+)/,
-                #    %{<b>(\\1)</b>})
-                #  para=@sto.lev_para_ocn.scrPara
-                #when /null/ # see whether u can improve
-                #    if (para !~/#{@margin.txt_0}|#{@margin.txt_1}|#{@margin.txt_2}/)
-                #      #format_scroll.gsubBody
-                #      #para=@sto.lev_para_ocn.scrPara
-                #    end
                 else
                   if para =~ /<:verse>/
                     para=poem_structure(para)
