@@ -14,8 +14,7 @@
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -440,54 +439,6 @@ WOK
             end
           end
         end
-        #obj.each do |o|
-        #  para=o.txt unless o.txt =~/^%% / #comments are lost, consider
-        #  if para
-        #    para.gsub!(/#{Mx[:fa_italics_o]}(.+?)#{Mx[:fa_italics_c]}/,'<i>\1</i>')
-        #    para.gsub!(/#{Mx[:fa_bold_o]}(.+?)#{Mx[:fa_bold_c]}/,'<b>\1</b>')
-        #    para.gsub!(/#{Mx[:fa_underscore_o]}(.+?)#{Mx[:fa_underscore_c]}/,'<u>\1</u>')
-        #    para.gsub!(/#{Mx[:fa_strike_o]}(.+?)#{Mx[:fa_strike_c]}/,'<del>\1</del>')
-        #    para.gsub!(/#{Mx[:br_line]}|#{Mx[:br_paragraph]}/,'<br />')
-        #    if @rcdc==false \
-        #    and (para =~/~metadata/ or para =~/^1~meta\s+Document Information/)
-        #      if para !~/(^0~|^@\S+?:|^\s*$|<ENDNOTES>|<EOF>)/
-        #        @rcdc=true
-        #      end
-        #      @sto=SiSU_text_parts::Split_text_object.new(@md,para).lev_segname_para
-        #      unless @rcdc
-        #        format_scroll=SiSU_XML_format::Format_scroll.new(@md,@sto.text) if @sto.format =~/i[12]|null/
-        #        case @sto.format
-        #        when /^(1):(\S*)/
-        #          node_structure(o,para,$1,$2)
-        #        when /^(2):(\S*)/
-        #          node_structure(o,para,$1,$2)
-        #        when /^(3):(\S*)/
-        #          node_structure(o,para,$1,$2)
-        #        when /^(4):(\S*)/ # work on see Split_text_object
-        #          node_structure(o,para,$1,$2)
-        #        when /^(5):(\S*)/
-        #          node_structure(o,para,$1,$2)
-        #        when /^(6):(\S*)/
-        #          node_structure(o,para,$1,$2)
-        #        else
-        #          if para =~ /<:verse>/
-        #            node_structure(o,para)
-        #          elsif para =~ /<:group>/
-        #            node_structure(o,para)
-        #          elsif para =~ /<:code>/
-        #            node_structure(o,para)
-        #          elsif para =~/<!Th?.+/ # tables come as single block #work area 2005w13
-        #          #elsif para =~/#{Mx[:gr_o]}Th?.+/ # tables come as single block #work area 2005w13
-        #            table=SiSU_Tables::Table_xml.new(para)
-        #            para=table.table_split
-        #            node_structure(o,para)
-        #          else node_structure(o,para,nil,nil)
-        #          end
-        #        end
-        #      end
-        #    end
-        #  end
-        #end
         obj.each do |o|
           para=o.txt unless o.txt =~/^%% / #comments are lost, consider
           if para
@@ -504,7 +455,7 @@ WOK
             if para !~/(^0~|^@\S+?:|^\s*$|<ENDNOTES>|<EOF>)/
               @sto=SiSU_text_parts::Split_text_object.new(@md,para).lev_segname_para
               unless @rcdc
-                format_scroll=SiSU_XML_format::Format_scroll.new(@md,@sto.text) if @sto.format =~/i[12]|null/
+                format_scroll=SiSU_XML_format::Format_scroll.new(@md,@sto.text) if @sto.format =~/i[12]|ordinary/
                 case @sto.format
                 when /^(1):(\S*)/
                   xml_clean(para)
