@@ -14,8 +14,7 @@
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -293,7 +292,7 @@ WOK
           if para !~/(^0~|^@\S+?:|^\s*$|<ENDNOTES>|<EOF>)/
             @sto=SiSU_text_parts::Split_text_object.new(@md,para).lev_segname_para
             unless @rcdc
-              format_scroll=SiSU_XML_format::Format_scroll.new(@md,@sto.text) if @sto.format =~/i[1-9]|null/
+              format_scroll=SiSU_XML_format::Format_scroll.new(@md,@sto.text) if @sto.format =~/i[1-9]|ordinary/
               case @sto.format
               when /^(1):(\S*)/
                 xml_clean(para)
@@ -319,25 +318,6 @@ WOK
                 xml_clean(para)
                 xml_structure(para,$1,$2)
                 para=@sto.lev_para_ocn.heading_body6
-              #when /^(i1)$/i
-              #  #format_scroll.gsubBody
-              #  #para=@sto[:lev_para_ocn].scrIndent1
-              #when /^(i2)$/i
-              #  format_scroll.gsubBody
-              #  para=@sto[:lev_para_ocn].scrIndent2
-              #when /^(center)$/i
-              #  para.gsub!(/(.+)/,
-              #    %{<center>(\\1)</center>})
-              #  para=@sto[:lev_para_ocn].scrPara
-              #when /^(b|bold)$/i
-              #  para.gsub!(/(.+)/,
-              #    %{<b>(\\1)</b>})
-              #  para=@sto[:lev_para_ocn].scrPara
-              #when /null/ # see whether u can improve
-              #    if (para !~/#{@vz.margin_txt_0}|#{@vz.margin_txt_1}|#{@vz.margin_txt_2}/)
-              #      #format_scroll.gsubBody
-              #      #para=@sto[:lev_para_ocn].scrPara
-              #    end
               else
                 if para =~ /<:verse>/
                   para=poem_structure(para)
