@@ -14,8 +14,7 @@
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -65,7 +64,7 @@ module SiSU_TexInfo
   include SiSU_Viz
   #include Stamp ... needed removed arbitrarily 2005w05/1 (warnings about undefined flags)
   require "#{SiSU_lib}/texinfo_format"
-  include TexInfoFormat
+  include SiSU_Texinfo_format
   @tex_file=[]
   @@tex_backslash="\\\\"
   @@tabular="{tabular}"
@@ -82,7 +81,6 @@ module SiSU_TexInfo
       @opt=opt
       @env=SiSU_Env::Info_env.new(@opt.fns)
       @st={ 'tex'=>{} }
-      @tex=TexInfoFormat::Texinfo.new
       @vz=SiSU_Env::Get_init.instance.skin
     end
     def directories
@@ -129,7 +127,7 @@ module SiSU_TexInfo
   end
   class Texinfo_make
     include SiSU_Param
-    include TexInfoFormat
+    include SiSU_Texinfo_format
     @@tex_1='(?:.+?)+~' #?? debug
     @@tabular="{tabular}"
     @@tex_pattern_margin_number="\\\\marginpar.+?\s+"
@@ -138,7 +136,7 @@ module SiSU_TexInfo
       @data,@md=data,md #fns
       @env=SiSU_Env::Info_env.new(@md.fns)
       @st={ 'tex'=>{} }
-      #@tex=TexInfoFormat::Texinfo.new
+      #@tex=SiSU_Texinfo_format::Texinfo.new
       @vz=SiSU_Env::Get_init.instance.skin
       @dp=@@dp ||=SiSU_Env::Info_env.new.digest.pattern
     end
@@ -165,7 +163,8 @@ module SiSU_TexInfo
         end
         para.gsub!(/<:p[bn]>/,'')
         para.gsub!(/(^|#{Mx[:gl_c]}|\s)\{(.+?)\}((?:https?|file):\/\/\S+)/,'\1(\2 [linked to:] \3)')
-        do_mono=TexInfoFormat::Texinfo.new(para,@md)
+        txt_obj={:txt =>para}
+        do_mono=SiSU_Texinfo_format::Texinfo.new(@md,txt_obj)
         @tex_file << do_mono.spec_char
       end
       data=@tex_file.delete_if {|x| x =~ /^0(?:\\)+~/m}
@@ -244,7 +243,8 @@ module SiSU_TexInfo
       @@tableheader=0
       data.each do |para|
         if para =~ /#{Mx[:tc_p]}|#{Mx[:gr_o]}T/ui
-          do_mono=TexInfoFormat::Texinfo.new(para,@md)
+          txt_obj={:txt =>para}
+          do_mono=SiSU_Texinfo_format::Texinfo.new(@md,txt_obj)
           para=do_mono.longtable # using longtable latex package
         end
         @tex_file << para
@@ -256,19 +256,24 @@ module SiSU_TexInfo
       @row_break='\\\\\\'
       @break_page="#@row_break\n#@row_break \n"
       md={}
-      @tex_file << TexInfoFormat::Texinfo.new('',@md).head
-      mono=TexInfoFormat::Texinfo.new(@md.title,@md)
+      txt_obj={:txt =>''}
+      @tex_file << SiSU_Texinfo_format::Texinfo.new(@md,txt_obj).head
+      txt_obj={:txt =>@md.title}
+      mono=SiSU_Texinfo_format::Texinfo.new(@md,txt_obj)
       @tex_file << mono.topnode
       texinfo_menu=[]
       n_menu,n_submenu=0,0
       @submenu,@subsubmenu={},{}
       data.each do |para|
         para.gsub!(/\s*<:name#example>\s*/,' ')
+        para.gsub!(/#{Mx[:id_o]}~0;0:0;x\d+#{Mx[:id_c]}/,'') # if book index? remove
         if para =~ /^#{Mx[:lv_o]}[1-3]:\S*?#{Mx[:lv_c]}\s*(.+?)\s*$/
-          toc=TexInfoFormat::Texinfo.new($1,@md)
+          txt_obj={:txt =>$1}
+          toc=SiSU_Texinfo_format::Texinfo.new(@md,txt_obj)
           texinfo_menu << toc.menu
         elsif para =~ /^#{Mx[:lv_o]}[4-6]:\S*?#{Mx[:lv_c]}\s*(.+?)\s*$/
-          toc=TexInfoFormat::Texinfo.new($1,@md)
+          txt_obj={:txt =>$1}
+          toc=SiSU_Texinfo_format::Texinfo.new(@md,txt_obj)
           texinfo_menu << toc.menu
           case para
           when /^#{Mx[:lv_o]}4:\S+?#{Mx[:lv_c]}\s*(.+?)\s*$/
@@ -297,7 +302,8 @@ module SiSU_TexInfo
       n_menu,n_submenu=0,0
       @@do_submenu,@@do_subsubmenu=1,1
       data.each do |para|
-        mono=TexInfoFormat::Texinfo.new(para,@md)
+        txt_obj={:txt =>para}
+        mono=SiSU_Texinfo_format::Texinfo.new(@md,txt_obj)
         case para
         when /^#{Mx[:lv_o]}1:/; mono.level1
         when /^#{Mx[:lv_o]}2:/; mono.level2
@@ -310,14 +316,16 @@ module SiSU_TexInfo
           n_submenu+=1
           @@do_subsubmenu=1
           if @@do_submenu==1
-            menu=TexInfoFormat::Texinfo.new(@submenu[n_menu],@md)
+            txt_obj={:txt =>@submenu[n_menu]}
+            menu=SiSU_Texinfo_format::Texinfo.new(@md,txt_obj)
             para="#{menu.submenu}#{mono.level5}"
             @@do_submenu=0
           else mono.level5
           end
         when /^#{Mx[:lv_o]}6:/;
           if @@do_submenu==1
-            menu=TexInfoFormat::Texinfo.new(@subsubmenu[n_menu],@md)
+            txt_obj={:txt =>@submenu[n_menu]}
+            menu=SiSU_Texinfo_format::Texinfo.new(@md,txt_obj)
             para="#{menu.subsubmenu}#{mono.level6}"
             @@do_subsubmenu=0
           else
@@ -391,7 +399,7 @@ module SiSU_TexInfo
         if para =~/#{Mx[:id_o]}\\~(\d+);\w\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}/ \
         and para !~ /#{Mx[:br_eof]}/
           parablock,paranum=/(.+?)#{Mx[:id_o]}\\~(\d+);\w\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}/im.match(para)[1,2]
-          do_duo=TexInfoFormat::DuoTex.new(parablock,paranum) ###is BUG
+          do_duo=SiSU_Texinfo_format::DuoTex.new(parablock,paranum) ###is BUG
           para=do_duo.paraNum if parablock
         end
         @tex_file << para
@@ -400,7 +408,8 @@ module SiSU_TexInfo
     end
     def tail
       data=@data
-      tex=TexInfoFormat::Texinfo.new('',@md)
+      txt_obj={:txt =>''}
+      tex=SiSU_Texinfo_format::Texinfo.new(@md,txt_obj)
       data << tex.dublincore
       data << tex.tail
     end
@@ -428,4 +437,3 @@ module SiSU_TexInfo
   end
 end
 __END__
-
