@@ -14,8 +14,7 @@
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -267,8 +266,8 @@ WOK
         (0..6).each { |x| @cont[x]=@level[x]=false }
         (4..6).each { |x| @xml_contents_close[x]='' }
         data.each do |para|
-          para=@trans.markup(para)
           @trans.char_enc.utf8(para) if @sys.locale =~/utf-?8/i #% utf8
+          para=@trans.markup(para)
           if para =~/^#{Rx[:meta]}\s*.+?$/ # for headers
             d_meta=SiSU_text_utils::Header_scan.new(@md,para).meta
             if d_meta; xml_head(d_meta)
@@ -289,7 +288,8 @@ WOK
             unless @rcdc
               m=/#{Mx[:id_o]}~(\d+);(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/
               if para =~m
-                format_scroll=SiSU_XML_format::Format_scroll.new(@md,@sto.text) if @sto.format =~/i[1-9]|null/
+                txt_obj={:txt =>@sto.text}
+                format_scroll=SiSU_XML_format::Format_scroll.new(@md,txt_obj) if @sto.format =~/i[1-9]|ordinary/
                 case @sto.format
                 when /^(1):(\S*)/
                   xml_structure(para,$1,@sto.ocn,$2)
@@ -342,26 +342,29 @@ WOK
               and para !~/#{Mx[:id_o]}~\d+;(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/
               elsif para =~/(MetaData)/ \
               and para =~/#{Mx[:id_o]}~\d+;[m]\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/ #debug 2003w46 add rc info
-                format_scroll=Format_scroll.new(@md,'<br /><a name="metadata">MetaData</a>')
+                txt_obj={:txt =>'<br /><a name="metadata">MetaData</a>'}
+                format_scroll=Format_scroll.new(@md,txt_obj)
                 para=format_scroll.bold_para
               elsif para =~/(Owner Details)/ \
               and para !~/#{Mx[:id_o]}~\d+;(?:\w|[0-6]:)\d+;\w\d+#{Mx[:id_c]}#{Mx[:id_o]}#@dp:#@dp#{Mx[:id_c]}$/
-                format_scroll=Format_scroll.new(@md,'<br /><a name="owner.details">Owner Details</a>')
+                txt_obj={:txt =>'<br /><a name="owner.details">Owner Details</a>'}
+                format_scroll=Format_scroll.new(@md,txt_obj)
                 @@xml[:owner_details]=format_scroll.bold_para
                 para=''
-              elsif para =~/(.*)<:#>(.*)/
-                one,two=$1,$2
-                format_text=Format_text_object.new(one,two)
-                para=format_text.seg_no_paranum
-              end
-              if para =~/<a name="n\d+">/ \
-              and para =~/^(-\{{2}~\d+|<!e[:_]\d+!>)/ # -endnote
-                para=''
+              #elsif para =~/(.*)<:#>(.*)/
+              #  one,two=$1,$2
+              #  format_text=Format_text_object.new(one,two)
+              #  para=format_text.seg_no_paranum
               end
+              #if para =~/<a name="n\d+">/ \
+              #and para =~/^(-\{{2}~\d+|<!e[:_]\d+!>)/ # -endnote
+              #  para=''
+              #end
               para=case para
               when /#{Mx[:pa_o]}:i[1-9]#{Mx[:pa_c]}/
                 if para =~/.*<:#>.*$/
-                  format_text=Format_text_object.new(para,'')
+                  txt_obj={:txt =>para}
+                  format_text=Format_text_object.new(@md,txt_obj)
                   format_text.scr_inden_ocn_e_no_paranum
                 end
               else para
@@ -369,11 +372,6 @@ WOK
               if para !~/#{@vz.margin_txt_0}|#{@vz.margin_txt_1}|#{@vz.margin_txt_2}/
                 # i don't get the condition for no paranum
               end
-              if para =~/<:center>/
-                one,two=/(.*)<:center>(.*)/.match(para)[1,2]
-                format_text=Format_text_object.new(one,two)
-                para=format_text.center
-              end
             else #
             end
             para.gsub!(/#{Mx[:pa_o]}:\S+#{Mx[:pa_c]}/,'') if para
