@@ -14,8 +14,7 @@
 
    SiSU, a framework for document structuring, publishing and search
 
-   Copyright (C) 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005, 2006,
-   2007, 2008 Ralph Amissah
+   Copyright (C) Ralph Amissah
 
    This program is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the Free
@@ -83,80 +82,80 @@ module SiSU_XML_metadata
 WOK
     end
     def body
-      if @md.dc_title                                                            # DublinCore 1 - title
-        @oai_pmh << %{  <dc:title xml:lang="en">#{@md.dc_title}</dc:title>\n}
-        #@oai_pmh << %{  <dc:title xml:lang="en">#{seg_name}#{@md.dc_title}</dc:title>\n}
+      if @md.full_title                                                            # DublinCore 1 - title
+        @oai_pmh << %{  <dc:title xml:lang="en">#{@md.full_title}</dc:title>\n}
+        #@oai_pmh << %{  <dc:title xml:lang="en">#{seg_name}#{@md.title}</dc:title>\n}
       end
-      if @md.dc_creator                                                          # DublinCore 2 - creator/author (author)
-        txt=meta_content_clean(@md.dc_creator)
-        @oai_pmh << %{  <dc:creator>#{txt}</dc:creator>\n}
+      if @md.author                                                          # DublinCore 2 - author/creator (author)
+        txt=meta_content_clean(@md.author)
+        @oai_pmh << %{  <dc:author>#{txt}</dc:author>\n}
       end
-      if @md.dc_subject                                                          # DublinCore 3 - subject (us library of congress, eric or udc, or schema???)
-        txt=meta_content_clean(@md.dc_subject)
+      if @md.subject                                                          # DublinCore 3 - subject (us library of congress, eric or udc, or schema???)
+        txt=meta_content_clean(@md.subject)
         @oai_pmh << %{  <dc:subject>#{txt}</dc:subject>\n}
       end
-      if @md.dc_description                                                      # DublinCore 4 - description
-        txt=meta_content_clean(@md.dc_description)
+      if @md.description                                                      # DublinCore 4 - description
+        txt=meta_content_clean(@md.description)
         @oai_pmh << %{  <dc:description>#{txt}</dc:description>\n}
       end
-      if @md.dc_publisher                                                        # DublinCore 5 - publisher (current copy published by)
-        txt=meta_content_clean(@md.dc_publisher)
+      if @md.publisher                                                        # DublinCore 5 - publisher (current copy published by)
+        txt=meta_content_clean(@md.publisher)
         @oai_pmh << %{  <dc:publisher>#{txt}</dc:publisher>\n}
       end
-      if @md.dc_contributor                                                      # DublinCore 6 - contributor
-        txt=meta_content_clean(@md.dc_contributor)
+      if @md.contributor                                                      # DublinCore 6 - contributor
+        txt=meta_content_clean(@md.contributor)
         @oai_pmh << %{  <dc:contributor>#{txt}</dc:contributor>\n}
       end
-      if @md.dc_date                                                             # DublinCore 7 - date year-mm-dd
-        @oai_pmh << %{  <dc:date>#{@md.dc_date}</dc:date>\n}
+      if @md.date                                                             # DublinCore 7 - date year-mm-dd
+        @oai_pmh << %{  <dc:date>#{@md.date}</dc:date>\n}
       end
-      if @md.dc_date_created                                                     # DublinCore 7 - date.created
-        @oai_pmh << %{  <dc:date_created>#{@md.dc_date_created}</dc:date_created>\n}
+      if @md.date_created                                                     # DublinCore 7 - date.created
+        @oai_pmh << %{  <dc:date_created>#{@md.date_created}</dc:date_created>\n}
       end
-      if @md.dc_date_issued                                                      # DublinCore 7 - date.issued
-        @oai_pmh << %{  <dc:date_issued>#{@md.dc_date_issued}</dc:date_issued>\n}
+      if @md.date_issued                                                      # DublinCore 7 - date.issued
+        @oai_pmh << %{  <dc:date_issued>#{@md.date_issued}</dc:date_issued>\n}
       end
-      if @md.dc_date_available                                                   # DublinCore 7 - date.available
-        @oai_pmh << %{  <dc:date_available>#{@md.dc_date_available}</dc:date_available>\n}
+      if @md.date_available                                                   # DublinCore 7 - date.available
+        @oai_pmh << %{  <dc:date_available>#{@md.date_available}</dc:date_available>\n}
       end
-      if @md.dc_date_valid                                                       # DublinCore 7 - date.valid
-        @oai_pmh << %{  <dc:date_valid>#{@md.dc_date_valid}</dc:date_valid>\n}
+      if @md.date_valid                                                       # DublinCore 7 - date.valid
+        @oai_pmh << %{  <dc:date_valid>#{@md.date_valid}</dc:date_valid>\n}
       end
-      if @md.dc_date_modified                                                    # DublinCore 7 - date.modified
-        @oai_pmh <<  %{  <dc:date_modified>#{@md.dc_date_modified}</dc:date_modified>\n}
+      if @md.date_modified                                                    # DublinCore 7 - date.modified
+        @oai_pmh <<  %{  <dc:date_modified>#{@md.date_modified}</dc:date_modified>\n}
       end
-      if @md.dc_type                                                             # DublinCore 8 - type
-        txt=meta_content_clean(@md.dc_type)
+      if @md.type                                                             # DublinCore 8 - type
+        txt=meta_content_clean(@md.type)
         @oai_pmh << %{  <dc:type>#{txt}</dc:type>\n}
       end
-      if @md.dc_format                                                           # DublinCore 9 - format
-        txt=meta_content_clean(@md.dc_format)
+      if @md.format                                                           # DublinCore 9 - format
+        txt=meta_content_clean(@md.format)
         @oai_pmh << %{  <dc:format>#{txt}</dc:format>\n}
       end
-      if @md.dc_identifier                                                       # DublinCore 10 - identifier
-        txt=meta_content_clean(@md.dc_identifier)
+      if @md.identifier                                                       # DublinCore 10 - identifier
+        txt=meta_content_clean(@md.identifier)
         @oai_pmh << %{  <dc:identifier>#{txt}</dc:identifier>\n}
       end
-      if @md.dc_source                                                           # DublinCore 11 - source
-        txt=meta_content_clean(@md.dc_source)
+      if @md.source                                                           # DublinCore 11 - source
+        txt=meta_content_clean(@md.source)
         @oai_pmh << %{  <dc:source>#{txt}</dc:source>\n}
       end
-      if @md.dc_language[:name]                                                  # DublinCore 12 - language (English)
-        @oai_pmh << %{  <dc:language>#{@md.dc_language[:name]}</dc:language>\n}
+      if @md.language[:name]                                                  # DublinCore 12 - language (English)
+        @oai_pmh << %{  <dc:language>#{@md.language[:name]}</dc:language>\n}
       end
       if @md.language_original[:name]
         @oai_pmh << %{  <dc:language>#{@md.language_original[:name]}</dc:language>\n}
       end
-      if @md.dc_relation                                                         # DublinCore 13 - relation
-        txt=meta_content_clean(@md.dc_relation)
+      if @md.relation                                                         # DublinCore 13 - relation
+        txt=meta_content_clean(@md.relation)
         @oai_pmh << %{  <dc:relation>#{txt}</dc:relation>\n}
       end
-      if @md.dc_coverage                                                         # DublinCore 14 - coverage
-        txt=meta_content_clean(@md.dc_coverage)
+      if @md.coverage                                                         # DublinCore 14 - coverage
+        txt=meta_content_clean(@md.coverage)
         @oai_pmh << %{  <dc:coverage>#{txt}</dc:coverage>\n}
       end
-      if @md.dc_rights                                                           # DublinCore 15 - rights
-        txt=meta_content_clean(@md.dc_rights)
+      if @md.rights                                                           # DublinCore 15 - rights
+        txt=meta_content_clean(@md.rights)
         @oai_pmh << %{  <dc:rights>#{txt}</dc:rights>\n}
       end
       if @md.keywords
@@ -201,7 +200,7 @@ see also http://dublincore.org/documents/dcmes-xml/
     xsi:schemaLocation="http://www.openarchives.org/OAI/2.0/oai_dc/
     http://www.openarchives.org/OAI/2.0/oai_dc.xsd">
   <dc:title xml:lang="en">Grassmann's space analysis</dc:title>
-  <dc:creator>Hyde, E. W. (Edward Wyllys)</dc:creator>
+  <dc:author>Hyde, E. W. (Edward Wyllys)</dc:author>
   <dc:subject>LCSH:Ausdehnungslehre; LCCN QA205.H99</dc:subject>
   <dc:publisher>J. Wiley &amp; Sons</dc:publisher>
   <dc:date>Created: 1906; Available: 1991</dc:date>
